##############################################################################
#                                                                            #
#                             DDL STAR DICTIONARY                            #
#                                                                            #
##############################################################################


data_DDL_STAR


save_DDL
_dictionary.name                        DDL_STAR
_dictionary.class                       Attribute
_dictionary.version                     3.2.12
_dictionary.date                        2002-02-02
_dictionary.uri                         www.crystal.uwa.edu.au/~syd/dic/ddl_3.dic
_definition.id                          ddl
_definition.scope                       Dictionary
_definition.class                       Registration
_description.text
;
     DDL STAR DICTIONARY    PROTOTYPE VERSION
 
     This dictionary contains the definitions of data items that
     constitute the vocabulary of the STAR dictionary definition
     language (DDL). The defined data names serve as attribute and
     dictionary registration tags for all other STAR dictionaries.
 
     DDL dictionary is composed of three major categories of information.
      |
      |__ ATTRIBUTES  (item names used as attributes in STAR dictionaries)
      |
      |
      |__ IMPORT_DDL  (definitions imported into other DDL definitions)
      |
      |__ AUDIT_DDL   (audit record of the DDL dictionary)
;
loop_
_dictionary_valid.scope
_dictionary_valid.attributes
Dictionary
;
                + _definition.id   + _definition.scope
                + _definition.class
                + _dictionary.name + _dictionary.version
                + _dictionary.date + _dictionary.uri
                ! ALIAS ! CATEGORY ! ENUMERATION ! LOOP ! NAME ! TYPE ! UNITS
                ! METHOD
;
Category
;
                + _definition.id  +  _definition.scope  +  _definition.class
                + _category.parent_id
                ! ALIAS ! DICTIONARY ! ENUMERATION ! LOOP ! NAME ! TYPE ! UNITS
;
Item
;
                + _definition.id + _name.attribute_id + _name.category_id
                ! DICTIONARY
;
save_

#===============================================================================

save_ATTRIBUTES
_definition.id                          attributes
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     The MAJOR CATEGORY of data items which define attributes used in
     all dictionaries to specify the properties of data items.
;
_category.parent_id                     ddl
save_

#-------------------------------------------------------------------------------

save_ALIAS
_definition.id                          alias
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     The attributes used to specify the aliased names of definitions.
;
_category.parent_id                     attributes
_category_key.item_id                   '_alias.definition_id'
_category_key.relational                '_alias.id'
save_


save_alias.id
_definition.id                          '_alias.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       alias
_name.attribute_id                      id
save_


save_alias.definition_id
_definition.id                          '_alias.definition_id'
_definition.update                      2000-11-02
_description.text
;
     Identifier of an aliased definition.
;
_name.category_id                       alias
_name.attribute_id                      definition_id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_alias.dictionary_uri
_definition.id                          '_alias.dictionary_uri'
_definition.update                      2000-11-02
_description.text
;
     Dictionary URI in which the aliased definition belongs.
;
_name.category_id                       alias
_name.attribute_id                      dictionary_uri
_type.container                         Single
_type.value                             Char
_type.purpose                           Uri
save_

#----------------------------------------------------------------------------

save_CATEGORY
_definition.id                          category
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     The attributes used to specify the properties of a
     "category" of data items.
;
_category.parent_id                     attributes
_category_key.relational                '_category.id'
save_


save_category.id
_definition.id                          '_category.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       category
_name.attribute_id                      id
save_


save_category.parent_id
_definition.id                          '_category.parent_id'
_definition.update                      2000-11-02
_description.text
;
     The definition id of the category which is a higher member of the
     organisational hierarchy than the current category definition.
;
_name.category_id                       category
_name.attribute_id                      parent_id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_category.join_set_id
_definition.id                          '_category.join_set_id'
_definition.update                      2000-11-02
_description.text
;
     The definition id of the category to which the curently defined
     category may be joined or merged. This relationship presumes that
     the category keys are interchangeable and the two categories form
     a common basis set.
;
_name.category_id                       category
_name.attribute_id                      join_set_id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_

#----------------------------------------------------------------------------

save_CATEGORY_KEY
_definition.id                          category_key
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     The attributes used to specify the properties of a
     "category_key" of data items.
;
_category.parent_id                     category
_category_key.item_id                   '_category_key.id'
save_


save_category_key.id
_definition.id                          '_category_key.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       category_key
_name.attribute_id                      id
save_


save_category_key.item_id
_definition.id                          '_category_key.item_id'
_definition.update                      2000-11-02
_description.text
;
     Name of the data item within the category which is a key reference
     item for accessing other items in the category. The value of this
     item must be unique in order to provide unambiguous access.
;
_name.category_id                       category_key
_name.attribute_id                      item_id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Name
save_


save_category_key.relational
_definition.id                          '_category_key.relational'
_definition.update                      2000-11-06
_description.text
;
     Name of the data item within the category which is the relational
     key to the category.
;
_name.category_id                       category_key
_name.attribute_id                      relational
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Name
save_

#-----------------------------------------------------------------------------

save_CATEGORY_MANDATORY
_definition.id                          category_mandatory
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     The attributes used to specify the properties of a
     "category_mandatory" of data items.
;
_category.parent_id                     category
_category_key.item_id                   '_category_mandatory.item_id'
_category_key.relational                '_category_mandatory.id'
save_


save_category_mandatory.id
_definition.id                          '_category_mandatory.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       category_mandatory
_name.attribute_id                      id
save_


save_category_mandatory.item_id
_definition.id                          '_category_mandatory.item_id'
_definition.update                      2000-11-02
_description.text
;
     The data name of an item which must exist if any item in the
     category appears in the save frame or data block.
;
_name.category_id                       category_mandatory
_name.attribute_id                      item_id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Name
save_

#----------------------------------------------------------------------------

save_DEFINITION
_definition.id                          definition
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     The attributes for classifying dictionary definitions.
;
_category.parent_id                     attributes
_category_key.relational                '_definition.id'
_category_mandatory.item_id             '_definition.id'
save_


save_definition.class
_definition.id                          '_definition.class'
_definition.update                      2000-11-10
_description.text
;
     The nature and the function of a definition or definitions.
;
_name.category_id                       definition
_name.attribute_id                      class
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
Registration
;
                  The definition of an item that is used to IDENTIFY and AUDIT
                  the function and compilation of each data dictionary.
;
Attribute
;
                  The definition of an item that is used to define the
                  ATTRIBUTES (i.e. characteristics) of other data items.
                  This class of definitions can only appear in a DDL dictionary.
;
Datum
;
                  The definition of an item that describes the specific
                  characteristic of a discipline-specific DATA ITEM.
;
Transient
;
                  The specification of attributes and data which are used
                  by other definitions in a dictionary. The definition names
                  may have no function or existance outside of this dictionary.
;
_enumeration.default                    Datum
save_


save_definition.id
_definition.id                          '_definition.id'
_definition.update                      2000-11-02
_description.text
;
     Identifier name of the definition contained within a save frame.
;
_name.category_id                       definition
_name.attribute_id                      id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_definition.import_id
_definition.id                          '_definition.import_id'
_definition.update                      2000-11-13
_description.text
;
     The identification of the save frame containing attributes to be
     imported into the defined data item. This identifier contains the
     _definition.id name and this may be preceded by a code name that
     can be mapped to an externally defined URI, or by the URI itself.
;
_name.category_id                       definition
_name.attribute_id                      import_id
_type.container                         Single
_type.value                             Char
_type.purpose                           Import
loop_
_description_example.case
'_generic.atom_site_label'
DIC5:_generic.atom_site_label
www.iugg.org/dic/period:_generic.atom_site_label
save_


save_definition.scope
_definition.id                          '_definition.scope'
_definition.update                      2000-11-06
_description.text
;
     The extent to which a definition affects other definitions.
;
_name.category_id                       definition
_name.attribute_id                      scope
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
Dictionary 'applies to all defined items in the dictionary'
Category 'applies to all defined items in the category'
Item 'applies to a single definition'
_enumeration.default                    Item
save_


save_definition.update
_definition.id                          '_definition.update'
_definition.update                      2000-11-10
_description.text
;
     The date that a definition was last changed.
;
_name.category_id                       definition
_name.attribute_id                      update
_type.container                         Single
_type.value                             Char
_type.purpose                           Date
save_


save_definition.xref_code
_definition.id                          '_definition.xref_code'
_definition.update                      2000-11-02
_description.text
;
     Code identifying the equivalent definition in the dictionary
     referenced by the DICTIONARY_XREF attributes.
;
_name.category_id                       definition
_name.attribute_id                      xref_code
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------------

save_DESCRIPTION
_definition.id                          description
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     The attributes of descriptive (non-machine parseable) parts of
     definitions.
;
_category.parent_id                     attributes
_category_key.relational                '_description.id'
save_


save_description.id
_definition.id                          '_description.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       description
_name.attribute_id                      id
save_


save_description.abbreviated
_definition.id                          '_description.abbreviated'
_definition.update                      2000-11-02
_description.text
;
     Abbreviated description containing key-words of the item.
;
_name.category_id                       description
_name.attribute_id                      abbreviated
_type.container                         Single
_type.value                             Char
save_


save_description.compact
_definition.id                          '_description.compact'
_definition.update                      2000-11-02
_description.text
;
     Compact concatenated description of the item.
;
_name.category_id                       description
_name.attribute_id                      compact
_type.container                         Single
_type.value                             Char
save_


save_description.text
_definition.id                          '_description.text'
_definition.update                      2000-11-02
_description.text
;
     The text description of the defined item.
;
_name.category_id                       description
_name.attribute_id                      text
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------------

save_DESCRIPTION_EXAMPLE
_definition.id                          description_example
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     The attributes of descriptive (non-machine parseable) examples of
     values of the defined items.
;
_category.parent_id                     description
_category_key.item_id                   '_description_example.case'
_category_key.relational                '_description_example.id'
save_


save_description_example.id
_definition.id                          '_description_example.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       description_example
_name.attribute_id                      id
save_


save_description_example.case
_definition.id                          '_description_example.case'
_definition.update                      2000-11-02
_description.text
;
     An example case of the defined item.
;
_name.category_id                       description_example
_name.attribute_id                      case
_type.container                         Single
_type.value                             Char
save_


save_description_example.detail
_definition.id                          '_description_example.detail'
_definition.update                      2000-11-02
_description.text
;
     A description of an example case for the defined item.
;
_name.category_id                       description_example
_name.attribute_id                      detail
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------------

save_DICTIONARY
_definition.id                          dictionary
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-10
_description.text
;
     Attributes for identifying and registering the dictionary. The items
     in this category are NOT used as attributes of INDIVIDUAL data items.
;
_category.parent_id                     attributes
loop_
_category_mandatory.item_id
'_dictionary.name'
'_dictionary.uri'
'_dictionary.date'
'_dictionary.version'
save_


save_dictionary.class
_definition.id                          '_dictionary.class'
_definition.update                      2000-11-13
_description.text
;
     The nature, or field of interest, of data items defined in the dictionary.
;
_name.category_id                       dictionary
_name.attribute_id                      class
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
Attribute 'dictionary containing ATTRIBUTE definitions'
Instance 'dictionary containing INSTANCE data definitions'
_enumeration.default                    Application
save_


save_dictionary.date
_definition.id                          '_dictionary.date'
_definition.update                      2000-11-10
_description.text
;
     The date that the last dictionary revision took place.
;
_name.category_id                       dictionary
_name.attribute_id                      date
_type.container                         Single
_type.value                             Char
_type.purpose                           Date
save_


save_dictionary.name
_definition.id                          '_dictionary.name'
_definition.update                      2000-11-10
_description.text
;
     The Common name of the dictionary.
;
_name.category_id                       dictionary
_name.attribute_id                      name
_type.container                         Single
_type.value                             Char
_type.purpose                           Idname
save_


save_dictionary.parent_name
_definition.id                          '_dictionary.parent_name'
_definition.update                      2000-11-10
_description.text
;
     The common name of the dictionary containing definitions that are
     referred to in the current dictionary.
;
_name.category_id                       dictionary
_name.attribute_id                      parent_name
_type.container                         Single
_type.value                             Char
_type.purpose                           Idname
save_


save_dictionary.parent_uri
_definition.id                          '_dictionary.parent_uri'
_definition.update                      2000-11-10
_description.text
;
     The universal resource indicator of the dictionary referred to in
     _dictionary.parent_name.
;
_name.category_id                       dictionary
_name.attribute_id                      parent_uri
_type.container                         Single
_type.value                             Char
_type.purpose                           Uri
save_


save_dictionary.uri
_definition.id                          '_dictionary.uri'
_definition.update                      2000-11-10
_description.text
;
     The universal resource indicator of this dictionary.
;
_name.category_id                       dictionary
_name.attribute_id                      uri
_type.container                         Single
_type.value                             Char
_type.purpose                           Uri
save_


save_dictionary.version
_definition.id                          '_dictionary.version'
_definition.update                      2000-11-10
_description.text
;
     A unique version identifier for the dictionary.
;
_name.category_id                       dictionary
_name.attribute_id                      version
_type.container                         Single
_type.value                             Char
_type.purpose                           Version
save_

#----------------------------------------------------------------------------

save_DICTIONARY_AUDIT
_definition.id                          dictionary_audit
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     Attributes for identifying and registering the dictionary. The items
     in this category are NOT used as attributes of individual data items.
;
_category.parent_id                     dictionary
_category_key.item_id                   '_dictionary_audit.version'
_category_mandatory.item_id             '_dictionary_audit.date'
save_


save_dictionary_audit.date
_definition.id                          '_dictionary_audit.date'
_definition.update                      2000-11-10
_description.text
;
     The date of each dictionary revision.
;
_name.category_id                       dictionary_audit
_name.attribute_id                      date
_type.container                         Single
_type.value                             Char
_type.purpose                           Date
save_


save_dictionary_audit.version
_definition.id                          '_dictionary_audit.version'
_definition.update                      2000-11-10
_description.text
;
     A unique version identifier for each revision of the dictionary.
;
_name.category_id                       dictionary_audit
_name.attribute_id                      version
_type.container                         Single
_type.value                             Char
_type.purpose                           Code
save_


save_dictionary_audit.revision
_definition.id                          '_dictionary_audit.revision'
_definition.update                      2000-11-02
_description.text
;
     A description of the revision applied for the _dictionary_audit.version.
;
_name.category_id                       dictionary_audit
_name.attribute_id                      revision
_type.container                         Single
_type.value                             Char
save_

#-----------------------------------------------------------------------------

save_DICTIONARY_VALID
_definition.id                          dictionary_valid
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-07
_description.text
;
     Data items which are used to specify the contents of definitions in
     the dictionary in terms of the _definition.scope     and the required
     and prohibited attributes.
;
_category.parent_id                     dictionary
_category_key.item_id                   '_dictionary_valid.scope'
_category_mandatory.item_id             '_dictionary_valid.attributes'
save_


save_dictionary_valid.attributes
_definition.id                          '_dictionary_valid.attributes'
_definition.update                      2000-11-07
_description.text
;
     A list of the attribute names and the attribute categories that are
     either MANDATORY or PROHIBITED for the _definition.scope value
     specified in the corresponding _dictionary_valid.scope. All
     unlisted attributes are considered optional.
 
     MANDATORY  attribute names are preceded by a "+" character.
     PROHIBITED attribute names are preceded by a "!" character.
;
_name.category_id                       dictionary_valid
_name.attribute_id                      attributes
_type.container                         Single
_type.value                             Uchar
save_


save_dictionary_valid.scope
_definition.id                          '_dictionary_valid.scope'
_definition.update                      2000-11-07
_description.text
;
     The _definition.scope code corresponding to the attribute list
     given in _dictionary_valid.attributes.
;
_name.category_id                       dictionary_valid
_name.attribute_id                      scope
_name.linked_item_id                    '_definition.scope'
_type.container                         Single
_type.value                             Char
_type.value                             Code
save_

#-----------------------------------------------------------------------------

save_DICTIONARY_XREF
_definition.id                          dictionary_xref
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     Data items which are used to cross reference other dictionaries that
     have defined the same data items. Data items in this category are NOT
     used as attributes of individual data items.
;
_category.parent_id                     dictionary
save_


save_dictionary_xref.date
_definition.id                          '_dictionary_xref.date'
_definition.update                      2000-11-02
_description.text
;
     Date of the cross-referenced dictionary.
;
_name.category_id                       dictionary_xref
_name.attribute_id                      date
_type.container                         Single
_type.value                             Char
_type.purpose                           Date
save_


save_dictionary_xref.format
_definition.id                          '_dictionary_xref.format'
_definition.update                      2000-11-02
_description.text
;
     Format of the cross referenced dictionary.
;
_name.category_id                       dictionary_xref
_name.attribute_id                      format
_type.container                         Single
_type.value                             Char
save_


save_dictionary_xref.name
_definition.id                          '_dictionary_xref.name'
_definition.update                      2000-11-02
_description.text
;
     Name of the cross referenced dictionary.
;
_name.category_id                       dictionary_xref
_name.attribute_id                      name
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------------

save_ENUMERATION
_definition.id                          enumeration
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     The attributes for restricting the values of defined data items.
;
_category.parent_id                     attributes
_category_key.relational                '_enumeration.id'
save_


save_enumeration.id
_definition.id                          '_enumeration.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       enumeration
_name.attribute_id                      id
save_


save_enumeration.default
_definition.id                          '_enumeration.default'
_definition.update                      2000-11-02
_description.text
;
     The default value for the defined item if it is not specified explicitly.
;
_name.category_id                       enumeration
_name.attribute_id                      default
_type.container                         Implied
save_


save_enumeration.range
_definition.id                          '_enumeration.range'
_definition.update                      2000-11-02
_description.text
;
     The inclusive range of values "from:to" allowed for the defined item.
;
_name.category_id                       enumeration
_name.attribute_id                      range
_type.container                         Single
_type.value                             Char
_type.purpose                           Range
save_

#-----------------------------------------------------------------------------

save_ENUMERATION_SET
_definition.id                          enumeration_set
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     Attributes of data items with pre-determined values.
;
_category.parent_id                     enumeration
_category_key.item_id                   '_enumeration_set.code'
_category_key.relational                '_enumeration_set.id'
save_


save_enumeration_set.id
_definition.id                          '_enumeration_set.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       enumeration_set
_name.attribute_id                      id
save_


save_enumeration_set.code
_definition.id                          '_enumeration_set.code'
_definition.update                      2000-11-02
_description.text
;
     A permitted code value for the defined item.
;
_name.category_id                       enumeration_set
_name.attribute_id                      code
_type.container                         Single
_type.value                             Uchar
save_


save_enumeration_set.construct
_definition.id                          '_enumeration_set.construct'
_definition.update                      2000-11-02
_description.text
;
     The construction rules of the value that the code describes.
     The construction rules conform to the regular expression
     (REGEX) specifications detailed in the IEEE document P1003.2
     Draft 11.2 Sept 1991 (ftp file '/doc/POSIX/1003.2/p121-140') with
     the *EXCEPTION* that they can include the '\n' and '\t' special
     characters.
;
_name.category_id                       enumeration_set
_name.attribute_id                      construct
_type.container                         Single
_type.value                             Char
save_


save_enumeration_set.detail
_definition.id                          '_enumeration_set.detail'
_definition.update                      2000-11-02
_description.text
;
     The meaning of the code (identified by _enumeration_set.code)
     in terms of the value of the quantity it describes.
;
_name.category_id                       enumeration_set
_name.attribute_id                      detail
_type.container                         Single
_type.value                             Char
save_


save_enumeration_set.xref_code
_definition.id                          '_enumeration_set.xref_code'
_definition.update                      2000-11-02
_description.text
;
     Code identifying the equivalent definition in the dictionary
     referenced by the DICTIONRY_XREF attributes.
;
_name.category_id                       enumeration_set
_name.attribute_id                      xref_code
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------------

save_LOOP
_definition.id                          loop
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     Attributes for looped lists.
;
_category.parent_id                     attributes
_category_key.relational                '_loop.id'
save_


save_loop.id
_definition.id                          '_loop.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       loop
_name.attribute_id                      id
save_


save_loop.level
_definition.id                          '_loop.level'
_definition.update                      2000-11-02
_description.text
;
     Specifies the level of the loop structure in which a defined
     item must reside if it used in a looped list.
;
_name.category_id                       loop
_name.attribute_id                      level
_type.container                         numb
_type.value                             Integer
_type.purpose                           Index
_enumeration.range                      1:1 
_enumeration.default                    1
save_

#----------------------------------------------------------------------------

save_METHOD
_definition.id                          method
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     Methods used for evaluating and validating defined items.
;
_category.parent_id                     attributes
_category_key.item_id                   '_method.class'
_category_key.relational                '_method.id'
save_


save_method.id
_definition.id                          '_method.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       method
_name.attribute_id                      id
save_


save_method.class
_definition.id                          '_method.class'
_definition.update                      2000-11-02
_description.text
;
     The purpose and scope of the method expression.
;
_name.category_id                       method
_name.attribute_id                      class
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
Evaluation 'method evaluates an item from related item values'
Definition 'method generates attribute value(s) in the definition'
Validation 'method compares an evaluation with existing item value'
_enumeration.default                    Evaluation
save_


save_method.expression
_definition.id                          '_method.expression'
_definition.update                      2000-11-02
_description.text
;
     The method expression for the defined item.
;
_name.category_id                       method
_name.attribute_id                      expression
_type.container                         Single
_type.value                             Char
_type.purpose                           Method
save_

#----------------------------------------------------------------------------

save_NAME
_definition.id                          name
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
     Attributes for identifying items and item categories.
;
_category.parent_id                     attributes
_category_key.relational                '_name.id'
loop_
_category_mandatory.item_id
'_name.attribute_id'
'_name.category_id'
save_


save_name.id
_definition.id                          '_name.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       name
_name.attribute_id                      id
save_


save_name.attribute_id
_definition.id                          '_name.attribute_id'
_definition.update                      2000-11-02
_description.text
;
     Identity of the attribute or extension of the defined data name
     which is unique within the category or mergable family of categories.
;
_name.category_id                       name
_name.attribute_id                      attribute_id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_name.category_id
_definition.id                          '_name.category_id'
_definition.update                      2000-11-02
_description.text
;
     Name of the category of the defined data item.
;
_name.category_id                       name
_name.attribute_id                      category_id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_name.linked_item_id
_definition.id                          '_name.linked_item_id'
_definition.update                      2000-11-02
_description.text
;
     Name of a linked item in another category which has equivalent values.
;
_name.category_id                       name
_name.attribute_id                      linked_item_id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Name
save_

#----------------------------------------------------------------------------

save_TYPE
_definition.id                          type
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
    Attributes which specify the 'typing' of data items.
;
_category.parent_id                     attributes
_category_key.relational                '_type.id'
save_


save_type.id
_definition.id                          '_type.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       type
_name.attribute_id                      id
save_


save_type.container
_definition.id                          '_type.container'
_definition.update                      2001-06-12
_description.text
;
     The simplest description of the contents of the STAR text string.
;
_name.category_id                       type
_name.attribute_id                      container
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
Single 'a single value'
Multiple 'multiple values related by boolean "|&!*" or range ":" ops'
List 'an list of values of indeterminate length'
Vector 'an fixed array of one dimension'
Matrix 'an fixed array of two dimensions or more'
Table 'an immutable array of items with "key":value format'
Implied 'implied by type.container of associated value'
_enumeration.default                    Single
save_


save_type.value
_definition.id                          '_type.value'
_definition.update                      2000-11-02
_description.text
;
     The specific 'typing' of individual data values in the defined object.
;
_name.category_id                       type
_name.attribute_id                      value
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
_enumeration_set.construct
Char 'a string of text (case-sensitive)' '[][ \n\t(_,.;:"&<>/\{}'`~!@#$%?+=*A-Za-z0-9|^-]*'
Uchar 'a string of text (case-insensitive)' '[][ \n\t(_,.;:"&<>/\{}'`~!@#$%?+=*A-Za-z0-9|^-]*'
Integer 'an integer number' -?[0-9]+
Float 'a floating-point real number' -?(([0-9]+)|([0-9]*[.][0-9]+))([(][0-9]+[)])?([eE][+-]?[0-9]+)?
Real 'a floating-point real number' -?(([0-9]+)|([0-9]*[.][0-9]+))([(][0-9]+[)])?([eE][+-]?[0-9]+)?
Imag 'a floating-point imaginary number "Real[jJ]"' ' '
Complex 'a complex number of the form "Real+Imag"' ' '
Binary 'a binary number preceded by "0b"' ' '
Hexadecimal 'a hexadecimal number preceded by "0x"' ' '
Octal 'a hexadecimal number preceded by "0o"' ' '
_enumeration.default                    Char
save_


save_type.purpose
_definition.id                          '_type.purpose'
_definition.update                      2000-11-02
_description.text
;
     The structure and purpose of the data value.
;
_name.category_id                       type
_name.attribute_id                      purpose
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
_enumeration_set.construct
Implied 'data value implied soley by the VALUE and CONTAINER typing' ' '
Name 'a defined data item name (always case insensitive)' '_[^\t\n "]+'
Idname 'an defined identifier or name component' '_A-Za-z0-9]+'
Code 'value or values defined in an enumerated list' '_,.;:"&<>/\{}'`~!@#$%A-Za-z0-9*|+-]*'
y/n 'the flag with values of "yes", "y", "no" or "n".' ' '
Date 'ISO date format yyyy-mm-dd' [0-9][0-9][0-9][0-9]-[0-9]?[0-9]-[0-9][0-9]
Index 'integer which is member of a defined sequential set' ' '
Import
;
                   a string containing the name of a definition; a definition
                   name preceded by "<code>:" where the code represents an
                   externally defined URI; or a definition name preceded by
                   "<URI>:"
;
' '
Uri 'an universal resource indicator string specifying a file' ' '
Version 'version digit string of the form <major>.<version>.<update>' ' '
Count 'positive or zero integer' ' '
Dimension 'integer dimensions of an array in square brackets' ' '
Range 'An inclusive range of numerical values min:max' ' '
Method 'a method expression for evaluating the defined item' '[][ \n\t(_,.;:"&<>/\{}'`~!@#$%?+=*A-Za-z0-9|^-]*'
Measurement
;
                   a number which can have a standard uncertainty value
                     either
                           1) appended as integers in parentheses at the
                              precision of the trailing digits, or
                           2) as a separate item with the same name as
                              defined item but with a trailing underscore su.
;
' '
_enumeration.default                    Implied
save_

#-----------------------------------------------------------------------------

save_TYPE_ARRAY
_definition.id                          type_array
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
    The attributes of array lists.
;
_category.parent_id                     type
_category_key.relational                '_type_array.id'
save_


save_type_array.id
_definition.id                          '_type_array.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       type_array
_name.attribute_id                      id
save_


save_type_array.class
_definition.id                          '_type_array.class'
_definition.update                      2000-11-02
_description.text
;
     The nature of the array.
;
_name.category_id                       type_array
_name.attribute_id                      class
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
Asymmetric 'no symmetry constraints'
Diagonal 'a diagonal matrix'
Symmetric 'a symmetric matrix'
Anti_Symmetric 'an anti-symmetric matrix'
Upper_Triangular 'a matrix with lower triangular zero elements'
Lower_Triangular 'a matrix with upper triangular zero elements'
_enumeration.default                    Asymmetric
save_


save_type_array.dimension
_definition.id                          '_type_array.dimension'
_definition.update                      2000-11-02
_description.text
;
     The dimensions of the list array bounded by square brackets.
     Each dimension may be expressed simply as an integer giving
     the maximum index permitted (the minimum is assumed to be 1).
     Alternately, each dimension may be entered in the form:
     <min_index>:<max_index>
;
_name.category_id                       type_array
_name.attribute_id                      dimension
_type.container                         Single
_type.value                             Char
_type.purpose                           Dimension
loop_
_description_example.case
_description_example.detail
[3,3] '3x3 Matrix'
[6] '6 element Tuple'
[4[2]] 'Tuple of four Tuples of 2 elements'
save_


save_type_array.order
_definition.id                          '_type_array.order'
_definition.update                      2000-11-02
_description.text
;
     The number of elements in each order of the list array.
;
_name.category_id                       type_array
_name.attribute_id                      order
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
Column_Major 'first dimension list is by column'
Row_Major 'first dimension list is by row'
_enumeration.default                    Row_Major
save_

#----------------------------------------------------------------------------

save_UNITS
_definition.id                          units
_definition.scope                       Category
_definition.class                       Attribute
_definition.update                      2000-11-02
_description.text
;
    The attributes for specifying units of measure.
;
_category.parent_id                     attributes
_category_key.relational                '_units.id'
save_


save_units.id
_definition.id                          '_units.id'
_definition.import_id                   '_generic.ddl_id'
_name.category_id                       units
_name.attribute_id                      id
save_


save_units.code
_definition.id                          '_units.code'
_definition.update                      2000-11-02
_definition.import_id                   GLOBAL:_codes.units_code
_description.text
;
     A code which identifies the units of measurement.
;
_name.category_id                       units
_name.attribute_id                      code
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
save_

#============================================================================
#
#   Attributes  and data to be imported into local definitions.
#
#============================================================================

save_IMPORT_DDL
_definition.id                          import_ddl
_definition.scope                       Category
_definition.class                       Transient
_definition.update                      2000-11-02
_description.text
;
     The MAJOR CATEGORY of definitions used to specify attributes which are
     imported into other items defined in the DDL dictionary.
;
_category.parent_id                     ddl
save_

#-------------------------------------------------------------------------------

save_GENERIC
_definition.id                          generic
_definition.scope                       Category
_definition.class                       Transient
_definition.update                      2000-11-02
_description.text
;
     Definitions used to specify generic attributes which are imported into
     items defined in this dictionary.
;
_category.parent_id                     import_ddl
save_


save_generic.ddl_id
_definition.id                          '_generic.ddl_id'
_definition.class                       Registration
_description.text
;
     Identity name of the ddl category used to internally reference the
     items defined in a DDL category.
;
_name.category_id                       generic
_name.attribute_id                      ddl_id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           IdName
save_

#----------------------------------------------------------------------------

save_CODES
_definition.id                          codes
_definition.scope                       Category
_definition.class                       Transient
_definition.update                      2000-11-02
_description.text
;
     Lists of enumeration codes which are imported into items
     defined in the dictionary.
;
_category.parent_id                     import_ddl
save_

#----------------------------------------------------------------------------

save_codes.units_code
_definition.id                          '_codes.units_code'
_definition.update                      2000-11-02
_description.text
;
     Enumeration data imported into the _units.code attribute.
;
_name.category_id                       codes
_name.attribute_id                      units_code
loop_
_enumeration_set.code
_enumeration_set.detail
centimetres 'length    'centimetres (meters * 10^( -2))''
millimetres 'length    'millimetres (meters * 10^( -3))''
nanometres 'length    'nanometres  (meters * 10^( -9))''
angstroms 'length    'angstroms   (meters * 10^(-10))''
picometres 'length    'picometres  (meters * 10^(-12))''
femtometres 'length    'femtometres (meters * 10^(-15))''
reciprocal_centimetres 'per_length 'reciprocal centimetres (meters * 10^( -2)^-1)''
reciprocal_millimetres 'per_length 'reciprocal millimetres (meters * 10^( -3)^-1)''
reciprocal_nanometres 'per-length 'reciprocal nanometres  (meters * 10^( -9)^-1)''
reciprocal_angstroms 'per-length 'reciprocal angstroms   (meters * 10^(-10)^-1)''
reciprocal_picometres 'per-length 'reciprocal picometres  (meters * 10^(-12)^-1)''
nanometre_squared 'length_squared 'nanometres squared (meters * 10^( -9))^2''
angstrom_squared 'length_squared 'angstroms squared  (meters * 10^(-10))^2''
8pi_angstroms_squared 'length_squared '8pi^2 * angstroms squared (meters * 10^(-10))^2''
picometre_squared 'length_squared 'picometres squared (meters * 10^(-12))^2''
nanometre_cubed 'length_cubed 'nanometres cubed (meters * 10^( -9))^3''
angstrom_cubed 'length_cubed 'angstroms cubed  (meters * 10^(-10))^3''
picometre_cubed 'length_cubed 'picometres cubed (meters * 10^(-12))^3''
kilopascals 'pressure      'kilopascals''
gigapascals 'pressure      'gigapascals''
hours 'time      'hours''
minutes 'time      'minutes''
seconds 'time      'seconds''
microseconds 'time      'microseconds''
degrees 'angle      'degrees (of arc)''
degree_per_minute 'rotation_per_time  'degrees (of arc) per minute''
celsius 'temperature     'degrees (of temperature) Celsius''
kelvins 'temperature     'degrees (of temperature) Kelvin''
electrons 'electrons              'electrons''
electron_squared 'electrons-squared    'electrons squared''
electron_per_nanometres_cubed 'electron-density 'electrons per nanometres cubed (meters * 10^( -9))^3''
electron_per_angstroms_cubed 'electron-density 'electrons per angstroms  cubed (meters * 10^(-10))^3''
electron_per_picometres_cubed 'electron-density 'electrons per picometres cubed (meters * 10^(-12))^3''
kilowatts 'power       'kilowatts''
milliamperes 'current     'milliamperes''
kilovolts 'emf         'kilovolts''
arbitrary 'arbitary    'arbitrary system of units''
save_

#============================================================================
#
#  This section contains the dictionary AUDIT history information.
#
#============================================================================

save_AUDIT_DDL
_definition.id                          audit_ddl
_definition.scope                       Category
_definition.class                       Registration
_definition.update                      2000-10-02
_description.text
;
     The audit record of the DDL dictionary.
;
_category.parent_id                     ddl
loop_
_dictionary_audit.version
_dictionary_audit.date
_dictionary_audit.revision
3.0 1999-04-06
;
    Initial draft of DDL3 based on attributes from DDL1.4 and DDL2.1.1.
;
3.0.1 1999-05-06
;
    Added new method attributes and enumeration LIST values
;
3.0.2 1999-05-11
;
    Repacked and redefined some definition and dictionary attributes
;
3.0.3 1999-05-12
;
    Introduced category.level etc. attributes and rearranged categories
;
3.0.4 1999-05-18
;
    Removed category.level, linked.parent, linked.child, category.child_id
    Changed related.function to include "Parent_Key", "Linked_Key",
    "Linked_Values" and "Linked_Array" codes.
;
3.0.5 1999-05-22
;
    Access keys in category families are inherited. Remove "Linked_Values"
    for related.function.
;
3.0.6 1999-05-24
;
    Add "Su_Implicit" code to related.function.
;
3.0.7 1999-05-25
;
    Further simplifications to the syntax.
;
3.0.8 1999-05-27
;
    Change _definition.class code DATA_ITEM to ITEM_DEFINITION
;
3.0.9 1999-06-10
;
    Add "List" to _type_array.class enumerations.
;
3.0.10 1999-06-11
;
    Add various codes to the enumeration lists.
;
3.0.11 1999-06-22
;
    Convert all enumeration list data names.
;
3.0.12 1999-06-28
;
    Recaste the TYPE attributes and enumerations.
;
3.0.13 1999-07-05
;
    Change "pattern" to "function" for TYPE attributes.
;
3.0.14 1999-07-09
;
    Change "string" to "container" for TYPE attributes.
    Change codes for definition.scope and definition.class
;
3.0.15 1999-11-26
;
    Add the _definition.update attribute.
;
3.0.16 2000-02-15
;
    Change the names of the files to reflect prototype specifications.
;
3.0.17 2000-04-17
;
    Add the attributes description.compact and description.abbreviated.
;
3.0.18 2000-05-19
;
    Add the definition class TRANSIENT for FUNCTION definitions.
;
3.0.19 2000-06-06
;
    Change the definition scope GROUP to Category.
    Change the definition scope ITEM to SINGLE.
    Add the definition scope COSET for common definitions.
    Change type.function to type.purpose.
;
3.0.20 2000-06-07
;
    Add the definition for category.coset_id
    Add the definition for item.coset_id
    Added the Equivalent code to related.function
;
3.1.00 2000-06-12
;
    Reorganised families into category groupings ATTRIBUTES and ENUMERATION
;
3.1.01 2000-06-20
;
    Inserted possible method validation scripts
;
3.1.02 2000-06-24
;
    MAJOR modifications and additions following discussions with JW.
;
3.1.03 2000-06-26
;
    Changes to MODEL attributes and many other changes.
;
3.1.04 2000-06-28
;
    Version agreed upon up to JW's return to Rutgers.
;
3.1.05 2000-06-29
;
    In list_data.method_class change ENUMERATION to EVALUATION.
;
3.1.06 2000-07-03
;
    Corrections from running dREL 1.0.3.
;
3.1.07 2000-07-11
;
    Add the attribute enumeration.dot.
;
3.1.08 2000-09-13
;
    Remove the attribute enumeration.dot.
;
3.1.09 2000-10-09
;
    Add the XREF definitions.
    In type_purpose change 'From:To' to 'Range'; 'Code' to 'State'.
    In type_container add the enumeration 'Multiple'
;
3.2.00 2000-11-02
;
    MAJOR revision and simplification of ALL definitions. Blame PMR!
;
3.2.01 2000-11-03
;
    Move the enumeration lists back into their respective definitions.
;
3.2.02 2000-11-06
;
    Change "State" back to "Code".
;
3.2.03 2000-11-07
;
    Add category_key.relational which gives the relational key used in DDL2
;
3.2.04 2000-11-10
;
    MAJOR changes to a number of attributes and categories.
;
3.2.05 2000-11-13
;
    Introduced _definition.import_id.
;
3.2.06 2000-11-24
;
    Change the _method.class enumeration state "Units" to "Definition".
;
3.2.07 2001-08-30
;
    Change "category.parent_id" to "category.family_id".
;
3.2.08 2001-09-03
;
    Change "alias.dictionary_class" to "alias.dictionary_uri".
    Change the "dictionary.class" states to "Attribute" and "Instance"
;
3.2.09 2001-09-26
;
    Change "category.family_id" to "category.parent_id".
;
3.2.10 2001-10-01
;
    Remove the definition of "alias.dictionary_version".
;
3.2.11 2001-10-02
;
    Converted reference to "codes.unit_code" to "codes.units_code".
;
3.2.12 2002-02-02
;
    Remove key from category DEFINITION.
;
save_

