##############################################################################
#                                                                            #
#                      CIF CORE DICTIONARY                                   #
#                                                                            #
##############################################################################


data_CORE_STRUCTURAL


save_CORE
_dictionary.name                        CORE_STRUCTURAL
_dictionary.version                     3.4.14
_dictionary.date                        2002-02-11
_dictionary.uri                         www.crystal.uwa.edu.au/~syd/dic/core_3.dic
_definition.id                          core
_definition.scope                       Dictionary
_definition.class                       Registration
_description.text
;
     CIF CORE DICTIONARY using the DDL PROTO and dREL methods
 
     This dictionary contains the definitions of data items that
     are considered CORE to structural studies in crystallography.
 
     This dictionary has been defined specifically to develop and
     test the dREL expression language parser. It uses attributes
     which are defined in the dictionary "ddl_3.dic". Neither this
     nor the DDL dictionary have been approved by the IUCr COMCIFS
     body and MUST NOT be distributed.
 
 
     CORE dictionary has the following major categories of information.
     |
     |__ CRYSTAL      (most pre-diffraction information)
     |
     |__ DIFFRACTION  (most diffraction information)
     |
     |__ STRUCTURE    (atom site and refinement information)
     |
     |__ MODEL        (interpretation of the structure information)
     |
     |__ PUBLICATION  (items used in publication and archiving)
     |
     |
     |
     |__ TRANSIENT_CORE (transient information imported into other definitions)
     |
     |__ AUDIT_CORE     (audit record of the core dictionary)
 
;
loop_
_dictionary_valid.scope
_dictionary_valid.attributes
Dictionary
;
                + _definition.id   + _definition.scope
                + _definition.class
                + _dictionary.name + _dictionary.version
                + _dictionary.date + _dictionary.uri
                ! ALIAS ! CATEGORY ! ENUMERATION ! LOOP ! NAME ! TYPE ! UNITS
                ! METHOD
;
Category
;
                + _definition.id  +  _definition.scope  +  _definition.class
                + _category.parent_id
                ! ALIAS ! DICTIONARY ! ENUMERATION ! LOOP ! NAME ! TYPE ! UNITS
;
Item
;
                + _definition.id + _name.attribute_id + _name.category_id
                ! DICTIONARY
;
save_

#============================================================================

save_CRYSTAL
_definition.id                          crystal
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The MAJOR CATEGORY of data items for pre-diffraction information
     used in crystallograhic structure studies.
;
_description.compact                    CrystalData
_category.parent_id                     core
save_


save_DIFFRACTION
_definition.id                          diffraction
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The MAJOR CATEGORY of data items relating to diffraction information.
;
_description.compact                    DiffractionData
_category.parent_id                     core
save_


save_STRUCTURE
_definition.id                          structure
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The MAJOR CATEGORY of data items wich specify the atomic site
     information determined from the diffraction data.
;
_description.compact                    StructureData
_category.parent_id                     core
save_


save_MODEL
_definition.id                          model
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The MAJOR CATEGORY of data items wich specify the molecular
     model information determined from the structural data.
;
_description.compact                    ModelData
_category.parent_id                     core
save_


save_PUBLICATION
_definition.id                          publication
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The MAJOR CATEGORY of data items wich specify the information
     prepared for publication and archiving the structural study.
;
_description.compact                    PublicationData
_category.parent_id                     core
save_

#============================================================================
#
#   Data items are grouped in CATEGORIES, which are listed alphabetically.
#
#============================================================================

save_ATOM_SITE
_definition.id                          atom_site
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe atomic site information
     used in crystallograhic structure studies.
;
_description.compact                    AtomSiteList
_category.parent_id                     structure
_category_key.item_id                   '_atom_site.label'
save_


save_atom_site.adp_type
_definition.id                          '_atom_site.adp_type'
_definition.update                      2000-11-03
_alias.definition_id                    '_atom_site.thermal_displace_type'
_description.text
;
     Code for type of atomic displacement parameters used for the site.
;
_description.compact                    AtomSiteAdpType
_name.category_id                       atom_site
_name.attribute_id                      adp_type
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
Uani 'anisotropic Uij'
Uiso 'isotropic U'
Uovl 'overall U'
Umpe 'multipole expansion U'
Bani 'anisotropic Bij'
Biso 'isotropic B'
Bovl 'overall B'
_enumeration.default                    Uiso
save_


save_atom_site.attached_hydrogens
_definition.id                          '_atom_site.attached_hydrogens'
_definition.update                      2000-11-03
_description.text
;
     The number of hydrogen atoms attached to the atom at this site
     excluding any H atoms for which coordinates (measured or calculated)
     are given.
;
_description.compact                    AtomSiteAttachedH
_name.category_id                       atom_site
_name.attribute_id                      attached_hydrogens
_type.container                         Single
_type.value                             Integer
_enumeration.range                      0:8 
_enumeration.default                    0
loop_
_description_example.case
_description_example.detail
2 'water oxygen'
1 'hydroxyl oxygen'
4 'ammonium nitrogen'
save_


save_atom_site.B_equiv_geom_mean
_definition.id                          '_atom_site.B_equiv_geom_mean'
_definition.update                      2000-11-03
_description.text
;
     Equivalent isotropic atomic displacement parameter, B(equiv),
     in angstroms squared, calculated as the geometric mean of
     the anisotropic atomic displacement parameters.
 
                 B(equiv) = (B~i~ B~j~ B~k~)^1/3^
 
     B~n~  = the principal components of the orthogonalised B^ij^
 
     The IUCr Commission on Nomenclature recommends against the use
     of B for reporting atomic displacement parameters. U, being
     directly proportional to B, is preferred.
;
_description.compact                    AtomSiteBisoMean
_name.category_id                       atom_site
_name.attribute_id                      B_equiv_geom_mean
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             angstroms_squared
save_


save_atom_site.B_iso_or_equiv
_definition.id                          '_atom_site.B_iso_or_equiv'
_definition.update                      2000-11-03
_description.text
;
     Isotropic atomic displacement parameter, or equivalent isotropic
     atomic displacement parameter, B(equiv), in angstroms squared,
     calculated from anisotropic temperature factor parameters.
 
         B(equiv) = (1/3) sum~i~[sum~j~(B^ij^ a*~i~ a*~j~ a~i~ a~j~)]
 
     a     = the real-space cell lengths
     a*    = the reciprocal-space cell lengths
     B^ij^ = 8 pi^2^ U^ij^
     Ref: Fischer, R. X. & Tillmanns, E. (1988). Acta Cryst. C44, 775-776.
 
     The IUCr Commission on Nomenclature recommends against the use
     of B for reporting atomic displacement parameters. U, being
     directly proportional to B, is preferred.
;
_description.compact                    AtomSiteBisoEquiv
_name.category_id                       atom_site
_name.attribute_id                      B_iso_or_equiv
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             angstroms_squared
save_


save_atom_site.calc_attached_atom
_definition.id                          '_atom_site.calc_attached_atom'
_definition.update                      2000-11-03
_description.text
;
     The _atom_site.label of the atom site to which the 'geometry-
     calculated' atom site is attached.
;
_description.compact                    AtomSiteParentAtom
_name.category_id                       atom_site
_name.attribute_id                      calc_attached_atom
_name.linked_item_id                    '_atom_site.label'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Label
save_


save_atom_site.calc_flag
_definition.id                          '_atom_site.calc_flag'
_definition.update                      2000-11-03
_description.text
;
     A standard code to signal if the site coordinates have been
     determined from the intensities or calculated from the geometry
     of surrounding sites, or have been assigned dummy coordinates.
;
_description.compact                    AtomSiteCalcStatus
_name.category_id                       atom_site
_name.attribute_id                      calc_flag
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
d 'determined from diffraction measurements'
calc 'calculated from molecular geometry'
c 'abbreviation for "calc"'
dum 'dummy site with meaningless coordinates'
_enumeration.default                    d
save_


save_atom_site.Cartn_xyz
_definition.id                          '_atom_site.Cartn_xyz'
_definition.update                      2000-11-03
_description.text
;
     Vector of Cartesian (orthogonal angstrom) atom site coordinates.
;
_description.compact                    AtomSiteCartnXyz
_name.category_id                       atom_site
_name.attribute_id                      Cartn_xyz
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
    With a  as  atom_site
 
    _atom_site.Cartn_xyz <- Vector ( [a.Cartn_x, a.Cartn_y, a.Cartn_z] )
;
save_


save_atom_site.Cartn_x
_definition.id                          '_atom_site.Cartn_x'
_definition.import_id                   '_generic.Cartn_coord'
_name.category_id                       atom_site
_name.attribute_id                      Cartn_x
save_


save_atom_site.Cartn_y
_definition.id                          '_atom_site.Cartn_y'
_definition.import_id                   '_generic.Cartn_coord'
_name.category_id                       atom_site
_name.attribute_id                      Cartn_y
save_


save_atom_site.Cartn_z
_definition.id                          '_atom_site.Cartn_z'
_definition.import_id                   '_generic.Cartn_coord'
_name.category_id                       atom_site
_name.attribute_id                      Cartn_z
save_


save_atom_site.chemical_conn_number
_definition.id                          '_atom_site.chemical_conn_number'
_definition.update                      2000-11-03
_description.text
;
     This number links an atom site to the chemical connectivity list.
     It must match a number specified by _chemical_conn_atom.number.
;
_description.compact                    AtomSiteChemConnLink
_name.category_id                       atom_site
_name.attribute_id                      chemical_conn_number
_name.linked_item_id                    '_chemical_conn_atom.number'
_type.container                         Single
_type.value                             Integer
_enumeration.range                      1:1 
save_


save_atom_site.constraints
_definition.id                          '_atom_site.constraints'
_definition.update                      2000-11-03
_description.text
;
     A description of the constraints applied to parameters at this
     site during refinement. See also _atom_site.refinement_flags
     and _refine_ls.number_constraints.
;
_description.compact                    AtomSiteConstraints
_name.category_id                       atom_site
_name.attribute_id                      constraints
_type.container                         Single
_type.value                             Uchar
_description_example.case               pop=1.0-pop(Zn3)
save_


save_atom_site.description
_definition.id                          '_atom_site.description'
_definition.update                      2000-11-03
_description.text
;
     A description of special aspects of this site. See also
     _atom_site.refinement_flags.
;
_description.compact                    AtomSiteDetails
_name.category_id                       atom_site
_name.attribute_id                      description
_type.container                         Single
_type.value                             Char
_description_example.case               'Ag/Si disordered'
save_


save_atom_site.disorder_assembly
_definition.id                          '_atom_site.disorder_assembly'
_definition.update                      2000-11-03
_description.text
;
     A code which identifies a cluster of atoms that show long range
     positional disorder but are locally ordered. Within each such
     cluster of atoms, _atom_site.disorder_group is used to identify
     the sites that are simultaneously occupied. This field is only
     needed if there is more than one cluster of disordered atoms
     showing independent local order.
;
_description.compact                    AtomSiteDisorderCode
_name.category_id                       atom_site
_name.attribute_id                      disorder_assembly
_type.container                         Single
_type.value                             Uchar
loop_
_description_example.case
_description_example.detail
A 'disordered methyl assembly with groups 1 and 2'
B 'disordered sites related by a mirror'
S 'disordered sites independent of symmetry'
save_


save_atom_site.disorder_group
_definition.id                          '_atom_site.disorder_group'
_definition.update                      2000-11-03
_description.text
;
     A code that identifies a group of positionally disordered atom
     sites that are locally simultaneously occupied. Atoms that are
     positionally disordered over two or more sites (e.g. the H
     atoms of a methyl group that exists in two orientations) can
     be assigned to two or more groups. Sites belonging to the same
     group are simultaneously occupied, but those belonging to
     different groups are not. A minus prefix (e.g. "-1") is used to
     indicate sites disordered about a special position.
;
_description.compact                    AtomSiteDisorderGroup
_name.category_id                       atom_site
_name.attribute_id                      disorder_group
_type.container                         Single
_type.value                             Uchar
loop_
_description_example.case
_description_example.detail
2 'unique disordered site in group 2'
-1 'symmetry-independent disordered site'
save_


save_atom_site.fract_xyz
_definition.id                          '_atom_site.fract_xyz'
_definition.update                      2000-11-03
_description.text
;
     Vector of atom site coordinates projected onto the crystal unit
     cell as fractions of the cell lengths.
;
_description.compact                    AtomSiteFractXyz
_name.category_id                       atom_site
_name.attribute_id                      fract_xyz
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
     With a  as  atom_site
 
     atom_site.fract_xyz <- Vector ( [a.fract_x, a.fract_y, a.fract_z] )
;
save_


save_atom_site.fract_x
_definition.id                          '_atom_site.fract_x'
_definition.import_id                   '_generic.fract_coord'
_name.category_id                       atom_site
_name.attribute_id                      fract_x
save_


save_atom_site.fract_y
_definition.id                          '_atom_site.fract_y'
_definition.import_id                   '_generic.fract_coord'
_name.category_id                       atom_site
_name.attribute_id                      fract_y
save_


save_atom_site.fract_z
_definition.id                          '_atom_site.fract_z'
_definition.import_id                   '_generic.fract_coord'
_name.category_id                       atom_site
_name.attribute_id                      fract_z
save_


save_atom_site.label
_definition.id                          '_atom_site.label'
_definition.import_id                   '_generic.atom_site_label'
_description.compact                    AtomSiteLabel
_name.category_id                       atom_site
_name.attribute_id                      label
save_


save_atom_site.label_component_0
_definition.id                          '_atom_site.label_component_0'
_definition.import_id                   '_generic.label_component'
_name.category_id                       atom_site
_name.attribute_id                      label_component_0
save_


save_atom_site.label_component_1
_definition.id                          '_atom_site.label_component_1'
_definition.import_id                   '_generic.label_component'
_name.category_id                       atom_site
_name.attribute_id                      label_component_1
save_


save_atom_site.label_component_2
_definition.id                          '_atom_site.label_component_2'
_definition.import_id                   '_generic.label_component'
_name.category_id                       atom_site
_name.attribute_id                      label_component_2
save_


save_atom_site.label_component_3
_definition.id                          '_atom_site.label_component_3'
_definition.import_id                   '_generic.label_component'
_name.category_id                       atom_site
_name.attribute_id                      label_component_3
save_


save_atom_site.label_component_4
_definition.id                          '_atom_site.label_component_4'
_definition.import_id                   '_generic.label_component'
_name.category_id                       atom_site
_name.attribute_id                      label_component_4
save_


save_atom_site.label_component_5
_definition.id                          '_atom_site.label_component_5'
_definition.import_id                   '_generic.label_component'
_name.category_id                       atom_site
_name.attribute_id                      label_component_5
save_


save_atom_site.label_component_6
_definition.id                          '_atom_site.label_component_6'
_definition.import_id                   '_generic.label_component'
_name.category_id                       atom_site
_name.attribute_id                      label_component_6
save_


save_atom_site.occupancy
_definition.id                          '_atom_site.occupancy'
_definition.update                      2000-11-03
_description.text
;
     The fraction of the atom type present at this site.
     The sum of the occupancies of all the atom types at this site
     may not significantly exceed 1.0 unless it is a dummy site. The
     value must lie in the 99.97% Gaussian confidence interval
     -3u =< x =< 1 + 3u. The _enumeration.range of 0.0:1.0 is thus
     correctly interpreted as meaning (0.0 - 3u) =< x =< (1.0 + 3u).
;
_description.compact                    AtomSiteOccupancy
_name.category_id                       atom_site
_name.attribute_id                      occupancy
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:1.0 
_enumeration.default                    1.0
save_


save_atom_site.refinement_flags
_definition.id                          '_atom_site.refinement_flags'
_definition.update                      2000-11-03
_description.text
;
     A concatenated series of single-letter codes which indicate the
     refinement restraints or constraints applied to this site.
;
_description.compact                    AtomSiteRefineFlags
_name.category_id                       atom_site
_name.attribute_id                      refinement_flags
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
S 'special position constraint on site'
G 'rigid group refinement of site'
R 'riding-atom site attached to non-riding atom'
D 'distance or angle restraint on site'
T 'thermal displacement constraints'
U 'Uiso or Uij restraint (rigid bond)'
P 'partial occupancy constraint'
save_


save_atom_site.restraints
_definition.id                          '_atom_site.restraints'
_definition.update                      2000-11-03
_description.text
;
     A description of restraints applied to specific parameters at
     this site during refinement. See also _atom_site.refinement_flags
     and _refine_ls.number_restraints.
;
_description.compact                    AtomSiteRestraints
_name.category_id                       atom_site
_name.attribute_id                      restraints
_type.container                         Single
_type.value                             Uchar
_description_example.case               'restrained to planar ring'
save_


save_atom_site.symmetry_multiplicity
_definition.id                          '_atom_site.symmetry_multiplicity'
_definition.update                      2000-11-03
_description.text
;
     The site multiplicity is the number of times that a site is
     repeated in a cell due to the space-group symmetry. For sites
     related by the general symmetry equivalent this number will be
     the total number of unique symmetry positions in the space group.
     For special sites this will be a lesser number. The permitted
     numbers for each space group are given in given in International
     Tables for Crystallography, Vol. A (1987).
;
_description.compact                    AtomSiteMultiplicity
_name.category_id                       atom_site
_name.attribute_id                      symmetry_multiplicity
_type.container                         Single
_type.value                             Integer
_enumeration.range                      1:192 
_method.expression
;
     With  a  as  atom_site
 
        mul  <-  1
        xyz  <-  a.fract_xyz
 
          Loop  s  as  symmetry_equiv  {
 
             sxyz  <-  s.R * xyz + s.T
             diff  <-  Mod( 99.5 + xyz - sxyz, 1.0) - 0.5
 
             If ( Norm ( diff ) > 0.1 ) mul +<- 1
       }
        _atom_site.symmetry_multiplicity <- mul
;
save_


save_atom_site.type_symbol
_definition.id                          '_atom_site.type_symbol'
_definition.update                      2000-11-03
_description.text
;
     A code to identify the atom specie(s) occupying this site.
     This code must match a corresponding _atom_type.symbol. The
     specification of this code is optional if component_0 of the
     _atom_site.label is used for this purpose. See _atom_type.symbol.
;
_description.compact                    AtomSiteTypeSymbol
_name.category_id                       atom_site
_name.attribute_id                      type_symbol
_name.linked_item_id                    '_atom_type.symbol'
_type.container                         Single
_type.value                             Uchar
loop_
_description_example.case
Cu
Cu2+
dummy
S-
H*
H(SDS)
_method.expression
;
          _atom_site.type_symbol  <-  AtomType ( _atom_site.label )
;
save_


save_atom_site.U_equiv_geom_mean
_definition.id                          '_atom_site.U_equiv_geom_mean'
_definition.update                      2000-11-03
_description.text
;
     Equivalent isotropic atomic displacement parameter, U(equiv),
     in angstroms squared, calculated as the geometric mean of
     the anisotropic atomic displacement parameters.
 
                U(equiv) = (U~i~ U~j~ U~k~)^1/3^
 
     U~n~ = the principal components of the orthogonalised U^ij^
;
_description.compact                    AtomSiteUisoMean
_name.category_id                       atom_site
_name.attribute_id                      U_equiv_geom_mean
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             angstroms_squared
save_


save_atom_site.U_iso_or_equiv
_definition.id                          '_atom_site.U_iso_or_equiv'
_definition.update                      2000-11-03
_description.text
;
     Isotropic atomic displacement parameter, or equivalent isotropic
     atomic  displacement parameter, U(equiv), in angstroms squared,
     calculated from anisotropic atomic displacement  parameters.
 
        U(equiv) = (1/3) sum~i~[sum~j~(U^ij^ a*~i~ a*~j~ a~i~ a~j~)]
 
     a  = the real-space cell lengths
     a* = the reciprocal-space cell lengths
     Ref: Fischer, R. X. & Tillmanns, E. (1988). Acta Cryst. C44, 775-776.
;
_description.compact                    AtomSiteUisoEquiv
_name.category_id                       atom_site
_name.attribute_id                      U_iso_or_equiv
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             angstroms_squared
save_


save_atom_site.Wyckoff_symbol
_definition.id                          '_atom_site.Wyckoff_symbol'
_definition.update                      2000-11-03
_description.text
;
     The Wyckoff symbol (letter) as listed in the space-group section
     of International Tables for Crystallography, Vol. A (1987).
;
_description.compact                    AtomSiteWyckoff
_name.category_id                       atom_site
_name.attribute_id                      Wyckoff_symbol
_type.container                         Single
_type.value                             Uchar
save_

#----------------------------------------------------------------------------

save_ATOM_SITE_ANISO
_definition.id                          atom_site_aniso
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe atomic site information
     used in crystallograhic structure studies.
;
_description.compact                    AtomSiteAnisoList
_category.parent_id                     atom_site
_category.join_set_id                   atom_site
_category_key.item_id                   '_atom_site_aniso.label'
save_


save_atom_site_aniso.label
_definition.id                          '_atom_site_aniso.label'
_definition.update                      2000-11-03
_description.text
;
     The atom site label used if the anisotropic atomic displacement
     parameters are stored as a separate list.
;
_description.compact                    AtomSiteAnisoLabel
_name.category_id                       atom_site_aniso
_name.attribute_id                      label
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Label
save_


save_atom_site_aniso.ratio
_definition.id                          '_atom_site_aniso.ratio'
_definition.update                      2000-11-03
_description.text
;
     Ratio of the maximum to minimum eigenvalues of the atomic
     displacement (thermal) ellipsoids.
;
_description.compact                    AtomSiteAnisoRatio
_name.category_id                       atom_site_aniso
_name.attribute_id                      ratio
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      1.0:1.0 
save_


save_atom_site_aniso.type_symbol
_definition.id                          '_atom_site_aniso.type_symbol'
_definition.update                      2000-11-03
_description.text
;
     This _atom_type.symbol code links the anisotropic atom parameters to
     the atom type data associated with this site and must match one of
     the _atom_type.symbol codes in this list.
;
_description.compact                    AtomSiteAnisoTypeSymbol
_name.category_id                       atom_site_aniso
_name.attribute_id                      type_symbol
_name.linked_item_id                    '_atom_type.symbol'
_type.container                         Single
_type.value                             Uchar
_method.expression
;
     _atom_site_aniso.type_symbol  <-  AtomType ( _atom_site_aniso.label )
;
save_


save_atom_site_aniso.matrix_beta
_definition.id                          '_atom_site_aniso.matrix_beta'
_definition.update                      2000-11-03
_description.text
;
     The symmetric anisotropic atomic displacement matrix beta(IJ)
     appears in a structure factor expression as:
 
     t = exp -       ( beta11 h h + ............ 2 beta23 k l )
 
     It is related to the adp matrices U(IJ) and B(IJ) as follows:
 
     t = exp -2pi**2 ( U11    h h a* a* + ...... 2 U23    k l b* c* )
     t = exp - 0.25  ( B11    h h a* a* + ...... 2 B23    k l b* c* )
;
_description.compact                    AtomSiteAnisoBetaIJ
_name.category_id                       atom_site_aniso
_name.attribute_id                      matrix_beta
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.class                       Symmetric
_type_array.dimension                   [3,3]
_method.expression
;
     With  a  as  atom_site_aniso
 
     If      (a.adp_type == 'uani')  {
 
         C <-  _cell_reciprocal.convert_U_to_beta
         B <-  C * _atom_site_aniso.matrix_U * C
     }
     Else If (a.adp_type == 'bani')  {
 
         C <-  _cell_reciprocal.convert_U_to_beta / (2.828427 * Pi)
         B <-  C * _atom_site_aniso.matrix_B * C
     }
     Else                                    {
         If (a.adp_type == 'uiso')  b  <- a.U_iso_or_equiv
         Else                       b  <- a.B_iso_or_equiv / (8 * Pi**2)
 
         C  <- _cell_reciprocal.convert_U_to_beta
         B  <-  C * Matrix([[b,0,0],[0,b,0],[0,0,b]]) * C
     }
     _atom_site_aniso.matrix_beta <- B
;
save_


save_atom_site_aniso.matrix_B
_definition.id                          '_atom_site_aniso.matrix_B'
_definition.update                      2000-11-03
_description.text
;
     The symmetric anisotropic atomic displacement matrix B.
;
_description.compact                    AtomSiteAnisoBIJ
_name.category_id                       atom_site_aniso
_name.attribute_id                      matrix_B
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.class                       Symmetric
_type_array.dimension                   [3,3]
_method.expression
;
     With a as atom_site_aniso
 
      a.matrix_B <- Matrix([[ a.B_11, a.B_12, a.B_13 ],
                            [ a.B_12, a.B_22, a.B_23 ],
                            [ a.B_13, a.B_23, a.B_33 ]])
;
save_


save_atom_site_aniso.B_11
_definition.id                          '_atom_site_aniso.B_11'
_definition.import_id                   '_generic.aniso_BIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      B_11
save_


save_atom_site_aniso.B_12
_definition.id                          '_atom_site_aniso.B_12'
_definition.import_id                   '_generic.aniso_BIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      B_12
save_


save_atom_site_aniso.B_13
_definition.id                          '_atom_site_aniso.B_13'
_definition.import_id                   '_generic.aniso_BIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      B_13
save_


save_atom_site_aniso.B_22
_definition.id                          '_atom_site_aniso.B_22'
_definition.import_id                   '_generic.aniso_BIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      B_22
save_


save_atom_site_aniso.B_23
_definition.id                          '_atom_site_aniso.B_23'
_definition.import_id                   '_generic.aniso_BIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      B_23
save_


save_atom_site_aniso.B_33
_definition.id                          '_atom_site_aniso.B_33'
_definition.import_id                   '_generic.aniso_BIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      B_33
save_


save_atom_site_aniso.matrix_U
_definition.id                          '_atom_site_aniso.matrix_U'
_definition.update                      2000-11-03
_description.text
;
     The symmetric anisotropic atomic displacement matrix U.
;
_description.compact                    AtomSiteAnisoUIJ
_name.category_id                       atom_site_aniso
_name.attribute_id                      matrix_U
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.class                       Symmetric
_type_array.dimension                   [3,3]
_method.expression
;
     With a as atom_site_aniso
 
        a.matrix_U <- Matrix([[ a.U_11, a.U_12, a.U_13 ],
                              [ a.U_12, a.U_22, a.U_23 ],
                              [ a.U_13, a.U_23, a.U_33 ]])
;
save_


save_atom_site_aniso.U_11
_definition.id                          '_atom_site_aniso.U_11'
_definition.import_id                   '_generic.aniso_UIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      U_11
save_


save_atom_site_aniso.U_12
_definition.id                          '_atom_site_aniso.U_12'
_definition.import_id                   '_generic.aniso_UIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      U_12
save_


save_atom_site_aniso.U_13
_definition.id                          '_atom_site_aniso.U_13'
_definition.import_id                   '_generic.aniso_UIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      U_13
save_


save_atom_site_aniso.U_22
_definition.id                          '_atom_site_aniso.U_22'
_definition.import_id                   '_generic.aniso_UIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      U_22
save_


save_atom_site_aniso.U_23
_definition.id                          '_atom_site_aniso.U_23'
_definition.import_id                   '_generic.aniso_UIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      U_23
save_


save_atom_site_aniso.U_33
_definition.id                          '_atom_site_aniso.U_33'
_definition.import_id                   '_generic.aniso_UIJ_element'
_name.category_id                       atom_site_aniso
_name.attribute_id                      U_33
save_

#============================================================================

save_ATOM_SITES
_definition.id                          atom_sites
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe information which applies
     to all atom sites in a crystal structure.
;
_category.parent_id                     structure
save_


save_atom_sites.solution_primary
_definition.id                          '_atom_sites.solution_primary'
_definition.update                      2000-11-03
_description.text
;
     Codes which identify the methods used to locate the first atomic
     sites determined.
;
_description.compact                    MethodologySolnPrimary
_name.category_id                       atom_sites
_name.attribute_id                      solution_primary
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
vecmap 'real-space vector search'
heavy 'heavy-atom method'
direct 'structure-invariant direct methods'
disper 'anomalous-dispersion techniques'
isomor 'isomorphous structure methods'
_enumeration.default                    direct
save_


save_atom_sites.solution_secondary
_definition.id                          '_atom_sites.solution_secondary'
_definition.update                      2000-11-03
_description.text
;
     Code which identifies the methods used to locate the remaining
     non-hydrogen sites determined.
;
_description.compact                    MethodologySolnSecondary
_name.category_id                       atom_sites
_name.attribute_id                      solution_secondary
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
difmap 'difference Fourier map'
geom 'inferred from neighbouring sites'
vecmap 'real-space vector search'
heavy 'heavy-atom method'
direct 'structure-invariant direct methods'
disper 'anomalous-dispersion techniques'
isomor 'isomorphous structure methods'
_enumeration.default                    difmap
save_


save_atom_sites.solution_hydrogens
_definition.id                          '_atom_sites.solution_hydrogens'
_definition.update                      2000-11-03
_description.text
;
     Code which identifies the methods used to locate the hydrogen atomic
     sites determined.
;
_description.compact                    methodologySolnHatoms
_name.category_id                       atom_sites
_name.attribute_id                      solution_hydrogens
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
difmap 'difference Fourier map'
geom 'inferred from neighbouring sites'
vecmap 'real-space vector search'
heavy 'heavy-atom method'
direct 'structure-invariant direct methods'
_enumeration.default                    difmap
save_

#----------------------------------------------------------------------------

save_ATOM_SITES_CARTN_TRANSFORM
_definition.id                          atom_sites_Cartn_transform
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the matrix elements
     used to transform Cartesion coordinates into fractional coordinates
     of all atom sites in a crystal structure.
;
_category.parent_id                     atom_sites
save_


save_atom_sites_Cartn_transform.axes
_definition.id                          '_atom_sites_Cartn_transform.axes'
_definition.update                      2000-11-03
_description.text
;
     Description of the relative alignment of the crystal cell axes to the
     Cartesian orthogonal axes as applied in the transformation matrix
     _atom_sites_Cartn_transform.matrix.
;
_description.compact                    AtomSitesCartnTransfAxes
_name.category_id                       atom_sites_Cartn_transform
_name.attribute_id                      axes
_type.container                         Single
_type.value                             Char
_description_example.case               'a parallel to x; b in the plane of y & z'
save_


save_atom_sites_Cartn_transform.matrix
_definition.id                          '_atom_sites_Cartn_transform.matrix'
_definition.update                      2000-11-03
_description.text
;
     Matrix used to transform fractional coordinates in the ATOM_SITE
     category to Cartesian  coordinates. The axial alignments of this
     transformation are described in _atom_sites_Cartn_transform.axes.
     The 3 x 1 translation is defined in _atom_sites_Cartn_transform.vector.
 
       x'                   |11 12 13|      x                  | 1 |
     ( y' ) Cartesian   =   |21 22 23|    ( y ) fractional  +  | 2 |
       z'                   |31 32 33|      z                  | 3 |
 
     The default transformation matrix uses Rollet's axial
     assignments with cell vectors a,b,c aligned with orthogonal
     axes X,Y,Z so that c||Z and b in plane YZ.
;
_description.compact                    AtomSitesCartnTransfMatrix
_name.category_id                       atom_sites_Cartn_transform
_name.attribute_id                      matrix
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.class                       Lower-Triangular
_type_array.dimension                   [3,3]
_method.expression
;
     With l  as  cell_length
     With a  as  cell_angle
     With r  as  cell_reciprocal_angle
 
    _atom_sites_Cartn_transform.matrix <- Matrix([
 
          [  l.a*Sind(a.beta)*Sind(r.gamma),                 0,   0 ],
          [ -l.a*Sind(a.beta)*Cosd(r.gamma), l.b*Sind(a.alpha),   0 ],
          [  l.a*Cosd(a.beta),               l.b*Cosd(a.alpha), l.c ]])
;
save_


save_atom_sites_Cartn_transform.vector
_definition.id                          '_atom_sites_Cartn_transform.vector'
_definition.update                      2000-11-03
_description.text
;
     Matrix used to transform fractional coordinates in the ATOM_SITE
     category to Cartesian  coordinates. The axial alignments of this
     transformation are described in _atom_sites_Cartn_transform.axes.
     The 3 x 1 translation is defined in _atom_sites_Cartn_transform.vector.
 
       x'                   |11 12 13|      x                  | 1 |
     ( y' ) Cartesian   =   |21 22 23|    ( y ) fractional  +  | 2 |
       z'                   |31 32 33|      z                  | 3 |
;
_description.compact                    AtomSitesCartnTransfVector
_name.category_id                       atom_sites_Cartn_transform
_name.attribute_id                      vector
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
save_

#============================================================================

save_ATOM_TYPE
_definition.id                          atom_type
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe atomic type information
     used in crystallograhic structure studies.
;
_description.compact                    AtomTypeList
_category.parent_id                     structure
_category_key.item_id                   '_atom_type.symbol'
save_


save_atom_type.analytical_mass_percent
_definition.id                          '_atom_type.analytical_mass_percent'
_definition.update                      2000-11-03
_alias.definition_id                    '_atom_type.analytical_mass_%'
_description.text
;
     Mass percentage of this atom type derived from chemical analysis.
;
_description.compact                    AtomTypeComposition%
_name.category_id                       atom_type
_name.attribute_id                      analytical_mass_percent
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:100. 
save_


save_atom_type.atomic_mass
_definition.id                          '_atom_type.atomic_mass'
_definition.update                      2000-11-03
_description.text
;
     Mass of this atom type.
;
_description.compact                    AtomTypeMass
_name.category_id                       atom_type
_name.attribute_id                      atomic_mass
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             daltons
save_


save_atom_type.atomic_number
_definition.id                          '_atom_type.atomic_number'
_definition.update                      2000-11-03
_description.text
;
     Atomic number of this atom type.
;
_description.compact                    AtomTypeNumber
_name.category_id                       atom_type
_name.attribute_id                      atomic_number
_type.container                         Single
_type.value                             Integer
_enumeration.range                      1:1 
save_


save_atom_type.description
_definition.id                          '_atom_type.description'
_definition.update                      2000-11-03
_description.text
;
     A description of the atom(s) designated by this atom type. In
     most cases this will be the element name and oxidation state of
     a single atom  species. For disordered or nonstoichiometric
     structures it will describe a combination of atom species.
;
_description.compact                    AtomTypeDetails
_name.category_id                       atom_type
_name.attribute_id                      description
_type.container                         Single
_type.value                             Char
_description_example.case               deuterium
save_


save_atom_type.display_colour_code
_definition.id                          '_atom_type.display_colour_code'
_definition.update                      2000-11-03
_description.text
;
     The display colour assigned to this atom type. Note that the
     possible colours are enumerated in the display_colour list
     category of items.
;
_description.compact                    AtomTypeColour
_name.category_id                       atom_type
_name.attribute_id                      display_colour_code
_name.linked_item_id                    '_display_colour.code'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
save_


save_atom_type.electron_count
_definition.id                          '_atom_type.electron_count'
_definition.update                      2000-11-03
_description.text
;
     Number of electrons in this atom type.
;
_description.compact                    AtomTypeElectrons
_name.category_id                       atom_type
_name.attribute_id                      electron_count
_type.container                         Single
_type.value                             Integer
_enumeration.range                      1:1 
save_


save_atom_type.element_symbol
_definition.id                          '_atom_type.element_symbol'
_definition.update                      2000-11-03
_description.text
;
     Element symbol for of this atom type.
;
_description.compact                    AtomTypeElement
_name.category_id                       atom_type
_name.attribute_id                      element_symbol
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
H
He
Li
Be
B
C
N
O
F
Ne
Na
Mg
Al
Si
P
S
Cl
Ar
K
Ca
Sc
Ti
V
Cr
Mn
Fe
Co
Ni
Cu
Zn
Ga
Ge
As
Se
Br
Kr
Rb
Sr
Y
Zr
Nb
Mo
Tc
Ru
Rh
Pd
Ag
Cd
In
Sn
Sb
Te
I
Xe
Cs
Ba
La
Ce
Pr
Nd
Pm
Sm
Eu
Gd
Tb
Dy
Ho
Er
Tm
Yb
Lu
Hf
Ta
W
Re
Os
Ir
Pt
Au
Hg
Tl
Pb
Bi
Po
At
Rn
Fr
Ra
Ac
Th
Pa
U
Np
Pu
Am
Cm
Bk
Cf
Es
Fm
Md
No
Lr
_enumeration.default                    C
save_


save_atom_type.number_in_cell
_definition.id                          '_atom_type.number_in_cell'
_definition.update                      2000-11-03
_description.text
;
     Total number of atoms of this atom type in the unit cell.
;
_description.compact                    AtomTypeCellCount
_name.category_id                       atom_type
_name.attribute_id                      number_in_cell
_type.container                         Single
_type.value                             Real
_enumeration.range                      0:0 
_method.expression
;
    With t as atom_type
 
    cnt <- 0.
 
    Loop a  as  atom_site  {
 
       if ( a.type_symbol == t.symbol ) {
 
          cnt +<- a.occupancy * a.symmetry_multiplicity
    }  }
    _atom_type.number_in_cell <- cnt
;
save_


save_atom_type.oxidation_number
_definition.id                          '_atom_type.oxidation_number'
_definition.update                      2000-11-03
_description.text
;
     Formal oxidation state of this atom type in the structure.
;
_description.compact                    AtomTypeOxidation
_name.category_id                       atom_type
_name.attribute_id                      oxidation_number
_type.container                         Single
_type.value                             Integer
_enumeration.range                      -8:8 
_enumeration.default                    0
save_


save_atom_type.radius_bond
_definition.id                          '_atom_type.radius_bond'
_definition.update                      2000-11-03
_description.text
;
     The effective intra-molecular bonding radius of this atom type.
;
_description.compact                    AtomTypeBondRad
_name.category_id                       atom_type
_name.attribute_id                      radius_bond
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:5.0 
_units.code                             angstroms
save_


save_atom_type.radius_contact
_definition.id                          '_atom_type.radius_contact'
_definition.update                      2000-11-03
_description.text
;
     The effective inter-molecular bonding radius of this atom type.
;
_description.compact                    AtomTypeContactRad
_name.category_id                       atom_type
_name.attribute_id                      radius_contact
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:5.0 
_units.code                             angstroms
_method.expression
;
     _atom_type.radius_contact <- atom_type.radius_bond + 1.25
;
save_


save_atom_type.symbol
_definition.id                          '_atom_type.symbol'
_definition.update                      2000-11-03
_description.text
;
     The identity of the atom specie(s) representing this atom type.
     Normally this code is the element symbol followed by the charge
     if there is one. The symbol may be composed of any character except
     an underline or a blank, with the proviso that digits designate an
     oxidation state and must be followed by a + or - character.
;
_description.compact                    AtomTypeSymbol
_name.category_id                       atom_type
_name.attribute_id                      symbol
_type.container                         Single
_type.value                             Uchar
loop_
_description_example.case
Mg
Cu2+
dummy
FeNi
save_

#============================================================================

save_ATOM_TYPE_SCAT
_definition.id                          atom_type_scat
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe atomic scattering
     information used in crystallograhic structure studies.
;
_category.parent_id                     atom_type
_category.join_set_id                   atom_type
_category_key.item_id                   '_atom_type_scat.symbol'
save_


save_atom_type_scat.Cromer_Mann_coeffs
_definition.id                          '_atom_type_scat.Cromer_Mann_coeffs'
_definition.update                      2000-11-03
_description.text
;
     The set of Cromer-Mann coefficients for generating X-ray scattering
     factors. [ a1, b1, a2, b2, a3, b3, a4, b4, c]
     Ref: International Tables for Crystallography, Vol. C
             (1991) Table 6.1.1.4
;
_description.compact                    AtomTypeCMCoeffs
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_coeffs
_type.container                         Tuple
_type.value                             Real
_type_array.dimension                   [9]
_method.expression
;
     With t  as  atom_type_scat
 
      _atom_type_scat.Cromer_Mann_coeffs  <-  Tuple ( [t.Cromer_Mann_c,
                                     t.Cromer_Mann_a1, t.Cromer_Mann_b1,
                                     t.Cromer_Mann_a2, t.Cromer_Mann_b2,
                                     t.Cromer_Mann_a3, t.Cromer_Mann_b3,
                                     t.Cromer_Mann_a4, t.Cromer_Mann_b4 ])
;
save_


save_atom_type_scat.Cromer_Mann_a1
_definition.id                          '_atom_type_scat.Cromer_Mann_a1'
_definition.import_id                   '_generic.Cromer_Mann_coeff'
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_a1
save_


save_atom_type_scat.Cromer_Mann_a2
_definition.id                          '_atom_type_scat.Cromer_Mann_a2'
_definition.import_id                   '_generic.Cromer_Mann_coeff'
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_a2
save_


save_atom_type_scat.Cromer_Mann_a3
_definition.id                          '_atom_type_scat.Cromer_Mann_a3'
_definition.import_id                   '_generic.Cromer_Mann_coeff'
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_a3
save_


save_atom_type_scat.Cromer_Mann_a4
_definition.id                          '_atom_type_scat.Cromer_Mann_a4'
_definition.import_id                   '_generic.Cromer_Mann_coeff'
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_a4
save_


save_atom_type_scat.Cromer_Mann_b1
_definition.id                          '_atom_type_scat.Cromer_Mann_b1'
_definition.import_id                   '_generic.Cromer_Mann_coeff'
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_b1
save_


save_atom_type_scat.Cromer_Mann_b2
_definition.id                          '_atom_type_scat.Cromer_Mann_b2'
_definition.import_id                   '_generic.Cromer_Mann_coeff'
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_b2
save_


save_atom_type_scat.Cromer_Mann_b3
_definition.id                          '_atom_type_scat.Cromer_Mann_b3'
_definition.import_id                   '_generic.Cromer_Mann_coeff'
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_b3
save_


save_atom_type_scat.Cromer_Mann_b4
_definition.id                          '_atom_type_scat.Cromer_Mann_b4'
_definition.import_id                   '_generic.Cromer_Mann_coeff'
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_b4
save_


save_atom_type_scat.Cromer_Mann_c
_definition.id                          '_atom_type_scat.Cromer_Mann_c'
_definition.import_id                   '_generic.Cromer_Mann_coeff'
_name.category_id                       atom_type_scat
_name.attribute_id                      Cromer_Mann_c
save_


save_atom_type_scat.dispersion_imag
_definition.id                          '_atom_type_scat.dispersion_imag'
_definition.update                      2000-11-03
_description.text
;
     The imaginary component of the anomalous dispersion scattering factors
     for this atom type and radiation by _diffrn_radiation_wavelength.value
;
_description.compact                    AtomTypeAnomDispImag
_name.category_id                       atom_type_scat
_name.attribute_id                      dispersion_imag
_type.container                         Single
_type.value                             Real
_enumeration.default                    0.0
save_


save_atom_type_scat.dispersion_real
_definition.id                          '_atom_type_scat.dispersion_real'
_definition.update                      2000-11-03
_description.text
;
     The real component of the anomalous dispersion scattering factors
     for this atom type and radiation by _diffrn_radiation_wavelength.value
;
_description.compact                    AtomTypeAnomDispReal
_name.category_id                       atom_type_scat
_name.attribute_id                      dispersion_real
_type.container                         Single
_type.value                             Real
_enumeration.default                    0.0
save_


save_atom_type_scat.dispersion_source
_definition.id                          '_atom_type_scat.dispersion_source'
_definition.update                      2000-11-03
_description.text
;
     Reference to source of real and imaginary dispersion
     corrections for scattering factors used for this atom type.
;
_description.compact                    AtomTypeAnomDispDetails
_name.category_id                       atom_type_scat
_name.attribute_id                      dispersion_source
_type.container                         Single
_type.value                             Char
_description_example.case               'International Tables Vol. IV Table 2.3.1'
save_


save_atom_type_scat.hi_ang_Fox_coeffs
_definition.id                          '_atom_type_scat.hi_ang_Fox_coeffs'
_definition.update                      2000-11-03
_description.text
;
     The set of Fox et al. coefficients for generating high angle
     X-ray scattering factors. [ c0, c1, c2, c3 ]
     Ref: International Tables for Crystallography, Vol. C
             (1991) Table 6.1.1.5
;
_description.compact                    AtomTypeFoxCoeffs
_name.category_id                       atom_type_scat
_name.attribute_id                      hi_ang_Fox_coeffs
_type.container                         Tuple
_type.value                             Real
_type_array.dimension                   [4]
_method.expression
;
     With t  as  atom_type_scat
 
    _atom_type_scat.hi_ang_Fox_coeffs  <- Tuple( [ t.hi_ang_Fox_c0,
                                                   t.hi_ang_Fox_c1,
                                                   t.hi_ang_Fox_c2,
                                                   t.hi_ang_Fox_c3 ])
;
save_


save_atom_type_scat.hi_ang_Fox_c0
_definition.id                          '_atom_type_scat.hi_ang_Fox_c0'
_definition.import_id                   '_generic.hi_ang_Fox_coeffs'
_name.category_id                       atom_type_scat
_name.attribute_id                      hi_ang_Fox_c0
save_


save_atom_type_scat.hi_ang_Fox_c1
_definition.id                          '_atom_type_scat.hi_ang_Fox_c1'
_definition.import_id                   '_generic.hi_ang_Fox_coeffs'
_name.category_id                       atom_type_scat
_name.attribute_id                      hi_ang_Fox_c1
save_


save_atom_type_scat.hi_ang_Fox_c2
_definition.id                          '_atom_type_scat.hi_ang_Fox_c2'
_definition.import_id                   '_generic.hi_ang_Fox_coeffs'
_name.category_id                       atom_type_scat
_name.attribute_id                      hi_ang_Fox_c2
save_


save_atom_type_scat.hi_ang_Fox_c3
_definition.id                          '_atom_type_scat.hi_ang_Fox_c3'
_definition.import_id                   '_generic.hi_ang_Fox_coeffs'
_name.category_id                       atom_type_scat
_name.attribute_id                      hi_ang_Fox_c3
save_


save_atom_type_scat.length_neutron
_definition.id                          '_atom_type_scat.length_neutron'
_definition.update                      2000-11-03
_description.text
;
     The bound coherent scattering length for the atom type at the
     isotopic composition used for the diffraction experiment.
;
_description.compact                    AtomTypeScatNeutronB
_name.category_id                       atom_type_scat
_name.attribute_id                      length_neutron
_type.container                         Single
_type.value                             Real
_enumeration.default                    0.0
_units.code                             femtometres
save_


save_atom_type_scat.source
_definition.id                          '_atom_type_scat.source'
_definition.update                      2000-11-03
_description.text
;
     Reference to source of scattering factors used for this atom type.
;
_description.compact                    AtomTypeScatDetails
_name.category_id                       atom_type_scat
_name.attribute_id                      source
_type.container                         Single
_type.value                             Char
_description_example.case               'International Tables Vol. IV Table 2.4.6B'
save_


save_atom_type_scat.symbol
_definition.id                          '_atom_type_scat.symbol'
_definition.update                      2000-11-03
_description.text
;
     The identity of the atom specie(s) representing this atom type.
     See _atom_type.symbol for further details.
;
_description.compact                    AtomTypeScatSymbol
_name.category_id                       atom_type_scat
_name.attribute_id                      symbol
_type.container                         Single
_type.value                             Uchar
save_


save_atom_type_scat.versus_stol_list
_definition.id                          '_atom_type_scat.versus_stol_list'
_definition.update                      2000-11-03
_description.text
;
     Table of scattering factors as a function of sin theta on lambda
     in increments of 0.01, increasing from 0.0.
;
_description.compact                    AtomTypeScatTable
_name.category_id                       atom_type_scat
_name.attribute_id                      versus_stol_list
_type.container                         Table
_type.value                             Real
save_

#============================================================================

save_CELL
_definition.id                          cell
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the parameters of
     the crystal unit cell and their measurement.
;
_category.parent_id                     crystal
save_


save_cell.atomic_mass
_definition.id                          '_cell.atomic_mass'
_definition.update                      2000-11-03
_description.text
;
     Atomic mass of the contents of the unit cell. This calculated
     from the atom sites present in the ATOM_TYPE list, rather than
     the ATOM_SITE lists of atoms in the refined model.
;
_description.compact                    CellAtomicMass
_name.category_id                       cell
_name.attribute_id                      atomic_mass
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.:0. 
_units.code                             daltons
_method.expression
;
    mass <- 0.
 
    Loop t as atom_type  {
 
                   mass +<- t.number_in_cell * t.atomic_mass
    }
      _cell.atomic_mass <- mass
;
save_


save_cell.formula_units_Z
_definition.id                          '_cell.formula_units_Z'
_definition.update                      2000-11-03
_description.text
;
     The number of the formula units in the unit cell as specified
     by _chemical_formula.structural, _chemical_formula.moiety or
     _chemical_formula.sum.
;
_description.compact                    CellFormulaZ
_name.category_id                       cell
_name.attribute_id                      formula_units_Z
_type.container                         Single
_type.value                             Integer
_enumeration.range                      1:1 
save_


save_cell.metric_tensor
_definition.id                          '_cell.metric_tensor'
_definition.update                      2000-11-03
_description.text
;
     The direct space (covariant) metric tensor used to transform
     vectors and coordinates from real (direct) to reciprocal space.
;
_description.compact                    CellMetricTensor
_name.category_id                       cell
_name.attribute_id                      metric_tensor
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.class                       Symmetric
_type_array.dimension                   [3,3]
_method.expression
;
     with v  as  cell_vector
 
           _cell.metric_tensor <- Matrix([[ v.a*v.a, v.a*v.b, v.a*v.c ],
                                          [ v.b*v.a, v.b*v.b, v.b*v.c ],
                                          [ v.c*v.a, v.c*v.b, v.c*v.c ]])
;
save_


save_cell.orthogonal_matrix
_definition.id                          '_cell.orthogonal_matrix'
_definition.update                      2000-11-03
_description.text
;
     Orthogonal matrix of the crystal unit cell. Definition uses
     Rollet's axial assignments with cell vectors a,b,c aligned
     with orthogonal axes X,Y,Z so that c||Z and b in plane YZ.
;
_description.compact                    CellOthogMatrix
_name.category_id                       cell
_name.attribute_id                      orthogonal_matrix
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.class                       Lower-Triangular
_type_array.dimension                   [3,3]
_method.expression
;
     With l  as  cell_length
     With a  as  cell_angle
     With r  as  cell_reciprocal_angle
 
    _cell.orthogonal_matrix <-   Matrix([
 
          [  l.a*Sind(a.beta)*Sind(r.gamma),                 0,   0 ],
          [ -l.a*Sind(a.beta)*Cosd(r.gamma), l.b*Sind(a.alpha),   0 ],
          [  l.a*Cosd(a.beta),               l.b*Cosd(a.alpha), l.c ]])
;
save_


save_cell.special_details
_definition.id                          '_cell.special_details'
_definition.update                      2000-11-03
_description.text
;
     Description of special aspects of the cell choice, noting
     possible alternative settings.
;
_description.compact                    CellDetails
_name.category_id                       cell
_name.attribute_id                      special_details
_type.container                         Single
_type.value                             Char
save_


save_cell.volume
_definition.id                          '_cell.volume'
_definition.update                      2000-11-03
_description.text
;
     Volume of the crystal unit cell.
;
_description.compact                    CellVolume
_name.category_id                       cell
_name.attribute_id                      volume
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             angstroms_cubed
_method.expression
;
      With v  as  cell_vector
 
      _cell.volume <-  v.a * ( v.b ^ v.c )
;
save_

#----------------------------------------------------------------------------

save_CELL_ANGLE
_definition.id                          cell_angle
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the angles between
     the axes in the crystal unit cell.
;
_category.parent_id                     cell
save_


save_cell_angle.alpha
_definition.id                          '_cell_angle.alpha'
_definition.update                      2000-11-03
_description.text
;
     The angle between the cell axes _cell_length.b and _cell_length.c.
;
_description.compact                    CellAngleAlpha
_name.category_id                       cell_angle
_name.attribute_id                      alpha
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:180.0 
_enumeration.default                    90.0
_units.code                             degrees
save_


save_cell_angle.beta
_definition.id                          '_cell_angle.beta'
_definition.update                      2000-11-03
_description.text
;
     The angle between the cell axes _cell_length.a and _cell_length.c.
;
_description.compact                    CellAngleBeta
_name.category_id                       cell_angle
_name.attribute_id                      beta
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:180.0 
_enumeration.default                    90.0
_units.code                             degrees
save_


save_cell_angle.gamma
_definition.id                          '_cell_angle.gamma'
_definition.update                      2000-11-03
_description.text
;
     The angle between the cell axes _cell_length.a and _cell_length.b.
;
_description.compact                    CellAngleGamma
_name.category_id                       cell_angle
_name.attribute_id                      gamma
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:180.0 
_enumeration.default                    90.0
_units.code                             degrees
save_

#----------------------------------------------------------------------------

save_CELL_LENGTH
_definition.id                          cell_length
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the lengths of
     the axes in the crystal unit cell.
;
_category.parent_id                     cell
save_


save_cell_length.a
_definition.id                          '_cell_length.a'
_name.category_id                       cell_length
_name.attribute_id                      a
_description.compact                    CellLengthA
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             angstroms
save_


save_cell_length.b
_definition.id                          '_cell_length.b'
_name.category_id                       cell_length
_name.attribute_id                      b
_description.compact                    CellLengthB
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             angstroms
save_


save_cell_length.c
_definition.id                          '_cell_length.c'
_name.category_id                       cell_length
_name.attribute_id                      c
_description.compact                    CellLengthC
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             angstroms
save_

#----------------------------------------------------------------------------

save_CELL_VECTOR
_definition.id                          cell_vector
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the axial vectors of
     the crystal unit cell.
;
_category.parent_id                     cell
save_


save_cell_vector.a
_definition.id                          '_cell_vector.a'
_name.category_id                       cell_vector
_name.attribute_id                      a
_description.compact                    CellVectorA
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
    _cell_vector.a <- _cell.orthogonal_matrix * Vector (1,0,0)
;
save_


save_cell_vector.b
_definition.id                          '_cell_vector.b'
_name.category_id                       cell_vector
_name.attribute_id                      b
_description.compact                    CellVectorB
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
    _cell_vector.b <- _cell.orthogonal_matrix * Vector (0,1,0)
;
save_


save_cell_vector.c
_definition.id                          '_cell_vector.c'
_name.category_id                       cell_vector
_name.attribute_id                      c
_description.compact                    CellVectorC
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
    _cell_vector.c <- _cell.orthogonal_matrix * Vector (0,0,1)
;
save_

#----------------------------------------------------------------------------

save_CELL_MEASUREMENT
_definition.id                          cell_measurement
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the angles between
     the axes in the crystal unit cell.
;
_category.parent_id                     cell
save_


save_cell_measurement.pressure
_definition.id                          '_cell_measurement.pressure'
_definition.update                      2000-11-03
_description.text
;
     The pressure at which the unit-cell parameters were measured
     (not the pressure used to synthesize the sample).
;
_description.compact                    CellMeasPressure
_name.category_id                       cell_measurement
_name.attribute_id                      pressure
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             kilopascals
save_


save_cell_measurement.radiation
_definition.id                          '_cell_measurement.radiation'
_definition.update                      2000-11-03
_description.text
;
     Description of the radiation used to measure the unit-cell data.
;
_description.compact                    CellMeasRadiation
_name.category_id                       cell_measurement
_name.attribute_id                      radiation
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
neutron
'X-ray tube'
synchrotron
save_


save_cell_measurement.reflns_used
_definition.id                          '_cell_measurement.reflns_used'
_definition.update                      2000-11-03
_description.text
;
     Number of reflections used to determine the unit cell.
     The reflections may be specified as cell_measurement_refln items.
;
_description.compact                    CellMeasReflnCount
_name.category_id                       cell_measurement
_name.attribute_id                      reflns_used
_type.container                         Single
_type.value                             Integer
save_


save_cell_measurement.temperature
_definition.id                          '_cell_measurement.temperature'
_definition.update                      2000-11-03
_description.text
;
     The temperature at which the unit-cell parameters were measured
     (not the temperature of synthesis).
;
_description.compact                    CellMeasTemperature
_name.category_id                       cell_measurement
_name.attribute_id                      temperature
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             kelvins
save_


save_cell_measurement.theta_max
_definition.id                          '_cell_measurement.theta_max'
_definition.update                      2000-11-03
_description.text
;
     Maximum theta scattering angle of reflections used to measure
     the crystal unit cell.
;
_description.compact                    CellMeasThetaMax
_name.category_id                       cell_measurement
_name.attribute_id                      theta_max
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:90.0 
_units.code                             degrees
save_


save_cell_measurement.theta_min
_definition.id                          '_cell_measurement.theta_min'
_definition.update                      2000-11-03
_description.text
;
     Minimum theta scattering angle of reflections used to measure
     the crystal unit cell.
;
_description.compact                    CellMeasThetaMin
_name.category_id                       cell_measurement
_name.attribute_id                      theta_min
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:90.0 
_units.code                             degrees
save_


save_cell_measurement.wavelength
_definition.id                          '_cell_measurement.wavelength'
_definition.update                      2000-11-03
_description.text
;
     Wavelength of the radiation used to measure the unit cell.
     If this is not specified, the wavelength is assumed to be the
     same as that given in _diffrn_radiation_wavelength.value
;
_description.compact                    CellMeasWaveLength
_name.category_id                       cell_measurement
_name.attribute_id                      wavelength
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_

#----------------------------------------------------------------------------

save_CELL_MEASUREMENT_REFLN
_definition.id                          cell_measurement_refln
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the reflection data
     used in the measurement of the crystal unit cell.
;
_category.parent_id                     cell_measurement
_category_key.item_id                   '_cell_measurement_refln.hkl'
save_


save_cell_measurement_refln.hkl
_definition.id                          '_cell_measurement_refln.hkl'
_definition.update                      2000-11-03
_description.text
;
     Miller indices of a reflection used to measure the unit cell.
;
_description.compact                    CellMeasReflnHkl
_name.category_id                       cell_measurement_refln
_name.attribute_id                      hkl
_type.container                         Vector
_type.value                             Integer
_type_array.dimension                   [3]
_method.expression
;
     With c  as  cell_measurement_refln
 
     _cell_measurement_refln.hkl  <-  Vector([c.index_h, c.index_k, c.index_l])
;
save_


save_cell_measurement_refln.theta
_definition.id                          '_cell_measurement_refln.theta'
_definition.update                      2000-11-03
_description.text
;
     Theta angle of reflection used to measure the crystal unit cell.
;
_description.compact                    CellMeasReflnTheta
_name.category_id                       cell_measurement_refln
_name.attribute_id                      theta
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:90.0 
_units.code                             degrees
save_


save_cell_measurement_refln.index_h
_definition.id                          '_cell_measurement_refln.index_h'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       cell_measurement_refln
_name.attribute_id                      index_h
save_


save_cell_measurement_refln.index_k
_definition.id                          '_cell_measurement_refln.index_k'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       cell_measurement_refln
_name.attribute_id                      index_k
save_


save_cell_measurement_refln.index_l
_definition.id                          '_cell_measurement_refln.index_l'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       cell_measurement_refln
_name.attribute_id                      index_l
save_

#----------------------------------------------------------------------------

save_CELL_RECIPROCAL
_definition.id                          cell_reciprocal
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the unit cell data
     in reciprocal space.
;
_category.parent_id                     cell
save_


save_cell_reciprocal.convert_U_to_beta
_definition.id                          '_cell_reciprocal.convert_U_to_beta'
_definition.update                      2000-11-03
_description.text
;
     The reciprocal space matrix for converting the U(ij) matrix of
     atomic displacement parameters to a dimensionless beta(IJ) matrix.
     The adp factor in a structure factor expression:
 
     t = exp -2pi**2 ( U11    h h a* a* + ...... 2 U23    k l b* c* )
     t = exp - 0.25  ( B11    h h a* a* + ...... 2 B23    k l b* c* )
       = exp -       ( beta11 h h + ............ 2 beta23 k l )
 
    The conversion of the U or B matrices to the beta matrix
 
         beta =   C U C   =    C B C /8pi**2
 
    where C is conversion matrix defined here.
;
_description.compact                    CellRecipConvertUtoBeta
_name.category_id                       cell_reciprocal
_name.attribute_id                      convert_U_to_beta
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.class                       Symmetric
_type_array.dimension                   [3,3]
_method.expression
;
    With r  as  cell_reciprocal_length
 
    _cell_reciprocal.convert_U_to_beta <- 1.4142 * Pi * Matrix([[ r.a, 0, 0 ],
                                                                [ 0, r.b, 0 ],
                                                                [ 0, 0, r.c ]])
;
save_


save_cell_reciprocal.metric_tensor
_definition.id                          '_cell_reciprocal.metric_tensor'
_definition.update                      2000-11-03
_description.text
;
     The reciprocal (contravariant) metric tensor used to transform
     vectors and coordinates from reciprocal space to real (direct)
     space.
;
_description.compact                    CellRecipMetricTensor
_name.category_id                       cell_reciprocal
_name.attribute_id                      metric_tensor
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.class                       Symmetric
_type_array.dimension                   [3,3]
_method.expression
;
     with r  as  cell_reciprocal_vector
 
    _cell_reciprocal.metric_tensor <- Matrix([[ r.a*r.a, r.a*r.b, r.a*r.c ],
                                              [ r.b*r.a, r.b*r.b, r.b*r.c ],
                                              [ r.c*r.a, r.c*r.b, r.c*r.c ]])
;
save_


save_cell_reciprocal.orthogonal_matrix
_definition.id                          '_cell_reciprocal.orthogonal_matrix'
_definition.update                      2000-11-03
_description.text
;
     Orthogonal matrix of the reciprocal space. The matrix may be
     used to transform the non-orthogonal vector h = (h,k,l) into
     the orthogonal indices p = (p,q,r)
 
                     M h = p
;
_description.compact                    HklOthogMatrix
_name.category_id                       cell_reciprocal
_name.attribute_id                      orthogonal_matrix
_type.container                         Matrix
_type.value                             Real
_type_array.dimension                   [3,3]
_method.expression
;
    _cell_reciprocal.orthogonal_matrix  <-  Inverse(
 
                           Transpose( _cell.orthogonal_matrix ))
;
save_

#----------------------------------------------------------------------------

save_CELL_RECIPROCAL_ANGLE
_definition.id                          cell_reciprocal_angle
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the unit cell angles
     in reciprocal space.
;
_category.parent_id                     cell_reciprocal
save_


save_cell_reciprocal_angle.alpha
_definition.id                          '_cell_reciprocal_angle.alpha'
_name.category_id                       cell_reciprocal_angle
_name.attribute_id                      alpha
_description.compact                    CellRecipAngleAlpha
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             degrees
_method.expression
;
    _cell_reciprocal_angle.alpha <- 180. - _cell_angle.alpha
;
save_


save_cell_reciprocal_angle.beta
_definition.id                          '_cell_reciprocal_angle.beta'
_name.category_id                       cell_reciprocal_angle
_name.attribute_id                      beta
_description.compact                    CellRecipAngleBeta
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             degrees
_method.expression
;
    _cell_reciprocal_angle.beta <- 180. - _cell_angle.beta
;
save_


save_cell_reciprocal_angle.gamma
_definition.id                          '_cell_reciprocal_angle.gamma'
_name.category_id                       cell_reciprocal_angle
_name.attribute_id                      gamma
_description.compact                    CellRecipAngleGamma
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             degrees
_method.expression
;
    _cell_reciprocal_angle.gamma <- 180. - _cell_angle.gamma
;
save_

#----------------------------------------------------------------------------

save_CELL_RECIPROCAL_LENGTH
_definition.id                          cell_reciprocal_length
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the unit cell lengths
     in reciprocal space.
;
_category.parent_id                     cell_reciprocal
save_


save_cell_reciprocal_length.a
_definition.id                          '_cell_reciprocal_length.a'
_name.category_id                       cell_reciprocal_length
_name.attribute_id                      a
_description.compact                    CellRecipLengthA
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             reciprocal_angstroms
_method.expression
;
    _cell_reciprocal_length.a <- Norm ( _cell_reciprocal_vector.a )
;
save_


save_cell_reciprocal_length.b
_definition.id                          '_cell_reciprocal_length.b'
_name.category_id                       cell_reciprocal_length
_name.attribute_id                      b
_description.compact                    CellRecipLengthB
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             reciprocal_angstroms
_method.expression
;
    _cell_reciprocal_length.b <- Norm ( _cell_reciprocal_vector.b )
;
save_


save_cell_reciprocal_length.c
_definition.id                          '_cell_reciprocal_length.c'
_name.category_id                       cell_reciprocal_length
_name.attribute_id                      c
_description.compact                    CellRecipLengthC
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             reciprocal_angstroms
_method.expression
;
    _cell_reciprocal_length.c <- Norm ( _cell_reciprocal_vector.c )
;
save_

#----------------------------------------------------------------------------

save_CELL_RECIPROCAL_VECTOR
_definition.id                          cell_reciprocal_vector
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the unit cell vectors
     in reciprocal space.
;
_category.parent_id                     cell_reciprocal
save_


save_cell_reciprocal_vector.a
_definition.id                          '_cell_reciprocal_vector.a'
_name.category_id                       cell_reciprocal_vector
_name.attribute_id                      a
_description.compact                    CellRecipVectorA
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
     With c  as  cell_vector
 
    _cell_reciprocal_vector.a <- c.b ^ c.c / _cell.volume
;
save_


save_cell_reciprocal_vector.b
_definition.id                          '_cell_reciprocal_vector.b'
_name.category_id                       cell_reciprocal_vector
_name.attribute_id                      b
_description.compact                    CellRecipVectorB
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
     With c  as  cell_vector
 
    _cell_reciprocal_vector.b <- c.c ^ c.a / _cell.volume
;
save_


save_cell_reciprocal_vector.c
_definition.id                          '_cell_reciprocal_vector.c'
_name.category_id                       cell_reciprocal_vector
_name.attribute_id                      c
_description.compact                    CellRecipVectorC
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
     With c  as  cell_vector
 
    _cell_reciprocal_vector.c <- c.a ^ c.b / _cell.volume
;
save_

#============================================================================

save_CHEMICAL
_definition.id                          chemical
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which describe the composition and
     chemical properties of the compounds. The formula data items must
     agree with those that specify the density, unit-cell and Z values.
;
_category.parent_id                     crystal
save_


save_chemical.absolute_configuration
_definition.id                          '_chemical.absolute_configuration'
_definition.update                      2000-11-03
_description.text
;
     Codes identifying the assignment of absolute structure. In the
     enumerated codes Set_E is defined to be the set of non-centrosymmetric
     crystal classes {1, 2, 3, 4, 6, 222, 32, 422, 622, 23, 432}, x(su) is
     the value of the Flack (1983) parameter as given by data item
     _refine_ls.abs_structure_Flack.
     Ref: Flack, H. D. (1983). Acta Cryst. A39, 876-881.
;
_description.compact                    ChemAbsConfigCode
_name.category_id                       chemical
_name.attribute_id                      absolute_configuration
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
rm
;
        'reference molecule' To be valid the crystal class must be in Set_E
         and the source of the chiral reference substance of known absolute
         configuration must be reported. The optical activity in solution or
         liquid state must be non-zero.
;
ad
;
        'anomalous dispersion' The absolute configuration established by
         anomalous dispersion effects in diffraction measurements on the
         crystal. To be valid the crystal class must be in Set_E and
         |x/su| < 1.6 and |(1-x)/su| > 5.0. The optical activity in
         solution or liquid state must be non-zero.
;
rmad
;
        'rm + ad' Established by the structure determination of a compound
         containing a chiral reference molecule of known absolute
         configuration and confirmed by anomalous dispersion effects in
         diffraction measurements on the crystal. To be valid the conditions
         of both 'rm' and 'ad' must be fulfilled. The optical activity in
         solution or liquid state must be non-zero.
;
syn
;
        'synthetic' The enantiomer has been assigned by reference to an
         unchanging chiral centre in the synthetic procedure. To be valid
         the crystal class must be in Set_E and the chiral centre used to
         assign the enantiomer must be reported. The optical activity in
         solution or liquid state must be non-zero.
;
unk
;
        'unknown' An arbitrary choice of enantiomer has been made. To be
         valid the crystal class must be in Set_E. The optical activity
         in solution or liquid state must be non-zero.
;
save_


save_chemical.compound_source
_definition.id                          '_chemical.compound_source'
_definition.update                      2000-11-03
_description.text
;
     Description of the source of the compound under study, or of the
     parent  molecule if a simple derivative is studied. This includes
     the place of  discovery for minerals or the actual source of a
     natural product.
;
_description.compact                    ChemCompoundSource
_name.category_id                       chemical
_name.attribute_id                      compound_source
_type.container                         Single
_type.value                             Char
save_


save_chemical.melting_point
_definition.id                          '_chemical.melting_point'
_definition.update                      2000-11-03
_description.text
;
     The temperature at which a crystalline solid changes to a liquid.
;
_description.compact                    ChemMeltingPoint
_name.category_id                       chemical
_name.attribute_id                      melting_point
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             kelvins
save_


save_chemical.name_common
_definition.id                          '_chemical.name_common'
_definition.update                      2000-11-03
_description.text
;
     Trivial name by which the compound is commonly known.
;
_description.compact                    ChemCommonName
_name.category_id                       chemical
_name.attribute_id                      name_common
_type.container                         Single
_type.value                             Char
save_


save_chemical.name_mineral
_definition.id                          '_chemical.name_mineral'
_definition.update                      2000-11-03
_description.text
;
     Mineral name accepted by the International Mineralogical Association.
;
_description.compact                    ChemMineralName
_name.category_id                       chemical
_name.attribute_id                      name_mineral
_type.container                         Single
_type.value                             Char
save_


save_chemical.name_structure_type
_definition.id                          '_chemical.name_structure_type'
_definition.update                      2000-11-03
_description.text
;
     Commonly used structure-type name. Usually only applied to
     minerals or inorganic compounds.
;
_description.compact                    ChemStructuralName
_name.category_id                       chemical
_name.attribute_id                      name_structure_type
_type.container                         Single
_type.value                             Char
save_


save_chemical.name_systematic
_definition.id                          '_chemical.name_systematic'
_definition.update                      2000-11-03
_description.text
;
     IUPAC or Chemical Abstracts full name of compound.
;
_description.compact                    ChemSystemName
_name.category_id                       chemical
_name.attribute_id                      name_systematic
_type.container                         Single
_type.value                             Char
save_


save_chemical.optical_rotation
_definition.id                          '_chemical.optical_rotation'
_definition.update                      2000-11-03
_description.text
;
     The optical rotation in solution of the compound is
     specified in the following format:
 
        '[\a]^TEMP^~WAVE~ = SORT (c = CONC, SOLV)'
 
     where: TEMP is the temperature of the measurement in degrees Celsius,
            WAVE is an indication of the wavelength of the light
                 used for the measurement,
            CONC is the concentration of the solution given as the
                 mass of the substance in g in 100 ml of solution,
            SORT is the signed value (preceded by a + or a - sign)
                 of 100.\a/(l.c), where \a is the signed optical
                 rotation in degrees measured in a cell of length l in
                 dm and c is the value of CONC in g, and
            SOLV is the chemical formula of the solvent.
;
_description.compact                    ChemOpticalRotDetails
_name.category_id                       chemical
_name.attribute_id                      optical_rotation
_type.container                         Single
_type.value                             Uchar
_description_example.case               '[\a]^25^~D~ = +108 (c = 3.42, CHCl~3~)'
save_

#============================================================================

save_CHEMICAL_CONN_ATOM
_definition.id                          chemical_conn_atom
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which describe the 2D chemical structure of
     the molecular species. They allow a 2D chemical diagram to be
     reconstructed for use in a publication or in a database search
     for structural and substructural relationships. In particular,
     the chemical_conn_atom data items provide information about the
     chemical properties of the atoms in the structure. In cases
     where crystallographic and molecular symmetry elements coincide
     they must also contain symmetry-generated atoms, so as to describe
     a complete chemical entity.
 
;
_description.compact                    ChemConnAtomList
_category.parent_id                     chemical
_category_key.item_id                   '_chemical_conn_atom.number'
save_


save_chemical_conn_atom.charge
_definition.id                          '_chemical_conn_atom.charge'
_definition.update                      2000-11-03
_description.text
;
     The net integer charge assigned to this atom. This is the
     formal charge assignment normally found in chemical diagrams.
;
_description.compact                    ChemConnAtomCharge
_name.category_id                       chemical_conn_atom
_name.attribute_id                      charge
_type.container                         Single
_type.value                             Integer
_enumeration.range                      -6:6 
_enumeration.default                    0
save_


save_chemical_conn_atom.display_x
_definition.id                          '_chemical_conn_atom.display_x'
_definition.update                      2000-11-03
_description.text
;
     Cartesian coordinate (x) of the atom site in a chemical diagram. The
     coordinate origin is at the lower left corner, the x axis is horizontal.
;
_description.compact                    ChemConnDisplayX
_name.category_id                       chemical_conn_atom
_name.attribute_id                      display_x
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:1.0 
save_


save_chemical_conn_atom.display_y
_definition.id                          '_chemical_conn_atom.display_y'
_definition.update                      2000-11-03
_description.text
;
     Cartesian coordinate (y) of the atom site in a chemical diagram. The
     coordinate origin is at the lower left corner, the y axis is vertical.
;
_description.compact                    ChemConnDisplayY
_name.category_id                       chemical_conn_atom
_name.attribute_id                      display_y
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:1.0 
save_


save_chemical_conn_atom.NCA
_definition.id                          '_chemical_conn_atom.NCA'
_definition.update                      2000-11-03
_description.text
;
     The number of connected atoms excluding terminal hydrogen atoms.
;
_description.compact                    ChemConnAtomNCA
_name.category_id                       chemical_conn_atom
_name.attribute_id                      NCA
_type.container                         Single
_type.value                             Integer
_enumeration.range                      0:0 
save_


save_chemical_conn_atom.NH
_definition.id                          '_chemical_conn_atom.NH'
_definition.update                      2000-11-03
_description.text
;
     The total number of hydrogen atoms attached to this atom,
     regardless of whether they are included in the refinement or
     the atom_site list. This number will be the same as
     _atom_site.attached_hydrogens only if none of the hydrogen
     atoms appear in the atom_site list.
;
_description.compact                    ChemConnAtomNH
_name.category_id                       chemical_conn_atom
_name.attribute_id                      NH
_type.container                         Single
_type.value                             Integer
_enumeration.range                      0:0 
save_


save_chemical_conn_atom.number
_definition.id                          '_chemical_conn_atom.number'
_definition.update                      2000-11-03
_description.text
;
     The chemical sequence number to be associated with this atom.
;
_description.compact                    ChemConnAtomNumber
_name.category_id                       chemical_conn_atom
_name.attribute_id                      number
_type.container                         Single
_type.value                             Integer
_type.purpose                           Index
_enumeration.range                      1:1 
save_


save_chemical_conn_atom.type_symbol
_definition.id                          '_chemical_conn_atom.type_symbol'
_definition.update                      2000-11-03
_description.text
;
     A code identifying the atom type.
;
_description.compact                    ChemConnAtomType
_name.category_id                       chemical_conn_atom
_name.attribute_id                      type_symbol
_name.linked_item_id                    '_atom_type.symbol'
_type.container                         Single
_type.value                             Uchar
save_

#----------------------------------------------------------------------------

save_CHEMICAL_CONN_BOND
_definition.id                          chemical_conn_bond
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the connections between
     the atoms sites in the chemical_conn_atom list and the nature
     of the chemical bond between these atoms.
;
_description.compact                    ChemConnBondList
_category.parent_id                     chemical
_category_key.item_id                   '_chemical_conn_bond.id'
save_


save_chemical_conn_bond.atom_1
_definition.id                          '_chemical_conn_bond.atom_1'
_definition.update                      2000-11-03
_description.text
;
     Sequence numbers that form the bond connecting two atom sites.
;
_name.category_id                       chemical_conn_bond
_name.attribute_id                      atom_1
_name.linked_item_id                    '_chemical_conn_atom.number'
_type.container                         Single
_type.value                             Integer
save_


save_chemical_conn_bond.atom_2
_definition.id                          '_chemical_conn_bond.atom_2'
_definition.update                      2000-11-03
_description.text
;
     Sequence numbers that form the bond connecting two atom sites.
;
_name.category_id                       chemical_conn_bond
_name.linked_item_id                    '_chemical_conn_atom.number'
_name.attribute_id                      atom_2
_type.container                         Single
_type.value                             Integer
save_


save_chemical_conn_bond.id
_definition.id                          '_chemical_conn_bond.id'
_definition.update                      2000-11-03
_description.text
;
     Bond identifier composed of a tuple of two sequence numbers
     specified as _chemical_conn_atom.number values.
;
_description.compact                    ChemConnBondId
_name.category_id                       chemical_conn_bond
_name.attribute_id                      id
_type.container                         Tuple
_type.value                             Integer
_type_array.dimension                   [2]
_method.expression
;
    With  c  as  chemical_conn_bond
 
    _chemical_conn_bond.id <- Tuple ( [c.atom_1, c.atom_2] )
;
save_


save_chemical_conn_bond.type
_definition.id                          '_chemical_conn_bond.type'
_definition.update                      2000-11-03
_description.text
;
     Code for the chemical bond type.
;
_description.compact                    ChemConnBondType
_name.category_id                       chemical_conn_bond
_name.attribute_id                      type
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
sing 'single bond'
doub 'double bond'
trip 'triple bond'
quad 'quadruple bond'
arom 'aromatic bond'
poly 'polymeric bond'
delo 'delocalized double bond'
pi 'pi bond'
_enumeration.default                    sing
save_

#----------------------------------------------------------------------------

save_CHEMICAL_FORMULA
_definition.id                          chemical_formula
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the composition and chemical
     properties of the compound. The formula data items must agree
     with those that specify the density, unit-cell and Z values.
 
     The following rules apply to the construction of the data items
     _chemical_formula.analytical, *.structural and *.sum. For the
     data item *.moiety the formula construction is broken up into
     residues or moieties, i.e. groups of atoms that form a molecular
     unit or molecular ion. The  rules given below apply within each
     moiety but different requirements apply to the way that moieties
     are connected (see _chemical_formula.moiety).
 
     1. Only recognized element symbols may be used.
 
     2. Each element symbol is followed by a 'count' number. A count of
        '1' may be omitted.
 
     3. A space or parenthesis must separate each cluster of (element
        symbol + count).
 
     4. Where a group of elements is enclosed in parentheses, the
        multiplier for the group must follow the closing parentheses.
        That is, all element and group multipliers are assumed to be
        printed as subscripted numbers. [An exception to this rule
        exists for *.moiety formulae where pre- and post-multipliers
        are permitted for molecular units].
 
     5. Unless the elements are ordered in a manner that corresponds to
        their chemical structure, as in _chemical_formula.structural,
        the order of the elements within any group or moiety
        depends on whether or not carbon is present. If carbon is
        present, the order should be: C, then H, then the other
        elements in alphabetical order of their symbol. If carbon is
        not present, the elements are listed purely in alphabetic order
        of their symbol. This is the 'Hill' system used by Chemical
        Abstracts. This ordering is used in _chemical_formula.moiety
        and _chemical_formula.sum.
 
           _chemical_formula.iupac      '[Mo (C O)4 (C18 H33 P)2]'
           _chemical_formula.moiety     'C40 H66 Mo O4 P2'
           _chemical_formula.structural '((C O)4 (P (C6 H11)3)2)Mo'
           _chemical_formula.sum         'C40 H66 Mo O4 P2'
           _chemical_formula.weight      768.81
;
_category.parent_id                     chemical
save_


save_chemical_formula.analytical
_definition.id                          '_chemical_formula.analytical'
_definition.update                      2000-11-03
_description.text
;
     Formula determined by standard chemical analysis including trace
     elements. Parentheses are used only for standard uncertainties (su's).
;
_description.compact                    ChemFormulaAnalytical
_name.category_id                       chemical_formula
_name.attribute_id                      analytical
_type.container                         Single
_type.value                             Uchar
_description_example.case               'Fe2.45(2)  Ni1.60(3)  S4'
save_


save_chemical_formula.iupac
_definition.id                          '_chemical_formula.iupac'
_definition.update                      2000-11-03
_description.text
;
     Formula expressed in conformance with IUPAC rules for inorganic
     and metal-organic compounds where these conflict with the rules
     for any other chemical_formula entries. Typically used for
     formatting a formula in accordance with journal rules. This
     should appear in the data block in addition to the most
     appropriate of the other chemical_formula data names.
     Ref: IUPAC (1990). Nomenclature of Inorganic Chemistry.
          Oxford: Blackwell Scientific Publications.
;
_description.compact                    ChemFormulaIupac
_name.category_id                       chemical_formula
_name.attribute_id                      iupac
_type.container                         Single
_type.value                             Uchar
_description_example.case               '[Co Re (C12 H22 P)2 (C O)6].0.5C H3 O H'
save_


save_chemical_formula.moiety
_definition.id                          '_chemical_formula.moiety'
_definition.update                      2000-11-03
_description.text
;
     Formula with each discrete bonded residue or ion shown as a
     separate moiety. See above CHEMICAL_FORMULA for rules
     for writing chemical formulae. In addition to the general
     formulae requirements, the following rules apply:
        1. Moieties are separated by commas ','.
        2. The order of elements within a moiety follows general rule
           5 in CHEMICAL_FORMULA.
        3. Parentheses are not used within moieties but may surround
           a moiety. Parentheses may not be nested.
        4. Charges should be placed at the end of the moiety. The
           Singlege '+' or '-' may be preceded by a numerical multiplier
           and should be separated from the last (element symbol +
           count) by a space. Pre- or post-multipliers may be used for
           individual moieties.
;
_description.compact                    ChemFormulaMoiety
_name.category_id                       chemical_formula
_name.attribute_id                      moiety
_type.container                         Single
_type.value                             Uchar
loop_
_description_example.case
'C7 H4 Cl Hg N O3 S'
'C12 H17 N4 O S 1+, C6 H2 N3 O7 1-'
'C12 H16 N2 O6, 5(H2 O1)'
'(Cd 2+)3, (C6 N6 Cr 3-)2, 2(H2 O)'
save_


save_chemical_formula.structural
_definition.id                          '_chemical_formula.structural'
_definition.update                      2000-11-03
_description.text
;
     This formula should correspond to the structure as reported, i.e.
     trace elements not included in atom type and atom site lists should
     not be included.
;
_description.compact                    ChemFormulaStructural
_name.category_id                       chemical_formula
_name.attribute_id                      structural
_type.container                         Single
_type.value                             Uchar
_description_example.case               '(Pt (N H3)2 (C5 H7 N3 O)2) (Cl O4)2'
save_


save_chemical_formula.sum
_definition.id                          '_chemical_formula.sum'
_definition.update                      2000-11-03
_description.text
;
     Chemical formulae in which all discrete bonded residues and ions are
     summed over the constituent elements, following the ordering given
     in rule 5 of the CATEGORY description.
;
_description.compact                    ChemFormulaSum
_name.category_id                       chemical_formula
_name.attribute_id                      sum
_type.container                         Single
_type.value                             Uchar
_description_example.case               'C18 H19 N7 O8 S'
save_


save_chemical_formula.weight
_definition.id                          '_chemical_formula.weight'
_definition.update                      2000-11-03
_description.text
;
     Mass of the formula specified in one or more of the chemical_formula
     data items which leads to the density in _exptl_crystal.density_diffrn.
;
_description.compact                    ChemFormulaWeight
_name.category_id                       chemical_formula
_name.attribute_id                      weight
_type.container                         Single
_type.value                             Real
_enumeration.range                      1.0:1.0 
_units.code                             daltons
save_


save_chemical_formula.weight_meas
_definition.id                          '_chemical_formula.weight_meas'
_definition.update                      2000-11-03
_description.text
;
     Formula mass measured by a non-diffraction experiment.
;
_description.compact                    ChemFormulaWeightMeas
_name.category_id                       chemical_formula
_name.attribute_id                      weight_meas
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      1.0:1.0 
_units.code                             daltons
save_

#============================================================================

save_DIFFRN
_definition.id                          diffrn
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the diffraction experiment.
;
_category.parent_id                     diffraction
save_


save_diffrn.ambient_pressure
_definition.id                          '_diffrn.ambient_pressure'
_definition.update                      2000-11-03
_description.text
;
     The mean pressure at which the diffraction intensities were measured.
;
_description.compact                    AmbientPressure
_name.category_id                       diffrn
_name.attribute_id                      ambient_pressure
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             kilopascals
save_


save_diffrn.ambient_temperature
_definition.id                          '_diffrn.ambient_temperature'
_definition.update                      2000-11-03
_description.text
;
     The mean temperature at which the diffraction intensities were measured.
;
_description.compact                    AmbientTemperature
_name.category_id                       diffrn
_name.attribute_id                      ambient_temperature
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             kelvins
save_


save_diffrn.crystal_treatment
_definition.id                          '_diffrn.crystal_treatment'
_definition.update                      2000-11-03
_description.text
;
     Remarks about how the crystal was treated prior to intensity measurement.
     Particularly relevant when intensities were measured at low temperature.
;
_description.compact                    CrystalTreatment
_name.category_id                       diffrn
_name.attribute_id                      crystal_treatment
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'equilibrated in hutch for 24 hours'
'flash frozen in liquid nitrogen'
'slow cooled with direct air stream'
save_


save_diffrn.special_details
_definition.id                          '_diffrn.special_details'
_definition.update                      2000-11-03
_description.text
;
     Special details of the diffraction measurement process. Should include
     information about source instability, crystal motion, degradation, etc.
;
_description.compact                    DiffrnMeasDetails
_name.category_id                       diffrn
_name.attribute_id                      special_details
_type.container                         Single
_type.value                             Char
_description_example.case
;
     The results may not be entirely reliable as the measurement was
     made during a heat wave when the air-conditioning had failed.
;
save_


save_diffrn.symmetry_description
_definition.id                          '_diffrn.symmetry_description'
_definition.update                      2000-11-03
_description.text
;
     Observed diffraction point symmetry, systematic absences and possible
     space group(s) or superspace group(s) compatible with these.
;
_description.compact                    DiffrnSymmetryDetails
_name.category_id                       diffrn
_name.attribute_id                      symmetry_description
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------

save_DIFFRN_ATTENUATOR
_definition.id                          diffrn_attenuator
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the attenuators used in the
     diffraction source.
;
_category.parent_id                     diffrn
_category_key.item_id                   '_diffrn_attenuator.code'
save_


save_diffrn_attenuator.code
_definition.id                          '_diffrn_attenuator.code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a particular attenuator setting; referenced by the
     _diffrn_refln.attenuator_code which is stored with the intensities.
;
_description.compact                    DiffrnAttenuatorCode
_name.category_id                       diffrn_attenuator
_name.attribute_id                      code
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_diffrn_attenuator.material
_definition.id                          '_diffrn_attenuator.material'
_definition.update                      2000-11-03
_description.text
;
     Description of the material from which the attenuator is made.
;
_description.compact                    DiffrnAttenuator
_name.category_id                       diffrn_attenuator
_name.attribute_id                      material
_type.container                         Single
_type.value                             Char
save_


save_diffrn_attenuator.scale
_definition.id                          '_diffrn_attenuator.scale'
_definition.update                      2000-11-03
_description.text
;
     The scale factor applied to a measured intensity if it is reduced by
     an attenuator identified by _diffrn_attenuator.code.
;
_description.compact                    DiffrnAttenuatorScale
_name.category_id                       diffrn_attenuator
_name.attribute_id                      scale
_type.container                         Single
_type.value                             Real
_enumeration.range                      1.0:1.0 
save_

#----------------------------------------------------------------------

save_DIFFRN_DETECTOR
_definition.id                          diffrn_detector
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the detectors used in the
     in the measurement of diffraction intensities.
;
_category.parent_id                     diffrn
save_


save_diffrn_detector.description
_definition.id                          '_diffrn_detector.description'
_definition.update                      2001-10-02
_alias.definition_id                    '_diffrn_radiation.detector'
_description.text
;
     Description of the type of diffraction radiation detector.
;
_description.compact                    DetectorClass
_name.category_id                       diffrn_detector
_name.attribute_id                      description
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'photographic film'
'scintillation counter'
'CCD plate'
'BF~3~ counter'
save_


save_diffrn_detector.area_resol_mean
_definition.id                          '_diffrn_detector.area_resol_mean'
_definition.update                      2000-11-03
_description.text
;
     The resolution limit of an area diffraction radiation detector.
;
_description.compact                    DetectorResolLimit
_name.category_id                       diffrn_detector
_name.attribute_id                      area_resol_mean
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             pixels_per_millimetre
save_


save_diffrn_detector.details
_definition.id                          '_diffrn_detector.details'
_definition.update                      2000-11-03
_description.text
;
     Description of special aspects of the radiation detector.
;
_description.compact                    DetectorDetails
_name.category_id                       diffrn_detector
_name.attribute_id                      details
_type.container                         Single
_type.value                             Char
save_


save_diffrn_detector.dtime
_definition.id                          '_diffrn_detector.dtime'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn_radiation.detector_dtime'
_description.text
;
     The maximum time between two detector signals that cannot be resolved.
;
_description.compact                    DetectorDeadTime
_name.category_id                       diffrn_detector
_name.attribute_id                      dtime
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             microseconds
save_


save_diffrn_detector.make
_definition.id                          '_diffrn_detector.make'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn_detector.type'
_description.text
;
     The make, model or name of the diffraction radiation detector.
;
_description.compact                    DetectorMake
_name.category_id                       diffrn_detector
_name.attribute_id                      make
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------------

save_DIFFRN_MEASUREMENT
_definition.id                          diffrn_measurement
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the details of the
     diffraction measurement.
;
_category.parent_id                     diffrn
save_


save_diffrn.measurement_details
_definition.id                          '_diffrn.measurement_details'
_definition.update                      2000-11-03
_description.text
;
     Description of special aspects of the diffraction measurement.
;
_description.compact                    DiffrnMeasDetails
_name.category_id                       diffrn
_name.attribute_id                      measurement_details
_type.container                         Single
_type.value                             Char
_description_example.case               '440 frames of 0.25\%'
save_


save_diffrn.measurement_device_class
_definition.id                          '_diffrn.measurement_device_class'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn.measurement_device'
_description.text
;
     Type of goniometer device used to mount and orient the specimen.
;
_description.compact                    DiffrnMeasDeviceClass
_name.category_id                       diffrn
_name.attribute_id                      measurement_device_class
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'three-circle diffractometer'
'four-circle diffractometer'
'\k-geometry diffractometer'
'oscillation camera'
'precession camera'
save_


save_diffrn.measurement_device_details
_definition.id                          '_diffrn.measurement_device_details'
_definition.update                      2000-11-03
_description.text
;
     Details of the goniometer device used in the diffraction experiment.
;
_description.compact                    DiffrnMeasDeviceDetails
_name.category_id                       diffrn
_name.attribute_id                      measurement_device_details
_type.container                         Single
_type.value                             Char
_description_example.case
;
                                 commercial goniometer modified locally to
                                 allow for 90\% \t arc
;
save_


save_diffrn.measurement_device_make
_definition.id                          '_diffrn.measurement_device_make'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn.measurement_device_type'
_description.text
;
     The make, model or name of the goniometer device used.
;
_description.compact                    DiffrnMeasDeviceMake
_name.category_id                       diffrn
_name.attribute_id                      measurement_device_make
_type.container                         Single
_type.value                             Char
save_


save_diffrn.measurement_method
_definition.id                          '_diffrn.measurement_method'
_definition.update                      2000-11-03
_description.text
;
     Description of scan method used to measure diffraction intensities.
;
_description.compact                    DiffrnMeasMethod
_name.category_id                       diffrn
_name.attribute_id                      measurement_method
_type.container                         Single
_type.value                             Char
_description_example.case               'profile data from \q/2\q scans'
save_


save_diffrn.measurement_specimen_support
_definition.id                          '_diffrn.measurement_specimen_support'
_definition.update                      2000-11-03
_description.text
;
     Mounting method for the crystal specimum during data collection.
;
_description.compact                    DiffrnSpecimumMount
_name.category_id                       diffrn
_name.attribute_id                      measurement_specimen_support
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'glass capillary'
'quartz capillary'
fiber
'metal loop'
save_

#----------------------------------------------------------------------------

save_DIFFRN_ORIENT
_definition.id                          diffrn_orient
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the orientation of the crystal
     axes to the diffractometer goniometer.
;
_category.parent_id                     diffrn
save_

#----------------------------------------------------------------------------

save_DIFFRN_ORIENT_MATRIX
_definition.id                          diffrn_orient_matrix
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the matrix specifying the
     orientation of the crystal axes to the diffractometer goniometer.
;
_category.parent_id                     diffrn_orient
save_


save_diffrn_orient_matrix.type
_definition.id                          '_diffrn_orient_matrix.type'
_definition.update                      2000-11-03
_description.text
;
     Description of orientation matrix and how it should be applied to define
     the orientation of the crystal with respect to the diffractometer axes.
;
_description.compact                    DiffrnOrientMatrixType
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      type
_type.container                         Single
_type.value                             Char
save_


save_diffrn_orient_matrix.UBIJ
_definition.id                          '_diffrn_orient_matrix.UBIJ'
_definition.update                      2000-11-03
_description.text
;
     The 3x3 matrix specifying the orientation of the crystal with
     respect to the diffractometer axes.
;
_description.compact                    DiffrnOrientMatrix
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UBIJ
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3,3]
_method.expression
;
     With  o  as  diffrn_orient_matrix
 
      _diffrn_orient_matrix.UBIJ  <-  Matrix([[ o.ub_11, o.ub_12, o.ub_13 ],
                                              [ o.ub_21, o.ub_22, o.ub_23 ],
                                              [ o.ub_31, o.ub_32, o.ub_33 ]])
;
save_


save_diffrn_orient_matrix.UB_11
_definition.id                          '_diffrn_orient_matrix.UB_11'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UB_11
save_


save_diffrn_orient_matrix.UB_12
_definition.id                          '_diffrn_orient_matrix.UB_12'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UB_12
save_


save_diffrn_orient_matrix.UB_13
_definition.id                          '_diffrn_orient_matrix.UB_13'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UB_13
save_


save_diffrn_orient_matrix.UB_21
_definition.id                          '_diffrn_orient_matrix.UB_21'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UB_21
save_


save_diffrn_orient_matrix.UB_22
_definition.id                          '_diffrn_orient_matrix.UB_22'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UB_22
save_


save_diffrn_orient_matrix.UB_23
_definition.id                          '_diffrn_orient_matrix.UB_23'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UB_23
save_


save_diffrn_orient_matrix.UB_31
_definition.id                          '_diffrn_orient_matrix.UB_31'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UB_31
save_


save_diffrn_orient_matrix.UB_32
_definition.id                          '_diffrn_orient_matrix.UB_32'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UB_32
save_


save_diffrn_orient_matrix.UB_33
_definition.id                          '_diffrn_orient_matrix.UB_33'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_orient_matrix
_name.attribute_id                      UB_33
save_

#----------------------------------------------------------------------------

save_DIFFRN_ORIENT_REFLN
_definition.id                          diffrn_orient_refln
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the reflections used to
     calculate the matrix which gives the orientation of the crystal
     axes to the diffractometer goniometer.
;
_category.parent_id                     diffrn_orient
_category_key.item_id                   '_diffrn_orient_refln.hkl'
save_


save_diffrn_orient_refln.angle_chi
_definition.id                          '_diffrn_orient_refln.angle_chi'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      angle_chi
save_


save_diffrn_orient_refln.angle_kappa
_definition.id                          '_diffrn_orient_refln.angle_kappa'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      angle_kappa
save_


save_diffrn_orient_refln.angle_omega
_definition.id                          '_diffrn_orient_refln.angle_omega'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      angle_omega
save_


save_diffrn_orient_refln.angle_phi
_definition.id                          '_diffrn_orient_refln.angle_phi'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      angle_phi
save_


save_diffrn_orient_refln.angle_psi
_definition.id                          '_diffrn_orient_refln.angle_psi'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      angle_psi
save_


save_diffrn_orient_refln.angle_theta
_definition.id                          '_diffrn_orient_refln.angle_theta'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      angle_theta
save_


save_diffrn_orient_refln.hkl
_definition.id                          '_diffrn_orient_refln.hkl'
_definition.update                      2000-11-03
_description.text
;
     Miller indices of a reflection used to define the orientation matrix.
;
_description.compact                    DiffrnOrientReflnHkl
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      hkl
_type.container                         Vector
_type.value                             Integer
_type_array.dimension                   [3]
_method.expression
;
     With a as diffrn_orient_refln
 
       _diffrn_orient_refln.hkl <- Vector([a.index_h, a.index_k, a.index_l])
;
save_


save_diffrn_orient_refln.index_h
_definition.id                          '_diffrn_orient_refln.index_h'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      index_h
save_


save_diffrn_orient_refln.index_k
_definition.id                          '_diffrn_orient_refln.index_k'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      index_k
save_


save_diffrn_orient_refln.index_l
_definition.id                          '_diffrn_orient_refln.index_l'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_orient_refln
_name.attribute_id                      index_l
save_

#----------------------------------------------------------------------------

save_DIFFRN_RADIATION
_definition.id                          diffrn_radiation
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the wavelength of the
     radiation used in measuring diffraction intensities. Items may be
     looped to identify and assign weights to distinct wavelength
     components from a polychromatic beam.
;
_category.parent_id                     diffrn
save_


save_diffrn_radiation.collimation
_definition.id                          '_diffrn_radiation.collimation'
_definition.update                      2000-11-03
_description.text
;
     Description of the collimation or focusing applied to the radiation.
;
_description.compact                    RadCollimator
_name.category_id                       diffrn_radiation
_name.attribute_id                      collimation
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'0.3 mm double-pinhole'
'0.5 mm'
'focusing mirrors'
save_


save_diffrn_radiation.filter_edge
_definition.id                          '_diffrn_radiation.filter_edge'
_definition.update                      2000-11-03
_description.text
;
     Absorption edge of the radiation filter used.
;
_description.compact                    RadFilter
_name.category_id                       diffrn_radiation
_name.attribute_id                      filter_edge
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_diffrn_radiation.inhomogeneity
_definition.id                          '_diffrn_radiation.inhomogeneity'
_definition.update                      2000-11-03
_description.text
;
     Half-width of the incident beam perpendicular to the diffraction plane.
;
_description.compact                    RadHalfWidth
_name.category_id                       diffrn_radiation
_name.attribute_id                      inhomogeneity
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             millimetres
save_


save_diffrn_radiation.monochromator
_definition.id                          '_diffrn_radiation.monochromator'
_definition.update                      2000-11-03
_description.text
;
     Description of the method used to obtain monochromatic radiation.
     If a monochromator crystal is used the material and the indices of
     the Bragg reflection are specified.
;
_description.compact                    RadMonochromator
_name.category_id                       diffrn_radiation
_name.attribute_id                      monochromator
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'Zr filter'
'Ge 220'
none
'equatorial mounted graphite'
save_


save_diffrn_radiation.polarisn_norm
_definition.id                          '_diffrn_radiation.polarisn_norm'
_definition.update                      2000-11-03
_description.text
;
     The angle, as viewed from the specimen, between the perpendicular
     component of the polarisation and the diffraction plane.
;
_description.compact                    RadPolarizNorm
_name.category_id                       diffrn_radiation
_name.attribute_id                      polarisn_norm
_type.container                         Single
_type.value                             Real
_enumeration.range                      -180.0:180.0 
_units.code                             degrees
save_


save_diffrn_radiation.polarisn_ratio
_definition.id                          '_diffrn_radiation.polarisn_ratio'
_definition.update                      2000-11-03
_description.text
;
     Polarisation ratio of the diffraction beam incident on the crystal.
     It is the ratio of the perpendicularly polarised to the parallel
     polarised component of the radiation. The perpendicular component
     forms an angle of _diffrn_radiation.polarisn_norm to the normal to
     the diffraction plane of the sample (i.e. the plane containing the
     incident and reflected beams).
;
_description.compact                    RadPolarizRatio
_name.category_id                       diffrn_radiation
_name.attribute_id                      polarisn_ratio
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_diffrn_radiation.probe
_definition.id                          '_diffrn_radiation.probe'
_definition.update                      2000-11-03
_description.text
;
     General description of the radiation used (i.e. name of subatomic
     particle or region of the electromagnetic spectrum).
;
_description.compact                    RadDescription
_name.category_id                       diffrn_radiation
_name.attribute_id                      probe
_type.container                         Single
_type.value                             Char
loop_
_enumeration_set.code
x-ray
neutron
electron
gamma
_enumeration.default                    x-ray
save_


save_diffrn_radiation.type
_definition.id                          '_diffrn_radiation.type'
_definition.update                      2000-11-03
_description.text
;
     Description of the radiation type. Detailed information on the
     description in _diffrn_radiation.probe.
;
_description.compact                    RadType
_name.category_id                       diffrn_radiation
_name.attribute_id                      type
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'Cu K\a'
'Cu K\a~1~'
'Cu K-L~2,3~'
white-beam
save_


save_diffrn_radiation.xray_symbol
_definition.id                          '_diffrn_radiation.xray_symbol'
_definition.update                      2000-11-03
_description.text
;
     IUPAC symbol for the X-ray wavelength for probe radiation.
;
_description.compact                    RadXraySymbol
_name.category_id                       diffrn_radiation
_name.attribute_id                      xray_symbol
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
K-L~3~ 'K\a~1~ in older Siegbahn notation'
K-L~2~ 'K\a~2~ in older Siegbahn notation'
K-M~3~ 'K\b~1~ in older Siegbahn notation'
K-L~2,3~ 'use where K-L~3~ and K-L~2~ are not resolved'
_enumeration.default                    K-L~3~
save_

#----------------------------------------------------------------------------

save_DIFFRN_RADIATION_WAVELENGTH
_definition.id                          diffrn_radiation_wavelength
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the wavelength of the
     radiation used in measuring diffraction intensities. Items may be
     looped to identify and assign weights to distinct wavelength
     components from a polychromatic beam.
;
_category.parent_id                     diffrn_radiation
_category_key.item_id                   '_diffrn_radiation_wavelength.id'
save_


save_diffrn_radiation_wavelength.value
_definition.id                          '_diffrn_radiation_wavelength.value'
_definition.update                      2000-11-03
#   _alias.definition_id       '_diffrn_radiation_wavelength' ##<<<<!!!!????
_description.text
;
     Wavelength of radiation used in diffraction measurements.
;
_description.compact                    RadWaveLength
_name.category_id                       diffrn_radiation_wavelength
_name.attribute_id                      value
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_diffrn_radiation_wavelength.id
_definition.id                          '_diffrn_radiation_wavelength.id'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a radiation used in the diffraction measurements.
     This is linked to _diffrn_refln.wavelength_id and _refln.wavelength_id
;
_description.compact                    RadWaveLengthId
_name.category_id                       diffrn_radiation_wavelength
_name.attribute_id                      id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
_description_example.case               x2
save_


save_diffrn_radiation_wavelength.wt
_definition.id                          '_diffrn_radiation_wavelength.wt'
_definition.update                      2000-11-03
_description.text
;
     Relative intensity of a radiation used in the diffraction measurements.
;
_description.compact                    RadWaveLengthWeight
_name.category_id                       diffrn_radiation_wavelength
_name.attribute_id                      wt
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:1.0 
_enumeration.default                    1.0
save_

#-----------------------------------------------------------------------------

save_DIFFRN_REFLN
_definition.id                          diffrn_refln
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the reflection measurements,
     prior to data reduction and merging.
;
_description.compact                    DiffrnReflnList
_category.parent_id                     diffrn
_category_key.item_id                   '_diffrn_refln.hkl'
save_


save_diffrn_refln.angle_chi
_definition.id                          '_diffrn_refln.angle_chi'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_refln
_name.attribute_id                      angle_chi
save_


save_diffrn_refln.angle_kappa
_definition.id                          '_diffrn_refln.angle_kappa'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_refln
_name.attribute_id                      angle_kappa
save_


save_diffrn_refln.angle_omega
_definition.id                          '_diffrn_refln.angle_omega'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_refln
_name.attribute_id                      angle_omega
save_


save_diffrn_refln.angle_phi
_definition.id                          '_diffrn_refln.angle_phi'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_refln
_name.attribute_id                      angle_phi
save_


save_diffrn_refln.angle_psi
_definition.id                          '_diffrn_refln.angle_psi'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_refln
_name.attribute_id                      angle_psi
save_


save_diffrn_refln.angle_theta
_definition.id                          '_diffrn_refln.angle_theta'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       diffrn_refln
_name.attribute_id                      angle_theta
save_


save_diffrn_refln.attenuator_code
_definition.id                          '_diffrn_refln.attenuator_code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying any attenuator setting for this reflection.
;
_description.compact                    DiffrnReflnAttenCode
_name.category_id                       diffrn_refln
_name.attribute_id                      attenuator_code
_name.linked_item_id                    '_diffrn_attenuator.code'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_diffrn_refln.class_code
_definition.id                          '_diffrn_refln.class_code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a relection class, if assigned. e.g. modulated structures
;
_description.compact                    DiffrnReflnClass
_name.category_id                       diffrn_refln
_name.attribute_id                      class_code
_name.linked_item_id                    '_diffrn_reflns_class.code'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_diffrn_refln.counts_bg_1
_definition.id                          '_diffrn_refln.counts_bg_1'
_definition.import_id                   '_generic.diffractometer_counts'
_name.category_id                       diffrn_refln
_name.attribute_id                      counts_bg_1
_description.compact                    DiffrnReflnCountsBg1
save_


save_diffrn_refln.counts_bg_2
_definition.id                          '_diffrn_refln.counts_bg_2'
_definition.import_id                   '_generic.diffractometer_counts'
_name.category_id                       diffrn_refln
_name.attribute_id                      counts_bg_2
_description.compact                    DiffrnReflnCountsBg2
save_


save_diffrn_refln.counts_net
_definition.id                          '_diffrn_refln.counts_net'
_definition.import_id                   '_generic.diffractometer_counts'
_name.category_id                       diffrn_refln
_name.attribute_id                      counts_net
_description.compact                    DiffrnReflnCountsNet
save_


save_diffrn_refln.counts_peak
_definition.id                          '_diffrn_refln.counts_peak'
_definition.import_id                   '_generic.diffractometer_counts'
_name.category_id                       diffrn_refln
_name.attribute_id                      counts_peak
_description.compact                    DiffrnReflnCountsPeak
save_


save_diffrn_refln.counts_total
_definition.id                          '_diffrn_refln.counts_total'
_definition.import_id                   '_generic.diffractometer_counts'
_name.category_id                       diffrn_refln
_name.attribute_id                      counts_total
_description.compact                    DiffrnReflnCountsTotal
save_


save_diffrn_refln.crystal_id
_definition.id                          '_diffrn_refln.crystal_id'
_definition.update                      2000-11-03
_description.text
;
     Name identifying each crystal if multiple crystals are used.
;
_description.compact                    DiffrnReflnCrystalId
_name.category_id                       diffrn_refln
_name.attribute_id                      crystal_id
_name.linked_item_id                    '_exptl_crystal.id'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_diffrn_refln.detect_slit_horiz
_definition.id                          '_diffrn_refln.detect_slit_horiz'
_definition.update                      2000-11-03
_description.text
;
     Total slit aperture angle in the diffraction plane.
;
_description.compact                    DiffrnReflnDetectSlitHoriz
_name.category_id                       diffrn_refln
_name.attribute_id                      detect_slit_horiz
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:90.0 
_units.code                             degrees
save_


save_diffrn_refln.detect_slit_vert
_definition.id                          '_diffrn_refln.detect_slit_vert'
_definition.update                      2000-11-03
_description.text
;
     Total slit aperture angle perpendicular to the diffraction plane.
;
_description.compact                    DiffrnReflnDetectSlitVert
_name.category_id                       diffrn_refln
_name.attribute_id                      detect_slit_vert
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:90.0 
_units.code                             degrees
save_


save_diffrn_refln.elapsed_time
_definition.id                          '_diffrn_refln.elapsed_time'
_definition.update                      2000-11-03
_description.text
;
     Elapsed time from the start to the end of the intensity measurement.
;
_description.compact                    DiffrnReflnElapseTime
_name.category_id                       diffrn_refln
_name.attribute_id                      elapsed_time
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             minutes
save_


save_diffrn_refln.hkl
_definition.id                          '_diffrn_refln.hkl'
_definition.update                      2000-11-03
_description.text
;
     Miller indices of a measured reflection. These need not match the
     _refln.hkl values if a transformation of the original measured
     cell has taken place.
;
_description.compact                    DiffrnReflnHkl
_name.category_id                       diffrn_refln
_name.attribute_id                      hkl
_type.container                         Vector
_type.value                             Real
_type_array.dimension                   [3]
_method.expression
;
     With a as diffrn_refln
 
           _diffrn_refln.hkl <- Vector( [a.index_h, a.index_h, a.index_l] )
;
save_


save_diffrn_refln.index_h
_definition.id                          '_diffrn_refln.index_h'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_refln
_name.attribute_id                      index_h
save_


save_diffrn_refln.index_k
_definition.id                          '_diffrn_refln.index_k'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_refln
_name.attribute_id                      index_k
save_


save_diffrn_refln.index_l
_definition.id                          '_diffrn_refln.index_l'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_refln
_name.attribute_id                      index_l
save_


save_diffrn_refln.intensity_net
_definition.id                          '_diffrn_refln.intensity_net'
_definition.update                      2000-11-03
_description.text
;
     Net intensity calculated from the diffraction counts after the
     attenuator and standard scales have been applied.
;
_description.compact                    DiffrnReflnInet
_name.category_id                       diffrn_refln
_name.attribute_id                      intensity_net
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
save_


save_diffrn_refln.scale_group_code
_definition.id                          '_diffrn_refln.scale_group_code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying the scale applying to this reflection.
;
_description.compact                    DiffrnReflnScaleGroup
_name.category_id                       diffrn_refln
_name.attribute_id                      scale_group_code
_name.linked_item_id                    '_diffrn_scale_group.code'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_diffrn_refln.scan_mode
_definition.id                          '_diffrn_refln.scan_mode'
_definition.update                      2000-11-03
_description.text
;
     Code identifying the mode of scanning with a diffractometer.
     See also  _diffrn_refln.scan_width and _diffrn_refln.scan_mode_backgd.
;
_description.compact                    DiffrnReflnScanMode
_name.category_id                       diffrn_refln
_name.attribute_id                      scan_mode
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
om 'omega scan'
ot 'omega/2theta scan'
q 'Q-scans (arbitrary reciprocal directions)'
_enumeration.default                    ot
save_


save_diffrn_refln.scan_mode_backgd
_definition.id                          '_diffrn_refln.scan_mode_backgd'
_definition.update                      2000-11-03
_description.text
;
     Code identifying mode of scanning to measure the background intensity.
;
_description.compact                    DiffrnReflnScanModeBgd
_name.category_id                       diffrn_refln
_name.attribute_id                      scan_mode_backgd
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
st 'stationary counter background'
mo 'moving counter background'
_enumeration.default                    st
save_


save_diffrn_refln.scan_rate
_definition.id                          '_diffrn_refln.scan_rate'
_definition.update                      2000-11-03
_description.text
;
     Angular rate of scanning a reflection to measure the intensity.
;
_description.compact                    DiffrnReflnScanRate
_name.category_id                       diffrn_refln
_name.attribute_id                      scan_rate
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             degrees_per_minute
save_


save_diffrn_refln.scan_time_backgd
_definition.id                          '_diffrn_refln.scan_time_backgd'
_definition.update                      2000-11-03
_description.text
;
     Time spent measuring background counts.
;
_description.compact                    DiffrnReflnScanTimeBgd
_name.category_id                       diffrn_refln
_name.attribute_id                      scan_time_backgd
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             seconds
save_


save_diffrn_refln.scan_width
_definition.id                          '_diffrn_refln.scan_width'
_definition.update                      2000-11-03
_description.text
;
     Angular scan width when measuring the peak intensity.
;
_description.compact                    DiffrnReflnScanWidth
_name.category_id                       diffrn_refln
_name.attribute_id                      scan_width
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:90.0 
_units.code                             degrees
save_


save_diffrn_refln.sin_theta_over_lambda
_definition.id                          '_diffrn_refln.sin_theta_over_lambda'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn_refln.sint/lambda'
_description.text
;
     (sin theta)/lambda value for this reflection.
;
_description.compact                    DiffrnReflnSinTheta/Lambda
_name.category_id                       diffrn_refln
_name.attribute_id                      sin_theta_over_lambda
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             reciprocal_angstroms
save_


save_diffrn_refln.standard_code
_definition.id                          '_diffrn_refln.standard_code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying if reflection was measured as a standard intensity.
     Must be '.' or match one of the _diffrn_standard_refln.code values.
;
_description.compact                    DiffrnReflnStandCode
_name.category_id                       diffrn_refln
_name.attribute_id                      standard_code
_name.linked_item_id                    '_diffrn_standard_refln.code'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_diffrn_refln.wavelength
_definition.id                          '_diffrn_refln.wavelength'
_definition.update                      2000-11-03
_description.text
;
     Mean wavelength of radiation used to measure this intensity.
;
_description.compact                    DiffrnReflnWaveLength
_name.category_id                       diffrn_refln
_name.attribute_id                      wavelength
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_diffrn_refln.wavelength_id
_definition.id                          '_diffrn_refln.wavelength_id'
_definition.update                      2000-11-03
_description.text
;
     Name identifying the wavelength in the diffrn_radiation_wavelength list.
;
_description.compact                    DiffrnReflnRadId
_name.category_id                       diffrn_refln
_name.attribute_id                      wavelength_id
_name.linked_item_id                    '_diffrn_radiation_wavelength.id'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_

#============================================================================

save_DIFFRN_REFLNS
_definition.id                          diffrn_reflns
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the overall reflection
     measurement information.
;
_category.parent_id                     diffrn
save_


save_diffrn_reflns.av_R_equivalents
_definition.id                          '_diffrn_reflns.av_R_equivalents'
_definition.update                      2000-11-03
_description.text
;
     The residual [sum av|del(I)| / sum |av(I)|] for symmetry-equivalent
     reflections used to calculate the average intensity av(I). The
     av|del(I)| term is the average absolute difference between av(I) and
     the individual symmetry-equivalent intensities.
;
_description.compact                    DiffrnResid(EquivI)
_name.category_id                       diffrn_reflns
_name.attribute_id                      av_R_equivalents
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_diffrn_reflns.av_sigmaI_over_netI
_definition.id                          '_diffrn_reflns.av_sigmaI_over_netI'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn_reflns.av_sigmaI/netI'
_description.text
;
     Measure [sum su(net I)|/sum|net I|] for all measured reflections.
;
_description.compact                    DiffrnRatio(sigI/netI)
_name.category_id                       diffrn_reflns
_name.attribute_id                      av_sigmaI_over_netI
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_diffrn_reflns.fraction_theta_full
_definition.id                          '_diffrn_reflns.fraction_theta_full'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn.measured_fraction_theta_full'
_description.text
;
      Fraction of unique (symmetry-independent) reflections measured
      out to _diffrn_reflns.theta_full.
;
_description.compact                    DiffrnCompletionThetaFull
_name.category_id                       diffrn_reflns
_name.attribute_id                      fraction_theta_full
_type.container                         Single
_type.value                             Real
_enumeration.range                      0:1.0 
save_


save_diffrn_reflns.fraction_theta_max
_definition.id                          '_diffrn_reflns.fraction_theta_max'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn.measured_fraction_theta_max'
_description.text
;
      Fraction of unique (symmetry-independent) reflections measured
          out to _diffrn_reflns.theta_max.
;
_description.compact                    DiffrnCompletionThetaMax
_name.category_id                       diffrn_reflns
_name.attribute_id                      fraction_theta_max
_type.container                         Single
_type.value                             Real
_enumeration.range                      0:1.0 
save_


save_diffrn_reflns.limit_h_max
_definition.id                          '_diffrn_reflns.limit_h_max'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_reflns
_name.attribute_id                      limit_h_max
save_


save_diffrn_reflns.limit_h_min
_definition.id                          '_diffrn_reflns.limit_h_min'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_reflns
_name.attribute_id                      limit_h_min
save_


save_diffrn_reflns.limit_k_max
_definition.id                          '_diffrn_reflns.limit_k_max'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_reflns
_name.attribute_id                      limit_k_max
save_


save_diffrn_reflns.limit_k_min
_definition.id                          '_diffrn_reflns.limit_k_min'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_reflns
_name.attribute_id                      limit_k_min
save_


save_diffrn_reflns.limit_l_max
_definition.id                          '_diffrn_reflns.limit_l_max'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_reflns
_name.attribute_id                      limit_l_max
save_


save_diffrn_reflns.limit_l_min
_definition.id                          '_diffrn_reflns.limit_l_min'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_reflns
_name.attribute_id                      limit_l_min
save_


save_diffrn_reflns.number
_definition.id                          '_diffrn_reflns.number'
_definition.update                      2000-11-03
_description.text
;
     Total number of measured intensities, excluding reflections that are
     classed as systematically absent arising from translational symmetry
     in the crystal unit cell.
;
_description.compact                    DiffrnReflnsCount
_name.category_id                       diffrn_reflns
_name.attribute_id                      number
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_diffrn_reflns.reduction_process
_definition.id                          '_diffrn_reflns.reduction_process'
_definition.update                      2000-11-03
_description.text
;
     Description of how intensities were reduced to structure-factor magnitudes.
;
_description.compact                    DiffrnReflnsReductionDetails
_name.category_id                       diffrn_reflns
_name.attribute_id                      reduction_process
_type.container                         Single
_type.value                             Char
_description_example.case               'data averaged using Fisher test'
save_


save_diffrn_reflns.theta_full
_definition.id                          '_diffrn_reflns.theta_full'
_definition.update                      2000-11-03
_description.text
;
     Theta angle at which the count of measured reflections is almost complete.
     The fraction of unique reflections measured out to this angle is given by
     _diffrn_reflns.fraction_theta_full.
;
_description.compact                    DiffrnThetaFull
_name.category_id                       diffrn_reflns
_name.attribute_id                      theta_full
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:90.0 
_units.code                             degrees
save_


save_diffrn_reflns.theta_max
_definition.id                          '_diffrn_reflns.theta_max'
_definition.update                      2000-11-03
_description.text
;
     Maximum theta angle of the measured reflections.
;
_description.compact                    DiffrnThetaMax
_name.category_id                       diffrn_reflns
_name.attribute_id                      theta_max
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:90.0 
_units.code                             degrees
save_


save_diffrn_reflns.theta_min
_definition.id                          '_diffrn_reflns.theta_min'
_definition.update                      2000-11-03
_description.text
;
     Minimum theta angle of the measured reflections.
;
_description.compact                    DiffrnThetaMin
_name.category_id                       diffrn_reflns
_name.attribute_id                      theta_min
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:90.0 
_units.code                             degrees
save_

#----------------------------------------------------------------------------

save_DIFFRN_REFLNS_TRANSF_MATRIX
_definition.id                          diffrn_reflns_transf_matrix
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the elements of the matrix
     used to transform the reflection indices _diffrn_refln.hkl
     into _refln.hkl.
                                 |11 12 13|
            (h k l) diffraction  |21 22 23|  =  (h' k' l')
                                 |31 32 33|
;
_category.parent_id                     diffrn_reflns
save_


save_diffrn_reflns_transf_matrix.TIJ
_definition.id                          '_diffrn_reflns_transf_matrix.TIJ'
_definition.update                      2000-11-03
_description.text
;
     Elements of the matrix used to transform the diffraction reflection
     indices _diffrn_refln.hkl into the _refln.hkl indices.
                                  |11 12 13|
             (h k l) diffraction  |21 22 23|  =  (h' k' l')
                                  |31 32 33|
;
_description.compact                    DiffrnReflnsTransformMatrix
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      TIJ
_type.container                         Matrix
_type.value                             Real
_type_array.dimension                   [3,3]
_method.expression
;
     With t as diffrn_reflns_transf_matrix
 
          _diffrn_reflns_transf_matrix.TIJ <- Matrix([[t.11, t.12, t.13],
                                                      [t.21, t.22, t.23],
                                                      [t.31, t.32, t.33]])
;
save_


save_diffrn_reflns_transf_matrix.11
_definition.id                          '_diffrn_reflns_transf_matrix.11'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      11
save_


save_diffrn_reflns_transf_matrix.12
_definition.id                          '_diffrn_reflns_transf_matrix.12'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      12
save_


save_diffrn_reflns_transf_matrix.13
_definition.id                          '_diffrn_reflns_transf_matrix.13'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      13
save_


save_diffrn_reflns_transf_matrix.21
_definition.id                          '_diffrn_reflns_transf_matrix.21'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      21
save_


save_diffrn_reflns_transf_matrix.22
_definition.id                          '_diffrn_reflns_transf_matrix.22'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      22
save_


save_diffrn_reflns_transf_matrix.23
_definition.id                          '_diffrn_reflns_transf_matrix.23'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      23
save_


save_diffrn_reflns_transf_matrix.31
_definition.id                          '_diffrn_reflns_transf_matrix.31'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      31
save_


save_diffrn_reflns_transf_matrix.32
_definition.id                          '_diffrn_reflns_transf_matrix.32'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      32
save_


save_diffrn_reflns_transf_matrix.33
_definition.id                          '_diffrn_reflns_transf_matrix.33'
_definition.import_id                   '_generic.orient_matrix_element'
_name.category_id                       diffrn_reflns_transf_matrix
_name.attribute_id                      33
save_

#============================================================================

save_DIFFRN_REFLNS_CLASS
_definition.id                          diffrn_reflns_class
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify different classes of
     reflections in the raw measured diffraction data.
 
;
_category.parent_id                     diffrn_reflns
_category_key.item_id                   '_diffrn_reflns_class.code'
save_


save_diffrn_reflns_class.av_R_eq
_definition.id                          '_diffrn_reflns_class.av_R_eq'
_definition.update                      2000-11-03
_description.text
;
     Residual [sum av|del(I)|/sum|av(I)|] for symmetry-equivalent reflections
     used to calculate the average intensity av(I). The av|del(I)| term is the
     average absolute difference between av(I) and the individual intensities.
;
_description.compact                    DiffrnShellResid(I)
_name.category_id                       diffrn_reflns_class
_name.attribute_id                      av_R_eq
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_diffrn_reflns_class.av_uI_over_I
_definition.id                          '_diffrn_reflns_class.av_uI_over_I'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn_reflns_class.av_sgI/I'
_description.text
;
     Measure [sum|su(net I)|/sum|net I|] for intensities in a reflection class.
;
_description.compact                    DiffrnShellRatio(suI/netI)
_name.category_id                       diffrn_reflns_class
_name.attribute_id                      av_uI_over_I
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_diffrn_reflns_class.code
_definition.id                          '_diffrn_reflns_class.code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a reflection class.
;
_description.compact                    DiffrnShellCode
_name.category_id                       diffrn_reflns_class
_name.attribute_id                      code
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
_description_example.case               m2
save_


save_diffrn_reflns_class.description
_definition.id                          '_diffrn_reflns_class.description'
_definition.update                      2000-11-03
_description.text
;
     Description of a reflection class.
;
_description.compact                    DiffrnShellDetails
_name.category_id                       diffrn_reflns_class
_name.attribute_id                      description
_type.container                         Single
_type.value                             Char
_description_example.case               'm=1 first order satellites'
save_


save_diffrn_reflns_class.d_res_high
_definition.id                          '_diffrn_reflns_class.d_res_high'
_definition.update                      2000-11-03
_description.text
;
     Highest resolution in reflection class i.e. smallest d value in class.
;
_description.compact                    DiffrnShellResolHi
_name.category_id                       diffrn_reflns_class
_name.attribute_id                      d_res_high
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_diffrn_reflns_class.d_res_low
_definition.id                          '_diffrn_reflns_class.d_res_low'
_definition.update                      2000-11-03
_description.text
;
     Lowest resolution in reflection class i.e. largest d value in class.
;
_description.compact                    DiffrnShellResolLo
_name.category_id                       diffrn_reflns_class
_name.attribute_id                      d_res_low
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_diffrn_reflns_class.number
_definition.id                          '_diffrn_reflns_class.number'
_definition.update                      2000-11-03
_description.text
;
     Number of measured intensities for a reflection class, excluding
     the systematic absences arising from centring translations.
;
_description.compact                    DiffrnShellNumber
_name.category_id                       diffrn_reflns_class
_name.attribute_id                      number
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_

#----------------------------------------------------------------------------

save_DIFFRN_SCALE_GROUP
_definition.id                          diffrn_scale_group
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the groups of reflections in
     the raw measured diffraction data with different relative scales.
;
_description.compact                    ScaleGroupList
_category.parent_id                     diffrn_reflns
_category_key.item_id                   '_diffrn_scale_group.code'
save_


save_diffrn_scale_group.code
_definition.id                          '_diffrn_scale_group.code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a specific scale group of reflections.
;
_description.compact                    ScaleGroupCode
_name.category_id                       diffrn_scale_group
_name.attribute_id                      code
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
_description_example.case               A
save_


save_diffrn_scale_group.I_net
_definition.id                          '_diffrn_scale_group.I_net'
_definition.update                      2000-11-03
_description.text
;
     Scale for a specific measurement group of eflections. Is multiplied
     with the net intensity to place all intensities on a common scale.
;
_description.compact                    ScaleGroupInet
_name.category_id                       diffrn_scale_group
_name.attribute_id                      I_net
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_

#----------------------------------------------------------------------------

save_DIFFRN_SOURCE
_definition.id                          diffrn_source
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify information about the
     radiation source.
;
_category.parent_id                     diffrn
save_


save_diffrn_source.device
_definition.id                          '_diffrn_source.device'
_definition.update                      2000-11-03
_description.text
;
     Identification of the device providing the source of radiation.
;
_description.compact                    RadSourceDevice
_name.category_id                       diffrn_source
_name.attribute_id                      device
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'sealed X-ray tube'
'nuclear reactor'
'spallation source'
'electron microscope'
'rotating-anode X-ray tube'
synchrotron
save_


save_diffrn_source.current
_definition.id                          '_diffrn_source.current'
_definition.update                      2000-11-03
_description.text
;
     Generator current at which the radiation source device was operated.
;
_description.compact                    RadSourceCurrent
_name.category_id                       diffrn_source
_name.attribute_id                      current
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             milliamperes
save_


save_diffrn_source.details
_definition.id                          '_diffrn_source.details'
_definition.update                      2000-11-03
_description.text
;
     General description of the radiation source device.
;
_description.compact                    RadSourceDetails
_name.category_id                       diffrn_source
_name.attribute_id                      details
_type.container                         Single
_type.value                             Char
save_


save_diffrn_source.power
_definition.id                          '_diffrn_source.power'
_definition.update                      2000-11-03
_description.text
;
     Generator power at which the radiation source device was operated.
;
_description.compact                    RadSourcePower
_name.category_id                       diffrn_source
_name.attribute_id                      power
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             kilowatts
save_


save_diffrn_source.size
_definition.id                          '_diffrn_source.size'
_definition.update                      2000-11-03
_description.text
;
     Description of the collimated source beam as viewed from the sample.
;
_description.compact                    RadSourceSize
_name.category_id                       diffrn_source
_name.attribute_id                      size
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'8mm x 0.4 mm fine-focus'
'broad focus'
save_


save_diffrn_source.target
_definition.id                          '_diffrn_source.target'
_definition.update                      2000-11-03
_description.text
;
     Chemical element symbol for the radiation source target (usually
     the anode). This can be used also for spallation sources.
;
_description.compact                    RadTargetElement
_name.category_id                       diffrn_source
_name.attribute_id                      target
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
H
He
Li
Be
B
C
N
O
F
Ne
Na
Mg
Al
Si
P
S
Cl
Ar
K
Ca
Sc
Ti
V
Cr
Mn
Fe
Co
Ni
Cu
Zn
Ga
Ge
As
Se
Br
Kr
Rb
Sr
Y
Zr
Nb
Mo
Tc
Ru
Rh
Pd
Ag
Cd
In
Sn
Sb
Te
I
Xe
Cs
Ba
La
Ce
Pr
Nd
Pm
Sm
Eu
Gd
Tb
Dy
Ho
Er
Tm
Yb
Lu
Hf
Ta
W
Re
Os
Ir
Pt
Au
Hg
Tl
Pb
Bi
Po
At
Rn
Fr
Ra
Ac
Th
Pa
U
Np
Pu
Am
Cm
Bk
Cf
Es
Fm
Md
No
Lr
_enumeration.default                    C
save_


save_diffrn_source.make
_definition.id                          '_diffrn_source.make'
_definition.update                      2000-11-03
_description.text
;
     Description of the make, model or name of the source device.
;
_description.compact                    RadDeviceMake
_name.category_id                       diffrn_source
_name.attribute_id                      make
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'NSLS beamline X8C'
'Rigaku RU200'
save_


save_diffrn_source.voltage
_definition.id                          '_diffrn_source.voltage'
_definition.update                      2000-11-03
_description.text
;
     Generator voltage at which the radiation source device was operated.
;
_description.compact                    RadSourceVoltage
_name.category_id                       diffrn_source
_name.attribute_id                      voltage
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             kilovolts
save_

#----------------------------------------------------------------------------

save_DIFFRN_STANDARDS
_definition.id                          diffrn_standards
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify information about the
     standard reflections used in the diffraction measurement process.
;
_category.parent_id                     diffrn
save_


save_diffrn_standards.decay_percent
_definition.id                          '_diffrn_standards.decay_percent'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn_standards.decay_%'
_description.text
;
     The percentage decrease in the mean of the intensities for the standard
     reflections at the start to the finish of the measurement process. This
     value affords a measure of the overall decay in crystal quality during
     measurement. Negative values only occur in exceptional instances where
     the final intensities are greater than the initial ones.
;
_description.compact                    DiffrnStandDecay%
_name.category_id                       diffrn_standards
_name.attribute_id                      decay_percent
_type.container                         Single
_type.value                             Real
_enumeration.range                      ?:100 
save_


save_diffrn_standards.interval_count
_definition.id                          '_diffrn_standards.interval_count'
_definition.update                      2000-11-03
_description.text
;
     Reflection count between the standard reflection measurements.
;
_description.compact                    DiffrnStandIntCount
_name.category_id                       diffrn_standards
_name.attribute_id                      interval_count
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_diffrn_standards.interval_time
_definition.id                          '_diffrn_standards.interval_time'
_definition.update                      2000-11-03
_description.text
;
     Time between the standard reflection measurements.
;
_description.compact                    DiffrnStandIntTime
_name.category_id                       diffrn_standards
_name.attribute_id                      interval_time
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.:0. 
_units.code                             seconds
save_


save_diffrn_standards.number
_definition.id                          '_diffrn_standards.number'
_definition.update                      2000-11-03
_description.text
;
     Count of unique standard reflections used in the diffraction measurements.
;
_description.compact                    DiffrnStandCount
_name.category_id                       diffrn_standards
_name.attribute_id                      number
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_diffrn_standards.scale_su
_definition.id                          '_diffrn_standards.scale_su'
_definition.update                      2000-11-03
_alias.definition_id                    '_diffrn_standards.scale_sigma'
_description.text
;
     Standard uncertainty (e.s.d.) of the individual mean standard scales
     applied to the intensity data.
;
_description.compact                    DiffrnStandScaleSu
_name.category_id                       diffrn_standards
_name.attribute_id                      scale_su
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_

#----------------------------------------------------------------------------

save_DIFFRN_STANDARD_REFLN
_definition.id                          diffrn_standard_refln
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the "standard" reflections
     measured repeatedly to monitor variations in intensity due to source
     flux, environment conditions or crystal quality.
;
_description.compact                    StandReflnList
_category.parent_id                     diffrn_standards
_category_key.item_id                   '_diffrn_standard_refln.hkl'
save_


save_diffrn_standard_refln.code
_definition.id                          '_diffrn_standard_refln.code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a standard reflection indices.
;
_description.compact                    StandReflnCode
_name.category_id                       diffrn_standard_refln
_name.attribute_id                      code
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
_description_example.case               s1
save_


save_diffrn_standard_refln.hkl
_definition.id                          '_diffrn_standard_refln.hkl'
_definition.update                      2000-11-03
_description.text
;
     Miller indices of a standard reflection.
;
_description.compact                    StandReflnHkl
_name.category_id                       diffrn_standard_refln
_name.attribute_id                      hkl
_type.container                         Vector
_type.value                             Real
_type_array.dimension                   [3]
_method.expression
;
     With d as diffrn_standard_refln
 
      _diffrn_standard_refln.hkl <- Vector([d.index_h, d.index_h, d.index_l])
;
save_


save_diffrn_standard_refln.index_h
_definition.id                          '_diffrn_standard_refln.index_h'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_standard_refln
_name.attribute_id                      index_h
save_


save_diffrn_standard_refln.index_k
_definition.id                          '_diffrn_standard_refln.index_k'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_standard_refln
_name.attribute_id                      index_k
save_


save_diffrn_standard_refln.index_l
_definition.id                          '_diffrn_standard_refln.index_l'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       diffrn_standard_refln
_name.attribute_id                      index_l
save_

#============================================================================

save_EXPTL
_definition.id                          exptl
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify the experimental work
     prior to diffraction measurements. These include crystallization
     and crystal measurements.
;
_category.parent_id                     crystal
save_


save_exptl.crystals_number
_definition.id                          '_exptl.crystals_number'
_definition.update                      2000-11-03
_description.text
;
     Number of crystals used in the measurement of intensities.
;
_description.compact                    CrystalsCount
_name.category_id                       exptl
_name.attribute_id                      crystals_number
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      1:1 
save_


save_exptl.special_details
_definition.id                          '_exptl.special_details'
_definition.update                      2000-11-03
_description.text
;
     Details of the experiment prior to intensity measurement.
     See also _exptl_crystal.preparation
;
_description.compact                    SpecialExptlDetails
_name.category_id                       exptl
_name.attribute_id                      special_details
_type.container                         Single
_type.value                             Char
save_

#---------------------------------------------------------------------------

save_EXPTL_ABSORPT
_definition.id                          exptl_absorpt
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify the experimental details
     of the  absorption measurements and corrections to the diffraction
     data.
;
_category.parent_id                     exptl
save_


save_exptl_absorpt.coefficient_mu
_definition.id                          '_exptl_absorpt.coefficient_mu'
_definition.update                      2000-11-03
_description.text
;
     Absorption coefficient mu calculated from the atomic content of
     the cell, the density and the radiation wavelength.
;
_description.compact                    AbsorbCoeffMu
_name.category_id                       exptl_absorpt
_name.attribute_id                      coefficient_mu
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             reciprocal_millimetres
save_


save_exptl_absorpt.correction_T_max
_definition.id                          '_exptl_absorpt.correction_T_max'
_definition.update                      2000-11-03
_description.text
;
     Maximum transmission factor for the crystal and radiation. These
     factors are also referred to as the absorption correction A or 1/A*.
;
_description.compact                    AbsorbTmax
_name.category_id                       exptl_absorpt
_name.attribute_id                      correction_T_max
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:1.0 
save_


save_exptl_absorpt.correction_T_min
_definition.id                          '_exptl_absorpt.correction_T_min'
_definition.update                      2000-11-03
_description.text
;
     Minimum transmission factor for the crystal and radiation. These
     factors are also referred to as the absorption correction A or 1/A*.
;
_description.compact                    AbsorbTmin
_name.category_id                       exptl_absorpt
_name.attribute_id                      correction_T_min
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:1.0 
save_


save_exptl_absorpt.correction_type
_definition.id                          '_exptl_absorpt.correction_type'
_definition.update                      2000-11-03
_description.text
;
     Code identifying the absorption correction type and method.
;
_description.compact                    AbsorbCorrectType
_name.category_id                       exptl_absorpt
_name.attribute_id                      correction_type
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
analytical 'analytical from crystal shape'
cylinder cylindrical
empirical 'empirical from intensities'
gaussian 'Gaussian from crystal shape'
integration 'integration from crystal shape'
multi-scan 'symmetry-related measurements'
none 'no absorption correction applied'
numerical 'numerical from crystal shape'
psi-scan 'psi-scan corrections'
refdelf 'refined from delta-F'
sphere spherical
_enumeration.default                    none
save_


save_exptl_absorpt.process_details
_definition.id                          '_exptl_absorpt.process_details'
_definition.update                      2000-11-03
_description.text
;
     Description of the absorption correction process applied to the
     measured intensities. A literature reference should be supplied
     for psi-scan or multi-scan techniques.
;
_description.compact                    AbsorbCorrectDetails
_name.category_id                       exptl_absorpt
_name.attribute_id                      process_details
_type.container                         Single
_type.value                             Char
loop_
_description_example.case
'Tompa analytical'
'MolEN (Fair, 1990)'
'(North, Phillips & Mathews, 1968)'
save_

#----------------------------------------------------------------------------

save_EXPTL_CRYSTAL
_definition.id                          exptl_crystal
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify information about the
     crystals used in the diffraction measurements.
;
_category.parent_id                     exptl
_category_key.item_id                   '_exptl_crystal.id'
save_


save_exptl_crystal.colour
_definition.id                          '_exptl_crystal.colour'
_definition.update                      2000-11-03
_description.text
;
     Colour and appearance of the crystal.
;
_description.compact                    CrystalColour
_name.category_id                       exptl_crystal
_name.attribute_id                      colour
_type.container                         Tuple
_type.value                             Uchar
_type_array.dimension                   [3]
_description_example.case               '[transluscent, pale, green]'
_method.expression
;
     With  c  as  exptl_crystal_appearance
 
      _exptl_crystal.colour <- Tuple ( [ c.general, c.intensity, c.base_colour ]
;
save_


save_exptl_crystal.density_diffrn
_definition.id                          '_exptl_crystal.density_diffrn'
_definition.update                      2001-02-15
_description.text
;
     Crystal density calculated from crystal unit cell and atomic content.
;
_description.compact                    CrystalDensityDiffrn
_name.category_id                       exptl_crystal
_name.attribute_id                      density_diffrn
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             megagrams_per_metres_cubed
_method.expression
;
    _exptl_crystal.density_diffrn <- 1.6605 * _cell.atomic_mass / _cell.volume
;
save_


save_exptl_crystal.density_meas
_definition.id                          '_exptl_crystal.density_meas'
_definition.update                      2000-11-03
_description.text
;
     Crystal density measured using standard chemical and physical methods.
;
_description.compact                    CrystalDensityMeas
_name.category_id                       exptl_crystal
_name.attribute_id                      density_meas
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             megagrams_per_metres_cubed
save_


save_exptl_crystal.density_meas_temp
_definition.id                          '_exptl_crystal.density_meas_temp'
_definition.update                      2000-11-03
_description.text
;
     Temperature at which _exptl_crystal.density_meas was determined.
;
_description.compact                    CrystalDensityTemperature
_name.category_id                       exptl_crystal
_name.attribute_id                      density_meas_temp
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             kelvins
save_


save_exptl_crystal.density_method
_definition.id                          '_exptl_crystal.density_method'
_definition.update                      2000-11-03
_description.text
;
     Description of method used to measure _exptl_crystal.density_meas.
;
_description.compact                    CrystalDensityMethod
_name.category_id                       exptl_crystal
_name.attribute_id                      density_method
_type.container                         Single
_type.value                             Char
_description_example.case               'flotation in aqueous KI'
save_


save_exptl_crystal.description
_definition.id                          '_exptl_crystal.description'
_definition.update                      2000-11-03
_description.text
;
     Description of the quality and habit of the crystal. The crystal
     dimensions should appear in the exptl_crystal_size category.
;
_description.compact                    CrystalDescription
_name.category_id                       exptl_crystal
_name.attribute_id                      description
_type.container                         Single
_type.value                             Char
save_


save_exptl_crystal.F_000
_definition.id                          '_exptl_crystal.F_000'
_definition.update                      2000-11-03
_description.text
;
     Number of electrons in the crystal unit cell contributing to F(000).
     It may contain dispersion contributions, and is calculated as
 
               F(000) = [ (sum f~r~)^2^ + (sum f~i~)^2^ ]^1/2^
 
               f~r~   = real part of the scattering factors at theta = 0
               f~i~   = imaginary part of the scattering factors at theta = 0
 
                        the sum is taken over each atom in the unit cell
;
_description.compact                    F(000)expected
_name.category_id                       exptl_crystal
_name.attribute_id                      F_000
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_exptl_crystal.id
_definition.id                          '_exptl_crystal.id'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a crystal if multiple crystals are used.
;
_description.compact                    CrystalId
_name.category_id                       exptl_crystal
_name.attribute_id                      id
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_exptl_crystal.preparation
_definition.id                          '_exptl_crystal.preparation'
_definition.update                      2000-11-03
_description.text
;
     Details of crystal growth and preparation of the crystals.
;
_description.compact                    CrystalPreparation
_name.category_id                       exptl_crystal
_name.attribute_id                      preparation
_type.container                         Single
_type.value                             Char
_description_example.case               'mounted in an argon-filled quartz capillary'
save_


save_exptl_crystal.pressure_history
_definition.id                          '_exptl_crystal.pressure_history'
_definition.update                      2000-11-03
_description.text
;
     Details concerning the pressure history of the crystals.
;
_description.compact                    CrystalOriginPressure
_name.category_id                       exptl_crystal
_name.attribute_id                      pressure_history
_type.container                         Single
_type.value                             Char
save_


save_exptl_crystal.size_length
_definition.id                          '_exptl_crystal.size_length'
_name.category_id                       exptl_crystal
_name.attribute_id                      size_length
_description.compact                    CrystalNeedleLength
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.:0. 
_units.code                             millimetres
save_


save_exptl_crystal.size_max
_definition.id                          '_exptl_crystal.size_max'
_name.category_id                       exptl_crystal
_name.attribute_id                      size_max
_description.compact                    CrystalSizeMax
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.:0. 
_units.code                             millimetres
save_


save_exptl_crystal.size_mid
_definition.id                          '_exptl_crystal.size_mid'
_name.category_id                       exptl_crystal
_name.attribute_id                      size_mid
_description.compact                    CrystalSizeMedial
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.:0. 
_units.code                             millimetres
save_


save_exptl_crystal.size_min
_definition.id                          '_exptl_crystal.size_min'
_name.category_id                       exptl_crystal
_name.attribute_id                      size_min
_description.compact                    CrystalSizeMin
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.:0. 
_units.code                             millimetres
save_


save_exptl_crystal.size_rad
_definition.id                          '_exptl_crystal.size_rad'
_name.category_id                       exptl_crystal
_name.attribute_id                      size_rad
_description.compact                    CrystalRadius
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.:0. 
_units.code                             millimetres
save_


save_exptl_crystal.thermal_history
_definition.id                          '_exptl_crystal.thermal_history'
_definition.update                      2000-11-03
_description.text
;
     Details concerning the thermal history of the crystals.
;
_description.compact                    CrystalOriginThermal
_name.category_id                       exptl_crystal
_name.attribute_id                      thermal_history
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------------

save_EXPTL_CRYSTAL_FACE
_definition.id                          exptl_crystal_face
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the dimensions of the
     crystals used in the diffraction measurements.
;
_category.parent_id                     exptl
_category_key.item_id                   '_exptl_crystal_face.id'
save_


save_exptl_crystal_face.crystal_id
_definition.id                          '_exptl_crystal_face.crystal_id'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a crystal if multiple crystals are used.
;
_description.compact                    CrystalFaceCrystalId
_name.category_id                       exptl_crystal_face
_name.attribute_id                      crystal_id
_name.linked_item_id                    '_exptl_crystal.id'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_exptl_crystal_face.diffr_chi
_definition.id                          '_exptl_crystal_face.diffr_chi'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       exptl_crystal_face
_name.attribute_id                      diffr_chi
save_


save_exptl_crystal_face.diffr_kappa
_definition.id                          '_exptl_crystal_face.diffr_kappa'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       exptl_crystal_face
_name.attribute_id                      diffr_kappa
save_


save_exptl_crystal_face.diffr_phi
_definition.id                          '_exptl_crystal_face.diffr_phi'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       exptl_crystal_face
_name.attribute_id                      diffr_phi
save_


save_exptl_crystal_face.diffr_psi
_definition.id                          '_exptl_crystal_face.diffr_psi'
_definition.import_id                   '_generic.diffractometer_angle'
_name.category_id                       exptl_crystal_face
_name.attribute_id                      diffr_psi
save_


save_exptl_crystal_face.hkl
_definition.id                          '_exptl_crystal_face.hkl'
_definition.update                      2000-11-03
_description.text
;
     Miller indices of the crystal face.
;
_description.compact                    CrystalFaceHkl
_name.category_id                       exptl_crystal_face
_name.attribute_id                      hkl
_type.container                         Vector
_type.value                             Real
_type_array.dimension                   [3]
_method.expression
;
     With f as exptl_crystal_face
 
      _exptl_crystal_face.hkl <- Vector ( [f.index_h, f.index_h, f.index_l] )
;
save_


save_exptl_crystal_face.index_h
_definition.id                          '_exptl_crystal_face.index_h'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       exptl_crystal_face
_name.attribute_id                      index_h
save_


save_exptl_crystal_face.index_k
_definition.id                          '_exptl_crystal_face.index_k'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       exptl_crystal_face
_name.attribute_id                      index_k
save_


save_exptl_crystal_face.index_l
_definition.id                          '_exptl_crystal_face.index_l'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       exptl_crystal_face
_name.attribute_id                      index_l
save_


save_exptl_crystal_face.id
_definition.id                          '_exptl_crystal_face.id'
_definition.update                      2000-11-03
_description.text
;
     Identifier which combines the crystal id and the face indices
     as a tuple. This is the key item of the category.
;
_description.compact                    CrystalFaceId
_name.category_id                       exptl_crystal_face
_name.attribute_id                      id
_type.container                         Tuple
_type.value                             Uchar
_type_array.dimension                   [2]
_method.expression
;
     With f as exptl_crystal_face
 
        _exptl_crystal_face.id <- Tuple ( [f.crystal_id, f.hkl] )
;
save_


save_exptl_crystal_face.perp_dist
_definition.id                          '_exptl_crystal_face.perp_dist'
_definition.update                      2000-11-03
_description.text
;
     Perpendicular distance of face to the centre of rotation of the crystal.
;
_description.compact                    CrystalFacePerpDist
_name.category_id                       exptl_crystal_face
_name.attribute_id                      perp_dist
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             millimetres
save_

#-------------------------------------------------------------------------------

save_EXPTL_CRYSTAL_APPEARANCE
_definition.id                          exptl_crystal_appearance
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of ENUMERATION items used to specify information about the
     crystal colour and appearance.
;
_category.parent_id                     exptl_crystal
save_


save_exptl_crystal_appearance.general
_definition.id                          '_exptl_crystal_appearance.general'
_definition.update                      2000-11-03
_description.text
;
     Appearance of the crystal.
;
_description.compact                    CrystalColourAppearance
_name.category_id                       exptl_crystal_appearance
_name.attribute_id                      general
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
metallic
lustrous
transluscent
clear
' '
_enumeration.default                    ' '
save_


save_exptl_crystal_appearance.intensity
_definition.id                          '_exptl_crystal_appearance.intensity'
_definition.update                      2000-11-03
_description.text
;
     Colour intensity of the crystal.
;
_description.compact                    CrystalColourIntensity
_name.category_id                       exptl_crystal_appearance
_name.attribute_id                      intensity
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
dark
light
intense
pale
' '
_enumeration.default                    ' '
save_


save_exptl_crystal_appearance.base_colour
_definition.id                          '_exptl_crystal_appearance.base_colour'
_definition.update                      2000-11-03
_description.text
;
     Base colour of the crystal.
;
_description.compact                    CrystalColourBase
_name.category_id                       exptl_crystal_appearance
_name.attribute_id                      base_colour
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
black
blue
bronze
brown
colourless
gold
green
grey
orange
pink
purple
red
silver
violet
white
yellow
_enumeration.default                    colourless
save_

#============================================================================

save_GEOM
_definition.id                          geom
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify the geometry of the
     structural model as derived from the atomic sites.
;
_description.compact                    StructuralGeom
_category.parent_id                     model
save_


save_geom.bond_distance_incr
_definition.id                          '_geom.bond_distance_incr'
_definition.update                      2000-11-03
_description.text
;
     Increment added to the bond radii for the atomic species to
     specify the maximum permitted "bonded" distance between two
     atom sites.
;
_description.compact                    GeomBondDistIncr
_name.category_id                       geom
_name.attribute_id                      bond_distance_incr
_type.container                         Single
_type.value                             Real
_enumeration.default                    0.2
_units.code                             angstroms
save_


save_geom.bond_distance_min
_definition.id                          '_geom.bond_distance_min'
_definition.update                      2000-11-03
_description.text
;
     Minimum permitted "bonded" distance between two atom sites.
;
_description.compact                    GeomBondDistMin
_name.category_id                       geom
_name.attribute_id                      bond_distance_min
_type.container                         Single
_type.value                             Real
_enumeration.default                    0.2
_units.code                             angstroms
save_


save_geom.contact_distance_incr
_definition.id                          '_geom.contact_distance_incr'
_definition.update                      2000-11-03
_description.text
;
     Increment added to the bond radii for the atomic species to
     specify the maximum permitted "contact" distance between two
     "non-bonded" atom sites.
;
_description.compact                    GeomContactDistIncr
_name.category_id                       geom
_name.attribute_id                      contact_distance_incr
_type.container                         Single
_type.value                             Real
_enumeration.default                    0.2
_units.code                             angstroms
save_


save_geom.contact_distance_min
_definition.id                          '_geom.contact_distance_min'
_definition.update                      2000-11-03
_description.text
;
     Minimum permitted "contact" distance between two "non-bonded" atom sites.
;
_description.compact                    GeomContactDistMin
_name.category_id                       geom
_name.attribute_id                      contact_distance_min
_type.container                         Single
_type.value                             Real
_enumeration.default                    0.2
_units.code                             angstroms
save_


save_geom.special_details
_definition.id                          '_geom.special_details'
_definition.update                      2000-11-03
_description.text
;
     Description of geometry information not covered by the existing data
     names in the geometry categories, such as least-squares planes.
;
_description.compact                    GeomSpecialDetails
_name.category_id                       geom
_name.attribute_id                      special_details
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------------

save_GEOM_ANGLE
_definition.id                          geom_angle
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify the geometry angles in the
     structural model as derived from the atomic sites.
;
_description.compact                    BondAngleList
_category.parent_id                     geom
_category_key.item_id                   '_geom_angle.id'
_method.expression
;
     dmin <- _geom.bond_distance_min
 
     Loop  m1  as  model_site  :i  {   # loop vertex model site
 
        rad1  <-  m1.radius_bond + _geom.bond_distance_incr
 
        Loop  m2  as  model_site  :j  {  # loop first target site
 
           If (i==j or m1.mole_index != m2.mole_index) Next
           v1 <- m2.Cartn_xyz - m1.Cartn_xyz
           d1 <- Norm (v1)
 
           If (d1<dmin or d1>(rad1+m2.radius_bond))  Next
 
           rad2  <-  m2.radius_bond + _geom.bond_distance_incr
 
           Loop  m3  as  model_site  :k>j  {  # loop second target site
 
              If (i==k or m1.mole_index != m3.mole_index) Next
              v2 <- m3.Cartn_xyz - m1.Cartn_xyz
              d2 <- Norm (v2)
 
              If (d2<dmin or d2>(rad2+m3.radius_bond)) Next
 
              angle <- Acosd ( v1*v2 / (d1*d2) )
 
              geom_angle( .id        <- Tuple ([m2.id, m1.id, m3.id]),
                          .distances <- Tuple ([d1, d2]),
                          .value     <- angle )
     }   }   }
;
save_


save_geom_angle.atom_site_label_1
_definition.id                          '_geom_angle.atom_site_label_1'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_angle
_name.attribute_id                      atom_site_label_1
save_


save_geom_angle.atom_site_label_2
_definition.id                          '_geom_angle.atom_site_label_2'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_angle
_name.attribute_id                      atom_site_label_2
save_


save_geom_angle.atom_site_label_3
_definition.id                          '_geom_angle.atom_site_label_3'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_angle
_name.attribute_id                      atom_site_label_3
save_


save_geom_angle.distances
_definition.id                          '_geom_angle.distances'
_definition.update                      2000-11-03
_description.text
;
     The pair of distances between sites 1 - 2 and 2 - 3.
;
_name.category_id                       geom_angle
_name.attribute_id                      distances
_type.container                         Tuple
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [2]
_units.code                             angstroms
save_


save_geom_angle.id
_definition.id                          '_geom_angle.id'
_definition.update                      2000-11-03
_description.text
;
     Atom site labels and symmetry operators as pairs for each of the
     three atom sites which identify the angle. The second label-symop
     pair in the list identifies the site at the apex of the angle.
;
_description.compact                    BondAngleId
_name.category_id                       geom_angle
_name.attribute_id                      id
_type.container                         Tuple[Tuple]
_type.value                             Uchar
_type_array.dimension                   [3[2]]
_method.expression
;
     With  a  as  geom_angle
 
     _geom_angle.id <- Tuple ([
                            Tuple ([ a.atom_site_label_1, a.site_symmetry_1 ]),
                            Tuple ([ a.atom_site_label_2, a.site_symmetry_2 ]),
                            Tuple ([ a.atom_site_label_3, a.site_symmetry_3 ])])
;
save_


save_geom_angle.publ_flag
_definition.id                          '_geom_angle.publ_flag'
_definition.update                      2000-11-03
_description.text
;
     Code signals if the angle is required for publication.
;
_description.compact                    BondAnglePublFlag
_name.category_id                       geom_angle
_name.attribute_id                      publ_flag
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
no 'do not include angle in special list'
n 'abbreviation for "no"'
yes 'do include angle in special list'
y 'abbreviation for "yes"'
_enumeration.default                    no
save_


save_geom_angle.site_symmetry_1
_definition.id                          '_geom_angle.site_symmetry_1'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_angle
_name.attribute_id                      site_symmetry_1
save_


save_geom_angle.site_symmetry_2
_definition.id                          '_geom_angle.site_symmetry_2'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_angle
_name.attribute_id                      site_symmetry_2
save_


save_geom_angle.site_symmetry_3
_definition.id                          '_geom_angle.site_symmetry_3'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_angle
_name.attribute_id                      site_symmetry_3
save_


save_geom_angle.value
_definition.id                          '_geom_angle.value'
_definition.update                      2000-11-03
#   _alias.definition_id       '_geom_angle'            #######!!!!????
_description.text
;
     Angle defined by the sites identified by _geom_angle.id
;
_description.compact                    BondAngle
_name.category_id                       geom_angle
_name.attribute_id                      value
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             degrees
_method.expression
;
     xc = List()
 
     For [label,symop] in  _geom_angle.id   {
 
         xf   <-  SymEquiv(symop, symmetry_equiv, _atom_site[label].fract_xyz)
 
         xc ++<- _atom_sites_Cartn_transform.matrix * xf
      }
         v1,v2  <- xc[0]-xc[1], xc[2]-xc[1]
 
      _geom_angle.value <- Acosd ( v1 * v2 / ( Norm (v1) * Norm (v2) ) )
;
save_

#----------------------------------------------------------------------------

save_GEOM_BOND
_definition.id                          geom_bond
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify the geometry bonds in the
     structural model as derived from the atomic sites.
;
_description.compact                    BondDistList
_category.parent_id                     geom
_category_key.item_id                   '_geom_bond.id'
_method.expression
;
     dmin <- _geom.bond_distance_min
 
     Loop  m1  as  model_site  :i  {
 
        rad   <-  m1.radius_bond + _geom.bond_distance_incr
 
        Loop  m2  as  model_site  :j  {
 
           If (i==j or m1.mole_index != m2.mole_index) Next
 
           d <- Norm (m1.Cartn_xyz - m2.Cartn_xyz)
 
           If (d<dmin or d>(rad+m2.radius_bond)) Next
 
           geom_bond( .id        <- Tuple ([m1.id, m2.id]),
                      .distance  <- d  )
      }   }
;
save_


save_geom_bond.atom_site_label_1
_definition.id                          '_geom_bond.atom_site_label_1'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_bond
_name.attribute_id                      atom_site_label_1
save_


save_geom_bond.atom_site_label_2
_definition.id                          '_geom_bond.atom_site_label_2'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_bond
_name.attribute_id                      atom_site_label_2
save_


save_geom_bond.distance
_definition.id                          '_geom_bond.distance'
_definition.update                      2000-11-03
_description.text
;
     Distance between the sites identified by _geom_bond.id
;
_description.compact                    BondDist
_name.category_id                       geom_bond
_name.attribute_id                      distance
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             angstroms
_method.expression
;
     xc = List()
 
     For [label,symop] in  _geom_bond.id   {
 
         xf   <-  SymEquiv(symop, symmetry_equiv, _atom_site[label].fract_xyz)
 
         xc ++<- _atom_sites_Cartn_transform.matrix * xf
      }
      _geom_bond.distance <- Norm ( xc[0] - xc[1] )
;
save_


save_geom_bond.id
_definition.id                          '_geom_bond.id'
_definition.update                      2000-11-03
_description.text
;
     Identity of bond distance in terms of the atom site labels and
     symmetry operators as pairs for each of the two "bonded" atom sites.
;
_description.compact                    BondDistId
_name.category_id                       geom_bond
_name.attribute_id                      id
_type.container                         Tuple[Tuple]
_type.value                             Uchar
_type_array.dimension                   [2[2]]
_method.expression
;
     With  a  as  geom_bond
 
     _geom_bond.id <- Tuple ([
                           Tuple ([ a.atom_site_label_1, a.site_symmetry_1 ]),
                           Tuple ([ a.atom_site_label_2, a.site_symmetry_2 ])])
;
save_


save_geom_bond.publ_flag
_definition.id                          '_geom_bond.publ_flag'
_definition.update                      2000-11-03
_description.text
;
     Code signals if the bond is required for publication.
;
_description.compact                    BondDistPublFlag
_name.category_id                       geom_bond
_name.attribute_id                      publ_flag
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
no 'do not include bond in special list'
n 'abbreviation for "no"'
yes 'do include bond in special list'
y 'abbreviation for "yes"'
_enumeration.default                    no
save_


save_geom_bond.site_symmetry_1
_definition.id                          '_geom_bond.site_symmetry_1'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_bond
_name.attribute_id                      site_symmetry_1
save_


save_geom_bond.site_symmetry_2
_definition.id                          '_geom_bond.site_symmetry_2'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_bond
_name.attribute_id                      site_symmetry_2
save_

#----------------------------------------------------------------------------

save_GEOM_CONTACT
_definition.id                          geom_contact
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify the contact distances in the
     structural model as derived from the atomic sites.
;
_description.compact                    BondContactList
_category.parent_id                     geom
_category_key.item_id                   '_geom_contact.id'
_method.expression
;
     Loop  m1  as  model_site  {
 
        rb  <-  m1.radius_bond    + _geom.bond_distance_incr
        rc  <-  m1.radius_contact + _geom.contact_distance_incr
 
        Loop  m2  as  model_site  {
 
           If (m2.id[1] != '1_555')  Next
           radb  <-  rb + m2.radius_bond
           radc  <-  rc + m2.radius_contact
           label <-  m2.id[0]
 
           Loop  s  as  symmetry_equiv  :ns   {
 
              axyz      <-  s.R * m2.fract_xyz + s.T
 
              Do i = -2,2 { Do j = -2,2 { Do k = -2,2 { # cell translations
 
                 tran  <-  Vector ([i,j,k])
                 bxyz  <-  axyz + tran
                 cxyz  <- _atom_sites_Cartn_transform.matrix * bxyz
                 d     <-  Norm (cxyz - m1.Cartn_xyz)
 
                 If (d < radb or d > radc) Next
 
                 id        <- Tuple([m1.id, Tuple([label, Symop(ns+1,tran)])])
 
                 geom_contact( .id        <- id,
                               .distance  <- d  )
     }  }  }  }  }  }
;
save_


save_geom_contact.atom_site_label_1
_definition.id                          '_geom_contact.atom_site_label_1'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_contact
_name.attribute_id                      atom_site_label_1
save_


save_geom_contact.atom_site_label_2
_definition.id                          '_geom_contact.atom_site_label_2'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_contact
_name.attribute_id                      atom_site_label_2
save_


save_geom_contact.distance
_definition.id                          '_geom_contact.distance'
_definition.update                      2000-11-03
_description.text
;
     Distance between the sites identifyed in _geom_contact.id
;
_description.compact                    BondContactDist
_name.category_id                       geom_contact
_name.attribute_id                      distance
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             angstroms
_method.expression
;
     xc = List()
 
     For [label,symop] in  _geom_contact.id   {
 
         xf   <-  SymEquiv(symop, symmetry_equiv, _atom_site[label].fract_xyz)
 
         xc ++<- _atom_sites_Cartn_transform.matrix * xf
     }
     _geom_contact.distance <- Norm ( xc[0] - xc[1] )
;
save_


save_geom_contact.id
_definition.id                          '_geom_contact.id'
_definition.update                      2000-11-03
_description.text
;
     Atom site labels and symmetry operators as pairs for each of the
     two atom sites which define the contact bond.
;
_description.compact                    BondContactId
_name.category_id                       geom_contact
_name.attribute_id                      id
_type.container                         Tuple[Tuple]
_type.value                             Uchar
_type_array.dimension                   [2[2]]
_method.expression
;
     With  a  as  geom_contact
 
     _geom_contact.id <- Tuple ([
                            Tuple ([ a.atom_site_label_1, a.site_symmetry_1 ]),
                            Tuple ([ a.atom_site_label_2, a.site_symmetry_2 ])])
;
save_


save_geom_contact.publ_flag
_definition.id                          '_geom_contact.publ_flag'
_definition.update                      2000-11-03
_description.text
;
     Code signals if the contact is required for publication.
;
_description.compact                    BondContactPublFlag
_name.category_id                       geom_contact
_name.attribute_id                      publ_flag
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
no 'do not include contact in special list'
n 'abbreviation for "no"'
yes 'do include contact in special list'
y 'abbreviation for "yes"'
_enumeration.default                    no
save_


save_geom_contact.site_symmetry_1
_definition.id                          '_geom_contact.site_symmetry_1'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_contact
_name.attribute_id                      site_symmetry_1
save_


save_geom_contact.site_symmetry_2
_definition.id                          '_geom_contact.site_symmetry_2'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_contact
_name.attribute_id                      site_symmetry_2
save_

#----------------------------------------------------------------------------

save_GEOM_HBOND
_definition.id                          geom_hbond
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify the hydrogen bond distances
     in the structural model as derived from the atomic sites.
;
_description.compact                    HbondList
_category.parent_id                     geom
_category_key.item_id                   '_geom_hbond.id'
save_


save_geom_hbond.angle_DHA
_definition.id                          '_geom_hbond.angle_DHA'
_definition.update                      2000-11-03
_description.text
;
     Angle subtended by the sites identifyed in _geom_hbond.id.
     The hydrogen at site H is at the apex of the angle.
;
_description.compact                    HbondAngleDHA
_name.category_id                       geom_hbond
_name.attribute_id                      angle_DHA
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             degrees
_method.expression
;
     xc = List()
 
     For [label,symop] in  _geom_hbond.id   {
 
         xf   <-  SymEquiv(symop, symmetry_equiv, _atom_site[label].fract_xyz)
 
         xc ++<- _atom_sites_Cartn_transform.matrix * xf
      }
         v1,v2  <- xc[0]-xc[1], xc[2]-xc[1]
 
     _geom_hbond.angle_DHA  <- Acosd ( v1 * v2 / ( Norm (v1) * Norm (v2) ) )
;
save_


save_geom_hbond.atom_site_label_A
_definition.id                          '_geom_hbond.atom_site_label_A'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_hbond
_name.attribute_id                      atom_site_label_A
save_


save_geom_hbond.atom_site_label_D
_definition.id                          '_geom_hbond.atom_site_label_D'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_hbond
_name.attribute_id                      atom_site_label_D
save_


save_geom_hbond.atom_site_label_H
_definition.id                          '_geom_hbond.atom_site_label_H'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_hbond
_name.attribute_id                      atom_site_label_H
save_


save_geom_hbond.distance_DH
_definition.id                          '_geom_hbond.distance_DH'
_definition.update                      2000-11-03
_description.text
;
     The set of data items which specify the distance between the
     three atom sites identified by _geom_hbond.id.
;
_name.category_id                       geom_hbond
_name.attribute_id                      distance_DH
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
_method.expression
;
     xc = List()
 
     Do i=0,1  {
         l,s  <-  _geom_hbond.id [i]
         xf   <-  SymEquiv(s, symmetry_equiv, _atom_site[l].fract_xyz)
         xc ++<- _atom_sites_Cartn_transform.matrix * xf
     }
      _geom_hbond.distance_DH <- Norm ( xc[0] - xc[1] )
;
save_


save_geom_hbond.distance_HA
_definition.id                          '_geom_hbond.distance_HA'
_definition.update                      2000-11-03
_description.text
;
     The set of data items which specify the distance between the
     three atom sites identified by _geom_hbond.id.
;
_name.category_id                       geom_hbond
_name.attribute_id                      distance_HA
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
_method.expression
;
     xc = List()
 
     Do i=1,2  {
         l,s  <-  _geom_hbond.id [i]
         xf   <-  SymEquiv(s, symmetry_equiv, _atom_site[l].fract_xyz)
         xc ++<- _atom_sites_Cartn_transform.matrix * xf
     }
      _geom_hbond.distance_HA <- Norm ( xc[0] - xc[1] )
;
save_


save_geom_hbond.distance_DA
_definition.id                          '_geom_hbond.distance_DA'
_definition.update                      2000-11-03
_description.text
;
     The set of data items which specify the distance between the
     three atom sites identified by _geom_hbond.id.
;
_name.category_id                       geom_hbond
_name.attribute_id                      distance_DA
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
_method.expression
;
     xc = List()
 
     Do i=0,2,2  {
         l,s  <-  _geom_hbond.id [i]
         xf   <-  SymEquiv(s, symmetry_equiv, _atom_site[l].fract_xyz)
         xc ++<- _atom_sites_Cartn_transform.matrix * xf
      }
      _geom_hbond.distance_DA <- Norm ( xc[0] - xc[1] )
;
save_


save_geom_hbond.id
_definition.id                          '_geom_hbond.id'
_definition.update                      2000-11-03
_description.text
;
     Atom site labels and symmetry operators as pairs for each of the
     three atom sites which define the hydrogen angle and distances.
     Site H is at the apex of the angle.
;
_description.compact                    HbondId
_name.category_id                       geom_hbond
_name.attribute_id                      id
_type.container                         Tuple[Tuple]
_type.value                             Uchar
_type_array.dimension                   [3[2]]
_method.expression
;
     With  a  as  geom_hbond
 
    _geom_hbond.id <- Tuple ([
                           Tuple ([ a.atom_site_label_D, a.site_symmetry_D ]),
                           Tuple ([ a.atom_site_label_H, a.site_symmetry_H ]),
                           Tuple ([ a.atom_site_label_A, a.site_symmetry_A ])])
;
save_


save_geom_hbond.publ_flag
_definition.id                          '_geom_hbond.publ_flag'
_definition.update                      2000-11-03
_description.text
;
     Code signals if the angle and distances are required for publication.
;
_description.compact                    HbondPublFlag
_name.category_id                       geom_hbond
_name.attribute_id                      publ_flag
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
no 'do not include hbond in special list'
n 'abbreviation for "no"'
yes 'do include hbond in special list'
y 'abbreviation for "yes"'
_enumeration.default                    no
save_


save_geom_hbond.site_symmetry_A
_definition.id                          '_geom_hbond.site_symmetry_A'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_hbond
_name.attribute_id                      site_symmetry_A
save_


save_geom_hbond.site_symmetry_D
_definition.id                          '_geom_hbond.site_symmetry_D'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_hbond
_name.attribute_id                      site_symmetry_D
save_


save_geom_hbond.site_symmetry_H
_definition.id                          '_geom_hbond.site_symmetry_H'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_hbond
_name.attribute_id                      site_symmetry_H
save_

#----------------------------------------------------------------------------

save_GEOM_TORSION
_definition.id                          geom_torsion
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify the torsion angles in the
     structural model as derived from the atomic sites.
;
_description.compact                    TorsionAngleList
_category.parent_id                     geom
_category_key.item_id                   '_geom_torsion.id'
_method.expression
;
     dmin <- _geom.bond_distance_min
 
     Loop  m1  as  model_site  :i  {
 
        rad1  <-  m1.radius_bond + _geom.bond_distance_incr
 
        Loop  m2  as  model_site  :j  {
 
           If (i==j or m2.mole_index!=m1.mole_index) Next
           v21 <- m1.Cartn_xyz - m2.Cartn_xyz
           d21 <- Norm (v21)
 
           If (d21 < dmin or d21 > (rad1+m2.radius_bond)) Next
           rad2  <-  m2.radius_bond + _geom.bond_distance_incr
 
           Loop  m3  as  model_site  :k  {
 
              If (k==i or k==j or m3.mole_index!=m2.mole_index) Next
              v23 <- m3.Cartn_xyz - m2.Cartn_xyz
              d23 <- Norm (v23)
 
              If (d23 < dmin or d23 > (rad2+m3.radius_bond)) Next
              rad3  <-  m3.radius_bond + _geom.bond_distance_incr
 
              Loop  m4  as  model_site  :l  {
 
                 If (l==k or l==j or l==i or m4.mole_index!=m3.mole_index) Next
                 v34 <- m4.Cartn_xyz - m3.Cartn_xyz
                 d34 <- Norm (v34)
 
                 If (d34 < dmin or d34 > (rad3+m4.radius_bond)) Next
 
                 u1    <-  v21 ^ v23
                 u2    <-  v34 ^ v23
 
                 angle <- Acosd ( u1 * u2 / ( Norm(u1) * Norm(u2) ) )
                 If ( (u1^u2)*v23 > 0 ) angle = -angle
 
                 geom_torsion( .id        <- Tuple ([m1.id,m2.id,m3.id,m4.id]),
                               .distances <- Tuple ([d21,d23,d34]),
                               .angle     <- angle )
     }   }   }    }
;
save_


save_geom_torsion.atom_site_label_1
_definition.id                          '_geom_torsion.atom_site_label_1'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_torsion
_name.attribute_id                      atom_site_label_1
save_


save_geom_torsion.atom_site_label_2
_definition.id                          '_geom_torsion.atom_site_label_2'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_torsion
_name.attribute_id                      atom_site_label_2
save_


save_geom_torsion.atom_site_label_3
_definition.id                          '_geom_torsion.atom_site_label_3'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_torsion
_name.attribute_id                      atom_site_label_3
save_


save_geom_torsion.atom_site_label_4
_definition.id                          '_geom_torsion.atom_site_label_4'
_definition.import_id                   '_generic.atom_site_label'
_name.category_id                       geom_torsion
_name.attribute_id                      atom_site_label_4
save_


save_geom_torsion.distances
_definition.id                          '_geom_torsion.distances'
_definition.update                      2000-11-03
_description.text
;
     Distances between sites 1 - 2, 2 - 3 and 3 - 4.
;
_name.category_id                       geom_torsion
_name.attribute_id                      distances
_type.container                         Tuple
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_units.code                             angstroms
save_


save_geom_torsion.id
_definition.id                          '_geom_torsion.id'
_definition.update                      2000-11-03
_description.text
;
     Atom site labels and symmetry operators as pairs for each of the
     four atom sites which define the torsion angle.
;
_description.compact                    TorsionAngleId
_name.category_id                       geom_torsion
_name.attribute_id                      id
_type.container                         Tuple[Tuple]
_type.value                             Uchar
_type_array.dimension                   [4[2]]
_method.expression
;
     With  a  as  geom_torsion
 
    _geom_torsion.id <- Tuple ([
                            Tuple ([ a.atom_site_label_1, a.site_symmetry_1 ]),
                            Tuple ([ a.atom_site_label_2, a.site_symmetry_2 ]),
                            Tuple ([ a.atom_site_label_3, a.site_symmetry_3 ]),
                            Tuple ([ a.atom_site_label_4, a.site_symmetry_4 ])])
;
save_


save_geom_torsion.publ_flag
_definition.id                          '_geom_torsion.publ_flag'
_definition.update                      2000-11-03
_description.text
;
     Code signals if the torsion angle is required for publication.
;
_description.compact                    TorsionAnglePublFlag
_name.category_id                       geom_torsion
_name.attribute_id                      publ_flag
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
no 'do not include angle in special list'
n 'abbreviation for "no"'
yes 'do include angle in special list'
y 'abbreviation for "yes"'
_enumeration.default                    no
save_


save_geom_torsion.angle
_definition.id                          '_geom_torsion.angle'
_definition.update                      2000-11-03
_description.text
;
     Angle defined by the sites identifyed in _geom_torsion.id.
;
_description.compact                    TorsionAngle
_name.category_id                       geom_torsion
_name.attribute_id                      angle
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             degrees
save_


save_geom_torsion.site_symmetry_1
_definition.id                          '_geom_torsion.site_symmetry_1'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_torsion
_name.attribute_id                      site_symmetry_1
save_


save_geom_torsion.site_symmetry_2
_definition.id                          '_geom_torsion.site_symmetry_2'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_torsion
_name.attribute_id                      site_symmetry_2
save_


save_geom_torsion.site_symmetry_3
_definition.id                          '_geom_torsion.site_symmetry_3'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_torsion
_name.attribute_id                      site_symmetry_3
save_


save_geom_torsion.site_symmetry_4
_definition.id                          '_geom_torsion.site_symmetry_4'
_definition.import_id                   '_generic.site_symmetry'
_name.category_id                       geom_torsion
_name.attribute_id                      site_symmetry_4
save_

#============================================================================

save_MODEL_SITE
_definition.id                          model_site
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe atomic sites and
     connections in the proposed atomic model.
;
_description.compact                    ModelSiteList
_category.parent_id                     model
_category_key.item_id                   '_model_site.id'
_method.expression
;
# Store unique sites as a local list
 
     atomlist  = List()
     Loop  a  as  atom_site  {
        axyz       <-   a.fract_xyz
        cxyz       <-  _atom_sites_Cartn_transform.matrix * axyz
        radb       <-  _atom_type[a.type_symbol].radius_bond
        radc       <-  _atom_type[a.type_symbol].radius_contact
        ls         <-  Tuple ( [a.label, "1_555"] )
        atomlist ++<-  [ls, axyz, cxyz, radb, radc, 0]
     }
 
# Store closest connected sites as a list
 
     molelist  = List()
     dmin     <- _geom.bond_distance_min
     m        <- 0
     n        <- 0
 
     For [ls1,a1,c1,rb1,rc1,m1] in atomlist  {
         If (m1 != 0) Next
         m         +<- 1
         n         +<- 1
         molelist ++<- [ls1,a1,c1,rb1,rc1,n,m]
         atomlist  <<- [ls1,a1,c1,rb1,rc1,m]
 
         Repeat  {
             connect <- "no"
 
             For [ls2,a2,c2,rb2,rc2,n2,m2] in molelist  {
                 If (m2 != m) Next
 
                 For [ls3,a3,c3,rb3,rc3,m3] in atomlist  {
                     dmax  <- rb2 + rb3 + _geom.bond_distance_incr
 
                     Loop  s  as  symmetry_equiv  :ns   {
 
                         axyz      <-  s.R * a3 + s.T
                         bxyz,tran <-  Closest (axyz, a2)
                         cxyz      <- _atom_sites_Cartn_transform.matrix *bxyz
                         d         <-  Norm (cxyz - c2)
 
                        If (d > dmin and d < dmax)          {
                            ls  <-  Tuple ([ls3[0], Symop(ns+1, tran)])
 
                            If (ls not in Strip(molelist,0))    {
                                n         +<- 1
                                molelist ++<- [ls,bxyz,cxyz,rb3,rc3,n,m]
                                atomlist  <<- [ls3,a3,c3,rb3,rc3,m]
                                connect    <- "yes"
         }   }   }   }   }
        If (connect == "no") Break
     }  }
 
# Store connected molecular sites as MODEL_SITE list
 
     For [ls,ax,cx,rb,rc,n,m] in molelist  {
 
        model_site( .id              <- ls,
                    .fract_xyz       <- ax,
                    .Cartn_xyz       <- cx,
                    .radius_bond     <- rb,
                    .radius_contact  <- rc,
                    .index           <- n,
                    .mole_index      <- m  )
      }
;
save_


save_model_site.display_colour_code
_definition.id                          '_model_site.display_colour_code'
_definition.update                      2000-11-03
_description.text
;
     The display colour assigned to this atom site. Note that the
     possible colours are enumerated in the display_colour list
     category of items.
;
_description.compact                    AtomTypeColour
_name.category_id                       model_site
_name.attribute_id                      display_colour_code
_name.linked_item_id                    '_display_colour.code'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
save_


save_model_site.radius_bond
_definition.id                          '_model_site.radius_bond'
_definition.update                      2000-11-03
_description.text
;
     Atomic radius of atom specie located at this site.
;
_description.compact                    ModelSiteBondRadius
_name.category_id                       model_site
_name.attribute_id                      radius_bond
_type.container                         Single
_type.value                             Real
_method.expression
;
     With  m  as  model_site
 
    _model_site.radius_bond <- _atom_type[m.type_symbol].radius_bond
;
save_


save_model_site.adp_matrix_beta
_definition.id                          '_model_site.adp_matrix_beta'
_definition.update                      2000-11-03
_description.text
;
     Matrix of dimensionless anisotropic atomic displacement parameters.
;
_description.compact                    ModelSiteAdpMatrixBeta
_name.category_id                       model_site
_name.attribute_id                      adp_matrix_beta
_type.container                         Matrix
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3,3]
_method.expression
;
     [label,symop] <-  _model_site.id
 
     a = atom_site[label]
     s = symmetry_equiv[SymKey(symop)]
 
     _model_site.adp_matrix_beta <- s.R * a.matrix_beta * s.RT
;
save_


save_model_site.adp_eigen_system
_definition.id                          '_model_site.adp_eigen_system'
_definition.update                      2000-11-03
_description.text
;
     The set of three adp eigenvales and associated eigenvectors
     in the form of 4 element Tuples. Each tuple has the form
 
                   [val, vecX, vecY, vecZ]
 
     where the vector elements are direction cosines to the orthogonal
     axes X,Y,Z. The tuples are sorted in descending magnitude of val.
     That is, the tuple with the largest val is first, and the smallest
     val is last.
;
_description.compact                    ModelSiteAdpEigenSystem
_name.category_id                       model_site
_name.attribute_id                      adp_eigen_system
_type.container                         Tuple[Tuple]
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3[4]]
_method.expression
;
      A    <- _cell.orthogonal_matrix
      U    <- A * _model_site.adp_matrix_beta * Transpose(A) /(2*Pi**2)
 
      _model_site.adp_eigen_system  <- Eigen( U )
 
;
save_


save_model_site.radius_contact
_definition.id                          '_model_site.radius_contact'
_definition.update                      2000-11-03
_description.text
;
     Atomic contact radius of atom specie located at this site.
;
_description.compact                    ModelSiteContactRadius
_name.category_id                       model_site
_name.attribute_id                      radius_contact
_type.container                         Single
_type.value                             Real
_method.expression
;
     With  m  as  model_site
 
    _model_site.radius_contact <- _atom_type[m.type_symbol].radius_contact
;
save_


save_model_site.Cartn_xyz
_definition.id                          '_model_site.Cartn_xyz'
_definition.update                      2000-11-03
_description.text
;
     Vector of Cartesian (orthogonal angstrom) atom site coordinates.
;
_description.compact                    ModelCartCoords
_name.category_id                       model_site
_name.attribute_id                      Cartn_xyz
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
     With  m  as  model_site
 
    _model_site.Cartn_xyz <- _atom_sites_Cartn_transform.matrix * m.fract_xyz
;
save_


save_model_site.fract_xyz
_definition.id                          '_model_site.fract_xyz'
_definition.update                      2000-11-03
_description.text
;
     Vector of fractional atom site coordinates.
;
_description.compact                    ModelFractCoords
_name.category_id                       model_site
_name.attribute_id                      fract_xyz
_type.container                         Vector
_type.value                             Real
_type.purpose                           Measurement
_type_array.dimension                   [3]
_method.expression
;
        With  m  as  model_site
 
                      xyz <- _atom_site[m.label].fract_xyz
 
    _model_site.fract_xyz <- SymEquiv(m.symop, symmetry_equiv, xyz)
;
save_


save_model_site.id
_definition.id                          '_model_site.id'
_definition.update                      2000-11-03
_description.text
;
     Identifier of model site in terms of the atom site label and
     symmetry operator.
;
_description.compact                    ModelSiteId
_name.category_id                       model_site
_name.attribute_id                      id
_type.container                         Tuple
_type.value                             Uchar
_type_array.dimension                   [2]
_method.expression
;
     With m as model_site
 
      _model_site.id <-  Tuple ( [ m.label, m.symop ] )
;
save_


save_model_site.index
_definition.id                          '_model_site.index'
_definition.update                      2000-11-03
_description.text
;
     Index number of an atomic site in the connected  molecule.
;
_description.compact                    ModelSiteIndex
_name.category_id                       model_site
_name.attribute_id                      index
_type.container                         Single
_type.value                             Integer
_type.purpose                           Index
save_


save_model_site.label
_definition.id                          '_model_site.label'
_definition.update                      2000-11-03
_description.text
;
     Label identifies an site in the proposed model.
;
_description.compact                    ModelSiteLabel
_name.category_id                       model_site
_name.attribute_id                      label
_name.linked_item_id                    '_atom_site.label'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Label
_method.expression
;
      _model_site.label <-  _model_site.id [0]
;
save_


save_model_site.mole_index
_definition.id                          '_model_site.mole_index'
_definition.update                      2000-11-03
_description.text
;
     Index number of a distinct molecules in the cell, not related by
     symmetry.
;
_description.compact                    ModelSiteMoleIndex
_name.category_id                       model_site
_name.attribute_id                      mole_index
_type.container                         Single
_type.value                             Integer
_type.purpose                           Index
save_


save_model_site.symop
_definition.id                          '_model_site.symop'
_definition.update                      2000-11-03
_definition.import_id                   '_generic.site_symmetry'
_description.compact                    ModelSiteSymop
_name.category_id                       model_site
_name.attribute_id                      symop
_type.container                         Single
_type.value                             Uchar
_method.expression
;
      _model_site.symop <-  _model_site.id [1]
;
save_


save_model_site.type_symbol
_definition.id                          '_model_site.type_symbol'
_definition.update                      2000-11-03
_description.text
;
     A code to identify the atom specie(s) occupying this site.
;
_description.compact                    ModelSiteAtomType
_name.category_id                       model_site
_name.attribute_id                      type_symbol
_name.linked_item_id                    '_atom_type.symbol'
_type.container                         Single
_type.value                             Uchar
_method.expression
;
    _model_site.type_symbol  <-  AtomType ( _model_site.label )
;
save_

#============================================================================

save_DISPLAY_COLOUR
_definition.id                          display_colour
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to enumerate the display
     colour codes used in the discipline.
;
_category.parent_id                     publication
_category_key.item_id                   '_display_colour.code'
save_


save_display_colour.code
_definition.id                          '_display_colour.code'
_definition.update                      2000-11-03
_description.text
;
     Name of permitted display colour code.
;
_description.compact                    DisplayColourCode
_name.category_id                       display_colour
_name.attribute_id                      code
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_display_colour.RGB
_definition.id                          '_display_colour.RGB'
_definition.update                      2000-11-03
_description.text
;
     The red-green-blue intensities, bases 256, for each colour code.
;
_description.compact                    DisplayColourRGB
_name.category_id                       display_colour
_name.attribute_id                      RGB
_type.container                         Tuple
_type.value                             Integer
_type_array.dimension                   [3]
_method.expression
;
     With c  as  display_colour
 
    _display_colour.RGB  <-  Tuple([ c.red, c.green, c.blue ])
;
save_


save_display_colour.red
_definition.id                          '_display_colour.red'
_definition.import_id                   '_generic.display_colour_intensity'
_name.category_id                       display_colour
_name.attribute_id                      red
save_


save_display_colour.green
_definition.id                          '_display_colour.green'
_definition.import_id                   '_generic.display_colour_intensity'
_name.category_id                       display_colour
_name.attribute_id                      green
save_


save_display_colour.blue
_definition.id                          '_display_colour.blue'
_definition.import_id                   '_generic.display_colour_intensity'
_name.category_id                       display_colour
_name.attribute_id                      blue
save_

#============================================================================

save_REFINE
_definition.id                          refine
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify information about the
     refinement of the structural model.
;
_category.parent_id                     structure
save_


save_refine.special_details
_definition.id                          '_refine.special_details'
_definition.update                      2000-11-03
_description.text
;
     Details of the refinement not specified by other data items.
;
_description.compact                    RefinementDetails
_name.category_id                       refine
_name.attribute_id                      special_details
_type.container                         Single
_type.value                             Char
save_

#----------------------------------------------------------------------------

save_REFINE_DIFF
_definition.id                          refine_diff
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the electron density limits
     in a difference Fourier map after the structure has been refined. The
     rms value is with respect to the arithmetic mean density, and is derived
     from summations over each grid point in the asymmetric unit of the cell.
;
_category.parent_id                     refine
save_


save_refine_diff.density_max
_definition.id                          '_refine_diff.density_max'
_name.category_id                       refine_diff
_name.attribute_id                      density_max
_description.compact                    RefineDiffDensMax
save_


save_refine_diff.density_min
_definition.id                          '_refine_diff.density_min'
_name.category_id                       refine_diff
_name.attribute_id                      density_min
_description.compact                    RefineDiffDensMin
save_


save_refine_diff.density_rms
_definition.id                          '_refine_diff.density_rms'
_name.category_id                       refine_diff
_name.attribute_id                      density_rms
_description.compact                    RefineDiffDensRms
save_

#----------------------------------------------------------------------------

save_REFINE_LS
_definition.id                          refine_ls
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify information about the
     refinement of the structural model.
;
_category.parent_id                     refine
save_


save_refine_ls.abs_structure_details
_definition.id                          '_refine_ls.abs_structure_details'
_definition.update                      2000-11-03
_description.text
;
     Details on the absolute structure and how it was determined.
;
_description.compact                    RefineAbsStructDetails
_name.category_id                       refine_ls
_name.attribute_id                      abs_structure_details
_type.container                         Single
_type.value                             Char
save_


save_refine_ls.abs_structure_Flack
_definition.id                          '_refine_ls.abs_structure_Flack'
_definition.update                      2000-11-03
_description.text
;
     Measure of absolute structure as defined by Flack (Acta Cryst. A39,
     876-881). For non-centrosymmetric structures the value must lie in the
     99.97% Gaussian confidence interval  -3u =< x =< 1 + 3u and a standard
     uncertainty u must be supplied. If the listed atom site coordinates
     correspond to the absolute structure expected from the Friedel
     differences, the Flack value will be within 3u of 0.0; if the atom
     site coordinates correspond to the inverse of the absolute structure
     the value will close to 1.0. The value is not applicable for
     centrosymmetric structures.
;
_description.compact                    RefineAbsStructFlack
_name.category_id                       refine_ls
_name.attribute_id                      abs_structure_Flack
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:1.0 
save_


save_refine_ls.abs_structure_Rogers
_definition.id                          '_refine_ls.abs_structure_Rogers'
_definition.update                      2000-11-03
_description.text
;
     Measure of absolute structure as defined by Rogers (Acta Cryst. A37,
     734-741). For non-centrosymmetric structures the value must lie in
     the 99.97% Gaussian confidence interval -1 -3u =< \h =< 1 + 3u and a
     standard uncertainty u must be supplied. If the atom site coordinates
     correspond to the absolute structure expected from the Friedel
     differences, the Rogers value will be within 3u of 1.0; if the atom
     site coordinates correspond to the inverse of the absolute structure
     the value will close to -1.0. The value is not applicable for
     centrosymmetric structures. ^^ **** check values
;
_description.compact                    RefineAbsStructRogers
_name.category_id                       refine_ls
_name.attribute_id                      abs_structure_Rogers
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      -1.0:1.0 
save_


save_refine_ls.d_res_high
_definition.id                          '_refine_ls.d_res_high'
_definition.update                      2000-11-03
_description.text
;
     Highest resolution for the reflections used in refinement.
     This corresponds to the smallest interpanar d value.
;
_description.compact                    RefineResolutionHigh
_name.category_id                       refine_ls
_name.attribute_id                      d_res_high
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_refine_ls.d_res_low
_definition.id                          '_refine_ls.d_res_low'
_definition.update                      2000-11-03
_description.text
;
     Lowest resolution for the reflections used in refinement.
     This corresponds to the largest interpanar d value.
;
_description.compact                    RefineResolutionLow
_name.category_id                       refine_ls
_name.attribute_id                      d_res_low
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_refine_ls.extinction_coef
_definition.id                          '_refine_ls.extinction_coef'
_definition.update                      2000-11-03
_description.text
;
     Extinction coefficient used to calculate the correction factor applied
     to the structure-factor data. How the extinction coefficient is
     estimated and applied is specified in the definitions of
     _refine_ls.extinction_expression and _refine_ls.extinction_method.
 
     For the 'Zachariasen' method it is the r* value (Zachariasen (1967)
     Acta Cryst. 23, 558-564; Larson (1967) Acta Cryst. 23, 664-665)
 
     For the 'Becker-Coppens type 1 isotropic' method it is the 'g' value,
     and for 'Becker-Coppens type 2 isotropic' method it is the 'rho' value
     (Becker & Coppens (1974) Acta Cryst. A30, 129-153).
 
     Note the magnitude of these values is usually about 10000.
;
_description.compact                    RefineExtinctionCoeff
_name.category_id                       refine_ls
_name.attribute_id                      extinction_coef
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_description_example.case               3472(52)
_description_example.detail             'Zachariasen coefficient r* = 0.347(5) E04'
save_


save_refine_ls.extinction_expression
_definition.id                          '_refine_ls.extinction_expression'
_definition.update                      2000-11-03
_description.text
;
     Description or reference of the extinction correction equation used
     to apply the _refine_ls.extinction_coef. This information should be
     sufficient to reproduce the extinction correction factors applied.
;
_description.compact                    RefineExtinctionExpression
_name.category_id                       refine_ls
_name.attribute_id                      extinction_expression
_type.container                         Single
_type.value                             Char
_description_example.case
;
              Larson, A. C. (1970). "Crystallographic Computing", edited by
              F. R. Ahmed. Eq. (22) p. 292.  Copenhagen: Munksgaard.
;
save_


save_refine_ls.extinction_method
_definition.id                          '_refine_ls.extinction_method'
_definition.update                      2000-11-03
_description.text
;
     Description of the extinction correction method applied with the data
     item _refine_ls.extinction_coef. This description should include
     information about the correction method, either 'Becker-Coppens' or
     'Zachariasen'. The latter is sometimes referred to as the 'Larson'
     method even though it employs Zachariasen's formula.
 
     The Becker-Coppens procedure is referred to as 'type 1' when correcting
     secondary extinction dominated by the mosaic spread; as 'type 2' when
     secondary extinction is dominated by particle size and includes a primary
     extinction component; and as 'mixed' when there are types 1 and 2.
 
     For the Becker-Coppens method it is also necessary to set the mosaic
     distribution as either 'Gaussian' or 'Lorentzian'; and the nature of the
     extinction as 'isotropic' or 'anisotropic'. Note that if either the
     'mixed' or 'anisotropic' corrections are applied the multiple coefficients
     cannot be contained in the _refine_ls.extinction_coef and must be listed
     in _refine.special_details.
 
     Ref:  Becker, P. J. & Coppens, P. (1974). Acta Cryst. A30, 129-153.
           Zachariasen, W. H. (1967). Acta Cryst. 23, 558-564.
           Larson, A. C. (1967). Acta Cryst. 23, 664-665.
;
_description.compact                    RefineExtinctionMethod
_name.category_id                       refine_ls
_name.attribute_id                      extinction_method
_type.container                         Single
_type.value                             Char
_description_example.case               'Becker-Coppens type 2 Gaussian isotropic'
save_


save_refine_ls.goodness_of_fit_all
_definition.id                          '_refine_ls.goodness_of_fit_all'
_definition.update                      2000-11-03
_description.text
;
     Least-squares goodness-of-fit parameter S for all reflections after
     the final cycle of refinement. Ideally, account should be taken of
     parameters restrained in the least squares.
 
                   {  sum { w [ Y(obs) - Y(calc) ]^2^ }  }^1/2^
               S = { ----------------------------------- }
                   {            Nref - Nparam            }
 
               Y(obs)  = the observed coefficients
                         (see @refine_ls_structure_factor_coef)
               Y(calc) = the calculated coefficients
                         (see @refine_ls_structure_factor_coef)
               w       = the least-squares reflection weight
                         [1/(u^2^)]
               u       = standard uncertainty
 
               Nref   = the number of reflections used in the refinement
               Nparam = the number of refined parameters
 
               and the sum is taken over the specified reflections
;
_description.compact                    RefineLsGofAllReflns
_name.category_id                       refine_ls
_name.attribute_id                      goodness_of_fit_all
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.goodness_of_fit_gt
_definition.id                          '_refine_ls.goodness_of_fit_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_refine_ls.goodness_of_fit_obs'
_description.text
;
     Least-squares goodness-of-fit parameter S for significantly intense
     reflections, (see _reflns.threshold_expression), after the final cycle
     of refinement. Account should be taken of parameters restrained in the
     least squares. See _refine_ls.goodness_of_fit_all for the S expression.
;
_description.compact                    RefineLsGofGtReflns
_name.category_id                       refine_ls
_name.attribute_id                      goodness_of_fit_gt
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.goodness_of_fit_ref
_definition.id                          '_refine_ls.goodness_of_fit_ref'
_definition.update                      2000-11-03
_description.text
;
     Least-squares goodness-of-fit parameter S for those reflections included
     in the final cycle of refinement. Account should be taken of restrained
     parameters. See _refine_ls.goodness_of_fit_all for the S expression.
;
_description.compact                    RefineLsGofRefineReflns
_name.category_id                       refine_ls
_name.attribute_id                      goodness_of_fit_ref
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.hydrogen_treatment
_definition.id                          '_refine_ls.hydrogen_treatment'
_definition.update                      2000-11-03
_description.text
;
     Code identifying how hydrogen atoms were treated in the refinement.
;
_description.compact                    RefineLsHatomTreatment
_name.category_id                       refine_ls
_name.attribute_id                      hydrogen_treatment
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
refall 'refined all H parameters'
refxyz 'refined H coordinates only'
refU 'refined H U only'
noref 'no refinement of H parameters'
constr 'H parameters constrained'
mixed 'some constrained, some independent'
undef 'H-atom parameters not defined'
_enumeration.default                    undef
save_


save_refine_ls.matrix_type
_definition.id                          '_refine_ls.matrix_type'
_definition.update                      2000-11-03
_description.text
;
     Code identifying the matrix type used for least-squares derivatives.
;
_description.compact                    RefineLsMatrixType
_name.category_id                       refine_ls
_name.attribute_id                      matrix_type
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
full full
fullcycle 'full with fixed elements per cycle'
atomblock 'block diagonal per atom'
userblock 'user-defined blocks'
diagonal 'diagonal elements only'
sparse 'selected elements only'
_enumeration.default                    full
save_


save_refine_ls.number_constraints
_definition.id                          '_refine_ls.number_constraints'
_definition.update                      2000-11-03
_description.text
;
     Count of constrained (non-refined or dependent) parameters in the
     least-squares process. These may be due to symmetry or any constraint
     process (e.g. rigid-body refinement). See also _atom_site.constraints
     and _atom_site.refinement_flags. A general description of constraints
     may appear in _refine.special_details.
;
_description.compact                    RefineLsConstraintsCount
_name.category_id                       refine_ls
_name.attribute_id                      number_constraints
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
_enumeration.default                    0
save_


save_refine_ls.number_parameters
_definition.id                          '_refine_ls.number_parameters'
_definition.update                      2000-11-03
_description.text
;
     Count of parameters refined in the least-squares process. If possible
     this number should include the restrained parameters. The restrained
     parameters are distinct from the constrained parameters (where one or
     more parameters are linearly dependent on the refined value of another).
     Least-squares restraints often depend on geometry or energy
     considerations and this makes their direct contribution to this number,
     and to the goodness-of-fit calculation, difficult to assess.
;
_description.compact                    RefineLsParametersCount
_name.category_id                       refine_ls
_name.attribute_id                      number_parameters
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_refine_ls.number_reflns
_definition.id                          '_refine_ls.number_reflns'
_definition.update                      2000-11-03
_description.text
;
     Number of unique reflections used in the least-squares refinement.
;
_description.compact                    RefineLsReflectionsCount
_name.category_id                       refine_ls
_name.attribute_id                      number_reflns
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      1:1 
save_


save_refine_ls.number_restraints
_definition.id                          '_refine_ls.number_restraints'
_definition.update                      2000-11-03
_description.text
;
     Number of restrained parameters in the least-squares refinement. These
     parameters do not directly dependent on another refined parameter. Often
     restrained parameters involve geometry or energy dependencies. See also
     _atom_site.constraints and _atom_site.refinement_flags. A description
     of refinement constraints may appear in _refine.special_details.
;
_description.compact                    RefineLsConstraintsCount
_name.category_id                       refine_ls
_name.attribute_id                      number_restraints
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_refine_ls.R_factor_all
_definition.id                          '_refine_ls.R_factor_all'
_definition.update                      2000-11-03
_description.text
;
     Residual factor for all reflections satisfying the resolution limits
     specified by _refine_ls.d_res_high and _refine_ls.d_res_low. This is
     the conventional R factor. See also wR factor definitions.
 
                   sum | F(meas) - F(calc) |
               R = ------------------------
                         sum | F(meas) |
 
               F(meas) = the measured structure-factor amplitudes
               F(calc) = the calculated structure-factor amplitudes
 
               and the sum is taken over the specified reflections
;
_description.compact                    RefineLsResid(F)AllReflns
_name.category_id                       refine_ls
_name.attribute_id                      R_factor_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.R_factor_gt
_definition.id                          '_refine_ls.R_factor_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_refine_ls.R_factor_obs'
_description.text
;
     Residual factor for the reflections judged significantly intense
     (see _reflns.number_gt and _reflns.threshold_expression) and included
     in the refinement. The reflections also satisfy the resolution limits
     specified by _refine_ls.d_res_high and _refine_ls.d_res_low. This is
     the conventional R factor (expressed in _refine_ls.R_factor_all).
;
_description.compact                    RefineLsResid(F)GtReflns
_name.category_id                       refine_ls
_name.attribute_id                      R_factor_gt
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.R_Fsqd_factor
_definition.id                          '_refine_ls.R_Fsqd_factor'
_definition.update                      2000-11-03
_description.text
;
     Residual factor R(Fsqd), calculated on the squared amplitudes of the
     measured and calculated structure factors, for significantly intense
     reflections (satisfying _reflns.threshold_expression) and included in
     the refinement. The reflections also satisfy the resolution limits
     specified by _refine_ls.d_res_high and _refine_ls.d_res_low.
 
                          sum | F(meas)^2^ - F(calc)^2^ |
               R(Fsqd) = -------------------------------
                                  sum F(meas)^2^
 
               F(meas)^2^ = squares of the measured structure-factor
               F(calc)^2^ = squares of the calculated structure-factor
 
               and the sum is taken over the specified reflections
;
_description.compact                    RefineLsResid(Fsqd)GtReflns
_name.category_id                       refine_ls
_name.attribute_id                      R_Fsqd_factor
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.R_I_factor
_definition.id                          '_refine_ls.R_I_factor'
_definition.update                      2000-11-03
_description.text
;
     Residual factor R(I) for significantly intense reflections (satisfying
     _reflns.threshold_expression) and included in the refinement. This is
     most often calculated in Rietveld refinements of powder data, where it
     is referred to as R~B~ or R~Bragg~.
 
                       sum | I(meas) - I(calc) |
               R(I) =  ------------------------
                              sum | I(meas) |
 
               I(meas) = the net measured intensities
               I(calc) = the net calculated intensities
 
               and the sum is taken over the specified reflections
;
_description.compact                    RefineLsResid(I)GtReflns
_name.category_id                       refine_ls
_name.attribute_id                      R_I_factor
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.restrained_S_all
_definition.id                          '_refine_ls.restrained_S_all'
_definition.update                      2000-11-03
_description.text
;
     Least-squares goodness-of-fit parameter S' for all reflections after
     the final cycle of least squares. This parameter explicitly includes
     the restraints applied in the least-squares process. See also
     _refine_ls.goodness_of_fit_all definition.
 
            {sum { w [ Y(meas) - Y(calc) ]^2^ }                   }^1/2^
            {         + sum~r~ { w~r~ [ P(calc) - P(targ) ]^2^ } }
       S' = { -------------------------------------------------- }
            {            N~ref~ + N~restr~ - N~param~            }
 
               Y(meas)  = the measured coefficients
                          (see _refine_ls.structure_factor_coef)
               Y(calc)  = the observed coefficients
                          (see _refine_ls.structure_factor_coef)
               w        = the least-squares reflection weight
                          [1/square of standard uncertainty (e.s.d.)]
 
               P(calc)  = the calculated restraint values
               P(targ)  = the target restraint values
               w~r~     = the restraint weight
 
               N~ref~   = the number of reflections used in the refinement
                        (see _refine_ls.number_reflns)
               N~restr~ = the number of restraints
                        (see _refine_ls.number_restraints)
               N~param~ = the number of refined parameters
                        (see _refine_ls.number_parameters)
 
               sum     is taken over the specified reflections
               sum~r~  is taken over the restraints
;
_description.compact                    RefineLsGofRestrainedAllReflns
_name.category_id                       refine_ls
_name.attribute_id                      restrained_S_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.restrained_S_gt
_definition.id                          '_refine_ls.restrained_S_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_refine_ls.restrained_S_obs'
_description.text
;
     Least-squares goodness-of-fit parameter S' for significantly intense
     reflections (satisfying _reflns.threshold_expression) after the final
     cycle of least squares. This parameter explicitly includes the restraints
     applied. The expression for S' is given in _refine_ls.restrained_S_all.
     See also _refine_ls.goodness_of_fit_all definition.
;
_description.compact                    RefineLsGofRestrainedGtReflns
_name.category_id                       refine_ls
_name.attribute_id                      restrained_S_gt
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.shift_over_su_max
_definition.id                          '_refine_ls.shift_over_su_max'
_definition.update                      2000-11-03
_alias.definition_id                    '_refine_ls.shift/esd_max'
_description.text
;
     Largest l-s parameter-shift (unsigned) to standard-uncertainty RATIO.
;
_description.compact                    RefineLsMaxShift/Su
_name.category_id                       refine_ls
_name.attribute_id                      shift_over_su_max
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.shift_over_su_mean
_definition.id                          '_refine_ls.shift_over_su_mean'
_definition.update                      2000-11-03
_alias.definition_id                    '_refine_ls.shift/esd_mean'
_description.text
;
     Mean l-s parameter-shift (unsigned) to standard-uncertainty RATIO.
;
_description.compact                    RefineLsMeanShift/Su
_name.category_id                       refine_ls
_name.attribute_id                      shift_over_su_mean
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.structure_factor_coef
_definition.id                          '_refine_ls.structure_factor_coef'
_definition.update                      2000-11-03
_description.text
;
     Structure-factor coefficient used in the least-squares refinement process.
;
_description.compact                    RefineLsStructFactorCoeff
_name.category_id                       refine_ls
_name.attribute_id                      structure_factor_coef
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
F 'structure factor magnitude'
Fsqd 'structure factor squared'
Inet 'net intensity'
_enumeration.default                    F
save_


save_refine_ls.weighting_details
_definition.id                          '_refine_ls.weighting_details'
_definition.update                      2000-11-03
_description.text
;
     Description of special aspects of the weighting scheme used in the
     least-squares refinement. Used to describe the weighting when the
     value of _refine_ls.weighting_scheme is specified as 'calc'.
;
_description.compact                    RefineLsWeightDetails
_name.category_id                       refine_ls
_name.attribute_id                      weighting_details
_type.container                         Single
_type.value                             Char
_description_example.case
;
        Sigdel model of Konnert-Hendrickson:
              Sigdel = Afsig +  Bfsig*(sin(\q)/\l - 1/6)
              Afsig  = 22.0, Bfsig = 150.0 at the beginning of refinement.
              Afsig  = 16.0, Bfsig =  60.0 at the end of refinement.
;
save_


save_refine_ls.weighting_scheme
_definition.id                          '_refine_ls.weighting_scheme'
_definition.update                      2000-11-03
_description.text
;
     General description of the weighting scheme used in the least-squares.
     An enumerated code should be contained in this description.
;
_description.compact                    RefineLsWeightCode
_name.category_id                       refine_ls
_name.attribute_id                      weighting_scheme
_type.container                         Single
_type.value                             Char
loop_
_enumeration_set.code
_enumeration_set.detail
sigma 'based on measured s.u.'s'
unit 'unit or no weights applied'
calc 'calculated weights applied'
_enumeration.default                    sigma
save_


save_refine_ls.wR_factor_all
_definition.id                          '_refine_ls.wR_factor_all'
_definition.update                      2000-11-03
_description.text
;
     Weighted residual factors for all reflections satisfying the resolution
     limits specified by _refine_ls.d_res_high and _refine_ls.d_res_low.
     See also the _refine_ls.R_factor_all definition.
 
            ( sum w [ Y(meas) - Y(calc) ]^2^  )^1/2^
       wR = ( ------------------------------ )
            (         sum w Y(meas)^2^       )
 
       Y(meas) = the measured   amplitude _refine_ls.structure_factor_coef
       Y(calc) = the calculated amplitude _refine_ls.structure_factor_coef
       w       = the least-squares weight
 
       and the sum is taken over the specified reflections
;
_description.compact                    RefineLsWResidAllReflns
_name.category_id                       refine_ls
_name.attribute_id                      wR_factor_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.wR_factor_gt
_definition.id                          '_refine_ls.wR_factor_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_refine_ls.wR_factor_obs'
_description.text
;
     Weighted residual factors for significantly intense reflections
     (satisfying @reflns_threshold_expression) included in the refinement.
     The reflections must also satisfy the resolution limits established by
     _refine_ls.d_res_high and _refine_ls.d_res_low. The expression is given
     in the _refine_ls.wR_factor_all definition.
;
_description.compact                    RefineLsWResidGtReflns
_name.category_id                       refine_ls
_name.attribute_id                      wR_factor_gt
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls.wR_factor_ref
_definition.id                          '_refine_ls.wR_factor_ref'
_definition.update                      2000-11-03
_description.text
;
     Weighted residual factors for reflections included in the refinement
     which satisfy the limits specified by _refine_ls.d_res_high and
     _refine_ls.d_res_low. See expression in _refine_ls.wR_factor_gt
;
_description.compact                    RefineLsWResidRefineReflns
_name.category_id                       refine_ls
_name.attribute_id                      wR_factor_ref
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_

#----------------------------------------------------------------------------

save_REFINE_LS_CLASS
_definition.id                          refine_ls_class
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify information about the
     refinement of the structural model.
;
_category.parent_id                     refine_ls
_category_key.item_id                   '_refine_ls_class.code'
save_


save_refine_ls_class.code
_definition.id                          '_refine_ls_class.code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a certain reflection class.
;
_description.compact                    LsShellCode
_name.category_id                       refine_ls_class
_name.attribute_id                      code
_name.linked_item_id                    '_reflns_class.code'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
_description_example.case               c1
save_


save_refine_ls_class.d_res_high
_definition.id                          '_refine_ls_class.d_res_high'
_definition.update                      2000-11-03
_description.text
;
     Highest resolution for the reflections in this class.
     This corresponds to the smallest interpanar d value.
;
_description.compact                    LsShellResolHigh
_name.category_id                       refine_ls_class
_name.attribute_id                      d_res_high
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_refine_ls_class.d_res_low
_definition.id                          '_refine_ls_class.d_res_low'
_definition.update                      2000-11-03
_description.text
;
     Lowest resolution for the reflections in this class.
     This corresponds to the largest interpanar d value.
;
_description.compact                    LsShellResolLow
_name.category_id                       refine_ls_class
_name.attribute_id                      d_res_low
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_refine_ls_class.R_factor_all
_definition.id                          '_refine_ls_class.R_factor_all'
_definition.update                      2000-11-03
_description.text
;
     Residual factor for reflections in this class included in the refinement.
     See _refine_ls.R_factor_all definition for details.
;
_description.compact                    LsShellResid(F)AllReflns
_name.category_id                       refine_ls_class
_name.attribute_id                      R_factor_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls_class.R_factor_gt
_definition.id                          '_refine_ls_class.R_factor_gt'
_definition.update                      2000-11-03
_description.text
;
     Residual factor for the reflections in this class judged significantly
     intense (see _reflns.threshold_expression) and included in the refinement.
     See _refine_ls.R_factor_all definition for details.
;
_description.compact                    LsShellResid(F)GtReflns
_name.category_id                       refine_ls_class
_name.attribute_id                      R_factor_gt
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls_class.R_Fsqd_factor
_definition.id                          '_refine_ls_class.R_Fsqd_factor'
_definition.update                      2000-11-03
_description.text
;
     Residual factor R(F^2^) for reflections in this class judged significantly
     intense (see _reflns.threshold_expression) and included in the refinement.
     See _refine_ls.R_Fsqd_factor definition for details.
;
_description.compact                    LsShellResid(Fsqd)GtReflns
_name.category_id                       refine_ls_class
_name.attribute_id                      R_Fsqd_factor
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls_class.R_I_factor
_definition.id                          '_refine_ls_class.R_I_factor'
_definition.update                      2000-11-03
_description.text
;
     Residual factor R(I) for reflections in this class judged significantly
     intense (see _reflns.threshold_expression) and included in the refinement.
     See _refine_ls.R_I_factor definition for details.
;
_description.compact                    LsShellResid(I)GtReflns
_name.category_id                       refine_ls_class
_name.attribute_id                      R_I_factor
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_refine_ls_class.wR_factor_all
_definition.id                          '_refine_ls_class.wR_factor_all'
_definition.update                      2000-11-03
_description.text
;
     Weight residual for all reflections in this class judged significantly
     intense (see _reflns.threshold_expression) and included in the refinement.
     See _refine_ls.wR_factor_all definition for details.
;
_description.compact                    LsShellWResid(F)GtReflns
_name.category_id                       refine_ls_class
_name.attribute_id                      wR_factor_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_

#============================================================================

save_REFLN
_definition.id                          refln
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe the reflection data
     used in the refinement of a crystallograhic structure model.
;
_description.compact                    ReflnList
_category.parent_id                     reflns
_category_key.item_id                   '_refln.hkl'
save_


save_refln.A_calc
_definition.id                          '_refln.A_calc'
_definition.update                      2000-11-03
_description.text
;
     The calculated real structure-factor component A =|Fcalc|cos(phase)
;
_description.compact                    ReflnCalcA
_name.category_id                       refln
_name.attribute_id                      A_calc
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_method.expression
;
    _refln.A_calc <- Real ( _refln.F_complex )
;
save_


save_refln.A_meas
_definition.id                          '_refln.A_meas'
_definition.update                      2000-11-03
_description.text
;
     The measured real structure-factor component A =|Fmeas|cos(phase)
;
_description.compact                    ReflnMeasA
_name.category_id                       refln
_name.attribute_id                      A_meas
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
save_


save_refln.B_calc
_definition.id                          '_refln.B_calc'
_definition.update                      2000-11-03
_description.text
;
     The calculated imaginary structure-factor component B =|Fcalc|sin(phase)
;
_description.compact                    ReflnCalcB
_name.category_id                       refln
_name.attribute_id                      B_calc
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_method.expression
;
    _refln.B_calc <- Imag ( _refln.F_complex )
;
save_


save_refln.B_meas
_definition.id                          '_refln.B_meas'
_definition.update                      2000-11-03
_description.text
;
     The measured imaginary structure-factor component B =|Fmeas|sin(phase)
;
_description.compact                    ReflnMeasB
_name.category_id                       refln
_name.attribute_id                      B_meas
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
save_


save_refln.class_code
_definition.id                          '_refln.class_code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying the class to which this reflection has been
     assigned. This code must match a value of _reflns_class.code.
     Reflections may be grouped into classes for a variety of
     purposes. For example, for modulated structures each reflection
     class may be defined by the number m=sum|m~i~|, where the m~i~
     are the integer coefficients that, in addition to h,k,l, index
     the corresponding diffraction vector in the basis defined
     for the reciprocal lattice.
;
_description.compact                    ReflnClassCode
_name.category_id                       refln
_name.attribute_id                      class_code
_name.linked_item_id                    '_reflns_class.code'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_refln.crystal_id
_definition.id                          '_refln.crystal_id'
_definition.update                      2000-11-03
_description.text
;
     Name identifying each crystal if multiple crystals are used. Is
     used to link with crystals identified by _exptl_crystal.id.
;
_description.compact                    ReflnCrystalId
_name.category_id                       refln
_name.attribute_id                      crystal_id
_name.linked_item_id                    '_exptl_crystal.id'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_refln.d_spacing
_definition.id                          '_refln.d_spacing'
_definition.update                      2000-11-03
_description.text
;
     The distance in angstroms between lattice planes in the crystal
     with the indices _refln.hkl for this reflection.
;
_description.compact                    ReflnDspacing
_name.category_id                       refln
_name.attribute_id                      d_spacing
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
_method.expression
;
    _refln.d_spacing = 2. / _refln.sin_theta_over_lambda
;
save_


save_refln.F_calc
_definition.id                          '_refln.F_calc'
_definition.update                      2000-11-03
_description.text
;
     The structure factor amplitude for the reflection calculated from
     the atom site data.
;
_description.compact                    ReflnCalcF
_name.category_id                       refln
_name.attribute_id                      F_calc
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
loop_
_method.class
_method.expression
DEFINITION
;
         If (_diffrn_radiation.probe == "neutron") {_units.code <- "femtometres"
  } Else If (_diffrn_radiation.probe == "electron"){_units.code <- "volts"
  } Else                                           {_units.code <- "electrons"
  }
;
EVALUATION
;
      _refln.F_calc  <-  Magn ( _refln.F_complex )
;
save_


save_refln.F_complex
_definition.id                          '_refln.F_complex'
_definition.update                      2000-11-03
_description.text
;
     The structure factor vector for the reflection calculated from
     the atom site data.
;
_description.compact                    ReflnComplexF
_name.category_id                       refln
_name.attribute_id                      F_complex
_type.container                         Single
_type.value                             Complex
_type.purpose                           Measurement
loop_
_method.class
_method.expression
DEFINITION
;
         If (_diffrn_radiation.probe == "neutron") {_units.code <- "femtometres"
  } Else If (_diffrn_radiation.probe == "electron"){_units.code <- "volts"
  } Else                                           {_units.code <- "electrons"
  }
;
EVALUATION
;
   With r  as  refln
 
      fc  <-  Complex (0., 0.)
      h   <-  r.hkl
      bb  <-  r.sin_theta_over_lambda **2
      uu  <-  8*Pi**2 * bb
 
   Loop a  as  atom_site  {
 
          x  <-  a.fract_xyz
 
          f  <-  ( r.form_factor_table [a.type_symbol] *
                                      a.symmetry_multiplicity * a.occupancy )
 
          If      (a.adp_type == 'uiso') t <- Exp(-a.U_iso_or_equiv * uu)
          Else If (a.adp_type == 'biso') t <- Exp(-a.B_iso_or_equiv * bb)
          Else                           u <- a.matrix_beta
 
      Loop s  as  symmetry_equiv  {
 
              If (a.adp_type == 'uani') t <- Exp(-h * s.R * u * s.RT * h)
 
              fc +<-  f * t * ExpImag( TwoPi * ( h * ( s.R * x + s.T)))
   }  }
      _refln.F_complex  <-  fc / _symmetry.multiplicity
;
save_


save_refln.F_meas
_definition.id                          '_refln.F_meas'
_definition.update                      2000-11-03
_description.text
;
     The structure factor amplitude for the reflection derived from the
     measured intensities.
;
_description.compact                    ReflnMeasF
_name.category_id                       refln
_name.attribute_id                      F_meas
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
loop_
_method.class
_method.expression
DEFINITION
;
         If (_diffrn_radiation.probe == "neutron") {_units.code <- "femtometres"
  } Else If (_diffrn_radiation.probe == "electron"){_units.code <- "volts"
  } Else                                           {_units.code <- "electrons"
  }
;
EVALUATION
;
                _refln.F_meas  <-  Sqrt ( _refln.F_squared_meas )
;
save_


save_refln.F_sigma   ## <<<<<<< to be discussed as a Measure issue
_definition.id                          '_refln.F_sigma'
_definition.update                      2000-11-03
_description.text
;
     The standard uncertainty of the measured structure factor amplitude.
     This item has been replaced by the implicit su of _refln.F_meas.
;
_description.compact                    ReflnSigmaF
_name.category_id                       refln
_name.attribute_id                      F_sigma
_type.container                         Single
_type.value                             Real
loop_
_method.class
_method.expression
DEFINITION
;
         If (_diffrn_radiation.probe == "neutron") {_units.code <- "femtometres"
  } Else If (_diffrn_radiation.probe == "electron"){_units.code <- "volts"
  } Else                                           {_units.code <- "electrons"
  }
;
EVALUATION
;
                _refln.F_sigma  <-  _refln.F_squared_sigma / 2
;
save_


save_refln.F_squared_calc
_definition.id                          '_refln.F_squared_calc'
_definition.update                      2000-11-03
_description.text
;
     The structure factor amplitude squared for the reflection calculated from
     the atom site data.
;
_description.compact                    ReflnCalcFsqd
_name.category_id                       refln
_name.attribute_id                      F_squared_calc
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
loop_
_method.class
_method.expression
DEFINITION
;
    If      (_diffrn_radiation.probe == "neutron") {
                                         _units.code <- "femtometres_squared"
  } Else If (_diffrn_radiation.probe == "electron") {
                                         _units.code <- "volts_squared"
  } Else                                {_units.code <- "electrons_squared"
  }
;
EVALUATION
;
                _refln.F_squared_calc  <-   _refln.F_calc **2
;
save_


save_refln.F_squared_meas
_definition.id                          '_refln.F_squared_meas'
_definition.update                      2000-11-03
_description.text
;
     The structure factor amplitude for the reflection derived from the
     measured intensities.
;
_description.compact                    ReflnMeasFsqd
_name.category_id                       refln
_name.attribute_id                      F_squared_meas
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
loop_
_method.class
_method.expression
DEFINITION
;
    If      (_diffrn_radiation.probe == "neutron") {
                                         _units.code <- "femtometres_squared"
  } Else If (_diffrn_radiation.probe == "electron") {
                                         _units.code <- "volts_squared"
  } Else                                {_units.code <- "electrons_squared"
  }
;
EVALUATION
;
                _refln.F_squared_meas  <-  _refln.F_meas **2
;
save_


save_refln.F_squared_sigma  ## <<<<<<<<< discuss as a Measure issue
_definition.id                          '_refln.F_squared_sigma'
_definition.update                      2000-11-03
_description.text
;
     The standard uncertainty of the measured structure factor squared.
     This item has been replaced by the implicit su of _refln.F_squared_meas.
;
_name.category_id                       refln
_name.attribute_id                      F_squared_sigma
_type.container                         Single
_type.value                             Real
loop_
_method.class
_method.expression
DEFINITION
;
    If      (_diffrn_radiation.probe == "neutron") {
                                         _units.code <- "femtometres_squared"
  } Else If (_diffrn_radiation.probe == "electron") {
                                         _units.code <- "volts_squared"
  } Else                                {_units.code <- "electrons_squared"
  }
;
EVALUATION
;
                _refln.F_squared_sigma  <-  2. * _refln.F_sigma
;
save_


save_refln.form_factor_table
_definition.id                          '_refln.form_factor_table'
_definition.update                      2000-11-03
_description.text
;
     Atomic scattering factor table for the scattering angle
     of this diffraction vector and atom types in structure.
;
_description.compact                    ReflnFormFactorTable
_name.category_id                       refln
_name.attribute_id                      form_factor_table
_type.container                         Table
_type.value                             Real
_method.expression
;
    With r  as  refln
 
     table = Table ()
     s  <-   r.sin_theta_over_lambda
 
    Loop t  as  atom_type  {
 
       If (_diffrn_radiation.probe == 'neutron') {
 
            f  <-  t.length_neutron
 
       } Else If (s < 2.0 ) {
 
            c  <-  t.Cromer_Mann_coeffs
 
            f  <- (c[0] + c[1] * Exp (-c[2] * s*s)
                        + c[3] * Exp (-c[4] * s*s)
                        + c[5] * Exp (-c[6] * s*s)
                        + c[7] * Exp (-c[8] * s*s))
       } Else {
 
            c  <-  t.hi_ang_Fox_coeffs
 
            f  <-  Exp ( c[0] + c[1]*s + c[2]*s*s + c[3]*s*s*s )
       }
        table [ t.symbol ]  <-  f
    }
       _refln.form_factor_table  <-  table
;
save_


save_refln.include_status
_definition.id                          '_refln.include_status'
_definition.update                      2000-11-03
_alias.definition_id                    '_refln.observed_status'
_description.text
;
     Code indicating how the reflection was included in the refinement
     and R-factor calculations.
;
_description.compact                    ReflnRefineInclusion
_name.category_id                       refln
_name.attribute_id                      include_status
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
o 'included in all; > _reflns.threshold_expression; within d-res limits'
< 'included partly; < _reflns.threshold_expression; within d-res limits'
- 'systematically absent reflection'
x 'unreliable measurement -- not used'
h '> _refine_ls.d_res_high'
l '< _refine_ls.d_res_low'
_enumeration.default                    o
save_


save_refln.hkl
_definition.id                          '_refln.hkl'
_definition.update                      2000-11-03
_description.text
;
     The Miller indices as a reciprocal space vector.
;
_description.compact                    ReflnHkl
_name.category_id                       refln
_name.attribute_id                      hkl
_type.container                         Vector
_type.value                             Real
_type_array.dimension                   [3]
_method.expression
;
     With r  as  refln
 
            _refln.hkl <- Vector ( [r.index_h, r.index_k, r.index_l] )
;
save_


save_refln.index_h
_definition.id                          '_refln.index_h'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       refln
_name.attribute_id                      index_h
save_


save_refln.index_k
_definition.id                          '_refln.index_k'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       refln
_name.attribute_id                      index_k
save_


save_refln.index_l
_definition.id                          '_refln.index_l'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       refln
_name.attribute_id                      index_l
save_


save_refln.intensity_calc
_definition.id                          '_refln.intensity_calc'
_definition.update                      2000-11-03
_description.text
;
     The intensity of the reflection calculated from the atom site data.
;
_description.compact                    ReflnCalcI
_name.category_id                       refln
_name.attribute_id                      intensity_calc
_type.container                         Single
_type.value                             Real
_method.expression
;
    _refln.intensity_calc  <-  _refln.F_squared_calc / _refln.Lp_factor
;
save_


save_refln.intensity_meas
_definition.id                          '_refln.intensity_meas'
_definition.update                      2000-11-03
_description.text
;
     The intensity of the reflection derived from the diffraction measurements.
;
_description.compact                    ReflnMeasI
_name.category_id                       refln
_name.attribute_id                      intensity_meas
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
save_


save_refln.Lp_factor
_definition.id                          '_refln.Lp_factor'
_definition.update                      2000-11-03
_description.text
;
     The Lorentz-polarization factor appropriate for the instrument
     used to measure the diffraction intensity. This is applied to
     convert the net intensity into the measured F squared.
;
_description.compact                    ReflnLpFactor
_name.category_id                       refln
_name.attribute_id                      Lp_factor
_type.container                         Single
_type.value                             Real
save_


save_refln.mean_path_length_tbar
_definition.id                          '_refln.mean_path_length_tbar'
_definition.update                      2000-11-03
_description.text
;
     Mean path length through the crystal for this diffraction vector.
;
_description.compact                    ReflnMeanPathLength
_name.category_id                       refln
_name.attribute_id                      mean_path_length_tbar
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             millimetres
save_


save_refln.phase_calc
_definition.id                          '_refln.phase_calc'
_definition.update                      2000-11-03
_description.text
;
     The phase of the calculated structure-factor.
;
_description.compact                    ReflnCalcPhase
_name.category_id                       refln
_name.attribute_id                      phase_calc
_type.container                         Single
_type.value                             Real
_units.code                             degrees
_type.purpose                           Measurement
_method.expression
;
    _refln.phase_calc <- Atan2d ( _refln.B_calc, _refln.A_calc )
;
save_


save_refln.phase_meas
_definition.id                          '_refln.phase_meas'
_definition.update                      2000-11-03
_description.text
;
     The phase of the measured structure-factor. This may be derived from
     the atom site data if available or from the phase solution process
     prior to determination of the structure.
;
_description.compact                    ReflnMeasPhase
_name.category_id                       refln
_name.attribute_id                      phase_meas
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             degrees
save_


save_refln.refinement_status
_definition.id                          '_refln.refinement_status'
_definition.update                      2000-11-03
_description.text
;
     Status code of reflection in the structure refinement process.
;
_description.compact                    ReflnRefineStatus
_name.category_id                       refln
_name.attribute_id                      refinement_status
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
_enumeration_set.detail
incl 'included in ls process'
excl 'excluded from ls process'
extn 'excluded due to extinction'
_enumeration.default                    incl
save_


save_refln.scale_group_code
_definition.id                          '_refln.scale_group_code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying the scale (if there is more than one scale) used
     convert the measured structure factor to a common absolute value.
;
_description.compact                    ReflnScaleCode
_name.category_id                       refln
_name.attribute_id                      scale_group_code
_name.linked_item_id                    '_reflns_scale.group_code'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_refln.sin_theta_over_lambda
_definition.id                          '_refln.sin_theta_over_lambda'
_definition.update                      2000-11-03
_alias.definition_id                    '_refln.sint/lambda'
_description.text
;
     The (sin theta)/lambda value for this reflection.
;
_description.compact                    ReflnSinTheta/Lambda
_name.category_id                       refln
_name.attribute_id                      sin_theta_over_lambda
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             reciprocal_angstroms
_method.expression
;
     With r  as  refln
                            h <- r.hkl
                            G <- _cell_reciprocal.metric_tensor
 
     r.sin_theta_over_lambda  <-  Sqrt ( h * G * h ) / 2.
;
save_


save_refln.symmetry_epsilon
_definition.id                          '_refln.symmetry_epsilon'
_definition.update                      2000-11-03
_description.text
;
     The symmetry reinforcement factor corresponding to the number of
     times the reflection indices are generated identically from the
     space-group symmetry operations.
;
_description.compact                    ReflnSymmetryEpsilon
_name.category_id                       refln
_name.attribute_id                      symmetry_epsilon
_type.container                         Single
_type.value                             Integer
_enumeration.range                      1:48 
save_


save_refln.symmetry_multiplicity
_definition.id                          '_refln.symmetry_multiplicity'
_definition.update                      2000-11-03
_description.text
;
     The number of reflections symmetry-equivalent under the Laue
     symmetry to the present reflection. In the Laue symmetry, Friedel
     opposites (h k l and -h -k -l) are equivalent. Tables of
     symmetry-equivalent reflections are available in International
     Tables for Crystallography, Volume A (1987), section 10.2.
;
_description.compact                    ReflnSymmetryMultiplicity
_name.category_id                       refln
_name.attribute_id                      symmetry_multiplicity
_type.container                         Single
_type.value                             Integer
_enumeration.range                      1:48 
save_


save_refln.wavelength
_definition.id                          '_refln.wavelength'
_definition.update                      2000-11-03
_description.text
;
     The mean wavelength in angstroms of radiation used to measure
     this reflection. This is an important parameter for data
     collected using energy-dispersive detectors or the Laue method.
;
_description.compact                    ReflnWavelength
_name.category_id                       refln
_name.attribute_id                      wavelength
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_refln.wavelength_id
_definition.id                          '_refln.wavelength_id'
_definition.update                      2000-11-03
_description.text
;
     Name identifying the wavelength in the DIFFRN_RADIATION_WAVELENGTH list.
;
_description.compact                    ReflnWavelengthId
_name.category_id                       refln
_name.attribute_id                      wavelength_id
_name.linked_item_id                    '_diffrn_radiation_wavelength.id'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_

#============================================================================

save_REFLNS
_definition.id                          reflns
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to specify parameters for the complete
     set of reflections used in the structure refinement process. Note that
     these parameters are often simmilar measures to those defined in the
     DIFFRN categories, but differ in that the parameters refer to the
     reduced/transformed reflections which have been used to refine the
     atom site data in the ATOM_SITE category. The DIFFRN definitions refer
     to the diffraction measurements and the raw reflection data.
;
_category.parent_id                     diffraction
save_


save_reflns.d_resolution_high
_definition.id                          '_reflns.d_resolution_high'
_definition.update                      2001-11-27
_description.text
;
     Highest resolution for the final REFLN data set.
     This corresponds to the smallest interpanar d value.
;
_description.compact                    ReflnsResolHigh
_name.category_id                       reflns
_name.attribute_id                      d_resolution_high
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_reflns.d_resolution_low
_definition.id                          '_reflns.d_resolution_low'
_definition.update                      2001-11-27
_description.text
;
     Lowest resolution for the final REFLN data set.
     This corresponds to the largest interpanar d value.
;
_description.compact                    ReflnsResolLow
_name.category_id                       reflns
_name.attribute_id                      d_resolution_low
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_reflns.Friedel_coverage
_definition.id                          '_reflns.Friedel_coverage'
_definition.update                      2000-11-03
_description.text
;
     The proportion of Friedel related reflections present in the number of
     the 'independent reflections' specified by the item _reflns.number_total.
 
     This proportion is calculated as the ratio:
 
           [N(Crystal class) - N(Laue symmetry)] / N(Laue symmetry)
 
     where, working from the @diffrn_refln_ list,
 
         N(Crystal class) is the number of reflections obtained on
             averaging under the symmetry of the crystal class
         N(Laue symmetry) is the number of reflections obtained on
             averaging under the Laue symmetry.
 
       (a) For centrosymmetric structures its value is
           necessarily equal to 0.0 as the crystal class
           is identical to the Laue symmetry.
       (b) For whole-sphere data for a crystal in the space
           group P1, _reflns.Friedel_coverage is equal to 1.0,
           as no reflection h k l is equivalent to -h -k -l
           in the crystal class and all Friedel pairs
           {h k l; -h -k -l} have been measured.
       (c) For whole-sphere data in space group Pmm2, the value
           will be < 1.0 because although reflections h k l and
           -h -k -l are not equivalent when h k l indices are
           non-zero, they are when l=0.
       (d) For a crystal in the group Pmm2 measurements of the
           two inequivalent octants h >= 0, k >=0, l lead to the
           same value as in (c), whereas measurements of the
           two equivalent octants h >= 0, k, l >= 0 will lead to
           a zero value for @reflns_Friedel_coverage.
;
_description.compact                    ReflnsFriedelCoverage
_name.category_id                       reflns
_name.attribute_id                      Friedel_coverage
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:1.0 
save_


save_reflns.limit_h_max
_definition.id                          '_reflns.limit_h_max'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       reflns
_name.attribute_id                      limit_h_max
save_


save_reflns.limit_h_min
_definition.id                          '_reflns.limit_h_min'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       reflns
_name.attribute_id                      limit_h_min
save_


save_reflns.limit_k_max
_definition.id                          '_reflns.limit_k_max'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       reflns
_name.attribute_id                      limit_k_max
save_


save_reflns.limit_k_min
_definition.id                          '_reflns.limit_k_min'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       reflns
_name.attribute_id                      limit_k_min
save_


save_reflns.limit_l_max
_definition.id                          '_reflns.limit_l_max'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       reflns
_name.attribute_id                      limit_l_max
save_


save_reflns.limit_l_min
_definition.id                          '_reflns.limit_l_min'
_definition.import_id                   '_generic.Miller_index'
_name.category_id                       reflns
_name.attribute_id                      limit_l_min
save_


save_reflns.number_gt
_definition.id                          '_reflns.number_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_reflns.number_observed'
_description.text
;
     Count of reflections in the REFLN set (not the DIFFRN_REFLN set) which
     are significantly intense (see _reflns.threshold_expression). It may
     include Friedel equivalent reflections (i.e. those which are equivalent
     under the Laue symmetry but inequivalent under the crystal class),
     depending to the nature of the structure and the procedures used.
;
_description.compact                    ReflnsGtCount
_name.category_id                       reflns
_name.attribute_id                      number_gt
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_reflns.number_total
_definition.id                          '_reflns.number_total'
_definition.update                      2000-11-03
_description.text
;
     Number of reflections in the REFLN set (not the DIFFRN_REFLN set). It may
     include Friedel equivalent reflections (i.e. those which are equivalent
     under the Laue symmetry but inequivalent under the crystal class),
     depending to the nature of the structure and the procedures used.
;
_description.compact                    ReflnsTotalCount
_name.category_id                       reflns
_name.attribute_id                      number_total
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_reflns.special_details
_definition.id                          '_reflns.special_details'
_definition.update                      2000-11-03
_description.text
;
     Description of the properties of the REFLN reflection list that is not
     given in other data items. Should include details about the averaging
     of symmetry-equivalent reflections including Friedel pairs.
;
_description.compact                    ReflnsSpecialDetails
_name.category_id                       reflns
_name.attribute_id                      special_details
_type.container                         Single
_type.value                             Char
save_


save_reflns.threshold_expression
_definition.id                          '_reflns.threshold_expression'
_definition.update                      2000-11-03
_alias.definition_id                    '_reflns.observed_criterion'
_description.text
;
     Description of the criterion used to classify a reflection as having a
     "significant intensity". This criterion is usually expressed in terms
     of a u(I) or u(F) threshold. "u" is the standard uncertainty.
;
_description.compact                    ReflnsThesholdExpression
_name.category_id                       reflns
_name.attribute_id                      threshold_expression
_type.container                         Single
_type.value                             Char
_description_example.case               I>2u(I)
save_

#----------------------------------------------------------------------------

save_REFLNS_CLASS
_definition.id                          reflns_class
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the properties of reflections
     in specific classes of reflections.
;
_category.parent_id                     reflns
_category_key.item_id                   '_reflns_class.code'
save_


save_reflns_class.code
_definition.id                          '_reflns_class.code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a reflection class.
;
_description.compact                    ReflnsClassCode
_name.category_id                       reflns_class
_name.attribute_id                      code
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
_description_example.case               c1
save_


save_reflns_class.description
_definition.id                          '_reflns_class.description'
_definition.update                      2000-11-03
_description.text
;
     Description of a reflection class.
;
_description.compact                    ReflnsClassDetails
_name.category_id                       reflns_class
_name.attribute_id                      description
_type.container                         Single
_type.value                             Char
_description_example.case               'H0L0 common projection reflections'
save_


save_reflns_class.d_res_high
_definition.id                          '_reflns_class.d_res_high'
_definition.update                      2000-11-03
_description.text
;
     Highest resolution for the reflections in this class.
     This corresponds to the smallest interpanar d value.
;
_description.compact                    ReflnsClassResolHigh
_name.category_id                       reflns_class
_name.attribute_id                      d_res_high
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_reflns_class.d_res_low
_definition.id                          '_reflns_class.d_res_low'
_definition.update                      2000-11-03
_description.text
;
     Lowest resolution for the reflections in this class.
     This corresponds to the largest interpanar d value.
;
_description.compact                    ReflnsClassResolLow
_name.category_id                       reflns_class
_name.attribute_id                      d_res_low
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_reflns_class.number_gt
_definition.id                          '_reflns_class.number_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_reflns_class.number_observed'
_description.text
;
     Count of reflections in this REFLN class (not the DIFFRN_REFLN set)
     which are significantly intense (see _reflns.threshold_expression). It may
     include Friedel equivalent reflections (i.e. those which are equivalent
     under the Laue symmetry but inequivalent under the crystal class),
     depending to the nature of the structure and the procedures used.
;
_description.compact                    ReflnsClassGtCount
_name.category_id                       reflns_class
_name.attribute_id                      number_gt
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_reflns_class.number_total
_definition.id                          '_reflns_class.number_total'
_definition.update                      2000-11-03
_description.text
;
     Count of reflections in this REFLN class (not the DIFFRN_REFLN set). It
     may include Friedel equivalent reflections (those which are equivalent
     under the Laue symmetry but inequivalent under the crystal class),
     depending to the nature of the structure and the procedures used.
;
_description.compact                    ReflnsClassTotalCount
_name.category_id                       reflns_class
_name.attribute_id                      number_total
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_reflns_class.R_factor_all
_definition.id                          '_reflns_class.R_factor_all'
_definition.update                      2000-11-03
_description.text
;
     Residual factor for reflections in this class included in the refinement.
     See _refine_ls.R_factor_all definition for details.
;
_description.compact                    ReflnsClassR(F)All
_name.category_id                       reflns_class
_name.attribute_id                      R_factor_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_reflns_class.R_factor_gt
_definition.id                          '_reflns_class.R_factor_gt'
_definition.update                      2000-11-03
_description.text
;
     Residual factor for the reflections in this class judged significantly
     intense (see _reflns.threshold_expression) and included in the refinement.
     See _refine_ls.R_factor_all definition for details.
;
_description.compact                    ReflnsClassR(F)Gt
_name.category_id                       reflns_class
_name.attribute_id                      R_factor_gt
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_reflns_class.R_Fsqd_factor
_definition.id                          '_reflns_class.R_Fsqd_factor'
_definition.update                      2000-11-03
_description.text
;
     Residual factor R(F^2^) for reflections in this class judged significantly
     intense (see _reflns.threshold_expression) and included in the refinement.
     See _refine_ls.R_Fsqd_factor definition for details.
;
_description.compact                    ReflnsClassR(Fsqd)Gt
_name.category_id                       reflns_class
_name.attribute_id                      R_Fsqd_factor
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_reflns_class.R_I_factor
_definition.id                          '_reflns_class.R_I_factor'
_definition.update                      2000-11-03
_description.text
;
     Residual factor R(I) for reflections in this class judged significantly
     intense (see _reflns.threshold_expression) and included in the refinement.
     See _refine_ls.R_I_factor definition for details.
;
_description.compact                    ReflnsClassR(I)Gt
_name.category_id                       reflns_class
_name.attribute_id                      R_I_factor
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_reflns_class.wR_factor_all
_definition.id                          '_reflns_class.wR_factor_all'
_definition.update                      2000-11-03
_description.text
;
     Weight residual for all reflections in this class judged significantly
     intense (see _reflns.threshold_expression) and included in the refinement.
     See _refine_ls.wR_factor_all definition for details.
;
_description.compact                    ReflnsClassWR(F)All
_name.category_id                       reflns_class
_name.attribute_id                      wR_factor_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_

#----------------------------------------------------------------------------

save_REFLNS_SCALE
_definition.id                          reflns_scale
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the scales needed to place
     measured structure factor coefficients on the same absolute scale.
;
_category.parent_id                     reflns
_category_key.item_id                   '_reflns_scale.group_code'
save_


save_reflns_scale.group_code
_definition.id                          '_reflns_scale.group_code'
_definition.update                      2000-11-03
_description.text
;
     Name identifying a reflection scale group. These names need not
     correspond to _diffrn_scale_group.code names.
;
_description.compact                    ReflnsScaleCode
_name.category_id                       reflns_scale
_name.attribute_id                      group_code
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Idname
save_


save_reflns_scale.meas_F
_definition.id                          '_reflns_scale.meas_F'
_definition.update                      2000-11-03
_description.text
;
     Structure factor scale for this scale group.
;
_description.compact                    ReflnsScaleMeasF
_name.category_id                       reflns_scale
_name.attribute_id                      meas_F
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
save_


save_reflns_scale.meas_F_squared
_definition.id                          '_reflns_scale.meas_F_squared'
_definition.update                      2000-11-03
_description.text
;
     Structure factor squared scale for this scale group.
;
_description.compact                    ReflnsScaleMeasFsqd
_name.category_id                       reflns_scale
_name.attribute_id                      meas_F_squared
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
save_


save_reflns_scale.meas_intensity
_definition.id                          '_reflns_scale.meas_intensity'
_definition.update                      2000-11-03
_description.text
;
     Net intensity scale for this scale group.
;
_description.compact                    ReflnsScaleMeasI
_name.category_id                       reflns_scale
_name.attribute_id                      meas_intensity
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_enumeration.range                      0.0:0.0 
save_

#----------------------------------------------------------------------------

save_REFLNS_SHELL
_definition.id                          reflns_shell
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items which specify the information about
     reflections divided into shells bounded by d resolution limits.
;
_category.parent_id                     reflns
_category_key.item_id                   '_reflns_shell.d_res_limits'
save_


save_reflns_shell.d_res_high
_definition.id                          '_reflns_shell.d_res_high'
_definition.update                      2000-11-03
_description.text
;
     Highest resolution for the reflections in this shell.
     This corresponds to the smallest interpanar d value.
;
_description.compact                    ReflnsShellResolHigh
_name.category_id                       reflns_shell
_name.attribute_id                      d_res_high
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_reflns_shell.d_res_limits
_definition.id                          '_reflns_shell.d_res_limits'
_definition.update                      2000-11-03
_description.text
;
     Resolution for the reflections in this shell stored as
     the tuple of lowest and highest values. This is the
     category key.
;
_description.compact                    ReflnsShellResolLimits
_name.category_id                       reflns_shell
_name.attribute_id                      d_res_limits
_type.container                         Tuple
_type.value                             Real
_type_array.dimension                   [2]
_method.expression
;
     With s as reflns_shell
 
        _reflns_shell.d_res_limits <- Tuple ( [ s.d_res_low, s.d_res_high ] )
;
save_


save_reflns_shell.d_res_low
_definition.id                          '_reflns_shell.d_res_low'
_definition.update                      2000-11-29
_description.text
;
     Lowest resolution for the reflections in this shell.
     This corresponds to the largest interpanar d value.
;
_description.compact                    ReflnsShellResolLow
_name.category_id                       reflns_shell
_name.attribute_id                      d_res_low
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
_units.code                             angstroms
save_


save_reflns_shell.meanI_over_uI_all
_definition.id                          '_reflns_shell.meanI_over_uI_all'
_definition.update                      2000-11-03
_alias.definition_id                    '_reflns_shell.meanI_over_sigI_all'
_description.text
;
     Ratio of the mean intensity in a shell to the mean standard uncertainty
     of the intensities in the shell.
;
_description.compact                    ReflnsShellMean(I/suI)All
_name.category_id                       reflns_shell
_name.attribute_id                      meanI_over_uI_all
_type.container                         Single
_type.value                             Real
save_


save_reflns_shell.meanI_over_uI_gt
_definition.id                          '_reflns_shell.meanI_over_uI_gt'
_definition.update                      2000-11-03
loop_
_alias.definition_id
'_reflns_shell.meanI_over_sigI_obs'
'_reflns_shell.meanI_over_sigI_gt'
_description.text
;
     Ratio of the mean intensity of significantly intense reflections (see
     _reflns.threshold_expression) in this shell to the mean standard
     uncertainty of the intensities in the shell.
;
_description.compact                    ReflnsShellMean(I/suI)Gt
_name.category_id                       reflns_shell
_name.attribute_id                      meanI_over_uI_gt
_type.container                         Single
_type.value                             Real
save_


save_reflns_shell.number_measured_all
_definition.id                          '_reflns_shell.number_measured_all'
_definition.update                      2000-11-03
_description.text
;
     Total count of reflections measured for this resolution shell.
;
_description.compact                    ReflnsShellCountAll
_name.category_id                       reflns_shell
_name.attribute_id                      number_measured_all
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_reflns_shell.number_measured_gt
_definition.id                          '_reflns_shell.number_measured_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_reflns_shell.number_measured_obs'
_description.text
;
     Number of reflections measured for this resolution shell which are
     significantly intense (see _reflns.threshold_expression).
;
_description.compact                    ReflnsShellCountGt
_name.category_id                       reflns_shell
_name.attribute_id                      number_measured_gt
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_reflns_shell.number_possible
_definition.id                          '_reflns_shell.number_possible'
_definition.update                      2000-11-03
_description.text
;
     Count of symmetry-unique reflections possible in this reflection shell.
;
_description.compact                    ReflnsShellUniqueCountEst
_name.category_id                       reflns_shell
_name.attribute_id                      number_possible
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_reflns_shell.number_unique_all
_definition.id                          '_reflns_shell.number_unique_all'
_definition.update                      2000-11-03
_description.text
;
     Count of symmetry-unique reflections present in this reflection shell.
;
_description.compact                    ReflnsShellUniqueCountAll
_name.category_id                       reflns_shell
_name.attribute_id                      number_unique_all
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_reflns_shell.number_unique_gt
_definition.id                          '_reflns_shell.number_unique_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_reflns_shell.number_unique_obs'
_description.text
;
     Number of symmetry-unique reflections present in this reflection shell
     which are significantly intense (see _reflns.threshold_expression).
;
_description.compact                    ReflnsShellUniqueCountGt
_name.category_id                       reflns_shell
_name.attribute_id                      number_unique_gt
_type.container                         Single
_type.value                             Integer
_type.purpose                           Count
_enumeration.range                      0:0 
save_


save_reflns_shell.percent_possible_all
_definition.id                          '_reflns_shell.percent_possible_all'
_definition.update                      2000-11-03
_description.text
;
     Percentage of reflections present in this shell over that possible.
;
_description.compact                    ReflnsShellCoverageAll
_name.category_id                       reflns_shell
_name.attribute_id                      percent_possible_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:100.0 
save_


save_reflns_shell.percent_possible_gt
_definition.id                          '_reflns_shell.percent_possible_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_reflns_shell.percent_possible_obs'
_description.text
;
     Percentage of reflections present in this shell which are significantly
     intense (see _reflns.threshold_expression), over that possible.
;
_description.compact                    ReflnsShellCoverageGt
_name.category_id                       reflns_shell
_name.attribute_id                      percent_possible_gt
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:100.0 
save_


save_reflns_shell.Rmerge_F_all
_definition.id                          '_reflns_shell.Rmerge_F_all'
_definition.update                      2000-11-03
_description.text
;
     Rmerge(F) for all reflections in a given shell.
 
                     sum~i~ ( sum~j~ | F~j~ - <F> | )
         Rmerge(F) = --------------------------------
                         sum~i~ ( sum~j~ <F> )
 
         F~j~  = the amplitude of the jth observation of reflection i
         <F> = the mean of the amplitudes of all observations of
                reflection i
 
         sum~i~ is taken over all reflections
         sum~j~ is taken over all observations of each reflection.
;
_description.compact                    ReflnsShellMergeR(F)All
_name.category_id                       reflns_shell
_name.attribute_id                      Rmerge_F_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_reflns_shell.Rmerge_F_gt
_definition.id                          '_reflns_shell.Rmerge_F_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_reflns_shell.Rmerge_F_obs'
_description.text
;
     Rmerge(F) for reflections in a shell which are significantly intense
     (see _reflns.threshold_expression). The residual merge expression is
     shown in the _reflns_shell.Rmerge_F_all definition.
;
_description.compact                    ReflnsShellMergeR(F)Gt
_name.category_id                       reflns_shell
_name.attribute_id                      Rmerge_F_gt
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_reflns_shell.Rmerge_I_all
_definition.id                          '_reflns_shell.Rmerge_I_all'
_definition.update                      2000-11-03
_description.text
;
     Rmerge(I) for all reflections in a given shell.
 
                     sum~i~ ( sum~j~ | I~j~ - <I> | )
         Rmerge(I) = --------------------------------
                         sum~i~ ( sum~j~ <I> )
 
         I~j~  = the intensity of the jth observation of reflection i
         <I> = the mean of the intensities of all observations of
                reflection i
 
         sum~i~ is taken over all reflections
         sum~j~ is taken over all observations of each reflection.
;
_description.compact                    ReflnsShellMergeR(I)All
_name.category_id                       reflns_shell
_name.attribute_id                      Rmerge_I_all
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_


save_reflns_shell.Rmerge_I_gt
_definition.id                          '_reflns_shell.Rmerge_I_gt'
_definition.update                      2000-11-03
_alias.definition_id                    '_reflns_shell.Rmerge_I_obs'
_description.text
;
     Rmerge(I) for reflections in a shell which are significantly intense
     (see _reflns.threshold_expression). The residual merge expression is
     shown in the _reflns_shell.Rmerge_I_all definition.
;
_description.compact                    ReflnsShellMergeR(I)Gt
_name.category_id                       reflns_shell
_name.attribute_id                      Rmerge_I_gt
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.0:0.0 
save_

#============================================================================

save_SYMMETRY
_definition.id                          symmetry
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2000-11-03
_description.text
;
     The CATEGORY of data items used to describe symmetry information
     used in crystallograhic structure studies.
;
_category.parent_id                     crystal
save_


save_symmetry.cell_setting
_definition.id                          '_symmetry.cell_setting'
_definition.update                      2000-11-03
_description.text
;
     Code for cell settings for this space-group symmetry.
;
_description.compact                    SymmetryCellSetting
_name.category_id                       symmetry
_name.attribute_id                      cell_setting
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Code
loop_
_enumeration_set.code
triclinic
monoclinic
orthorhombic
tetragonal
rhombohedral
trigonal
hexagonal
cubic
_enumeration.default                    triclinic
save_


save_symmetry.Int_Tables_number
_definition.id                          '_symmetry.Int_Tables_number'
_definition.update                      2000-11-03
_description.text
;
     Space-group number from International Tables for Crystallography, Vol. A.
;
_description.compact                    SymmetryIntTabNumber
_name.category_id                       symmetry
_name.attribute_id                      Int_Tables_number
_type.container                         Single
_type.value                             Integer
_enumeration.range                      1:230 
save_


save_symmetry.multiplicity
_definition.id                          '_symmetry.multiplicity'
_definition.update                      2000-11-03
_description.text
;
     Number of unique symmetry elements in the space group.
;
_description.compact                    SymmetryMultiplicity
_name.category_id                       symmetry
_name.attribute_id                      multiplicity
_type.container                         Single
_type.value                             Integer
_enumeration.range                      1:192 
_method.expression
;
     n <- 0
 
     Loop  s  as  symmetry_equiv  n +<- 1
 
      _symmetry.multiplicity  <-  n
;
save_


save_symmetry.space_group_name_Hall
_definition.id                          '_symmetry.space_group_name_Hall'
_definition.update                      2000-11-03
_description.text
;
     Space-group symbol as described by Hall. This symbol gives the
     space-group setting explicitly. Leave spaces between the separate
     components of the symbol.
     Ref: Hall, S. R. (1981). Acta Cryst. A37, 517-525.
;
_description.compact                    SpaceGroupSymbolHall
_name.category_id                       symmetry
_name.attribute_id                      space_group_name_Hall
_type.container                         Single
_type.value                             Uchar
loop_
_description_example.case
'P 2ac  2n'
'-R 3 2"'
'P 61 2 2 (0 0 -1)'
save_


save_symmetry.space_group_name_H_M
_definition.id                          '_symmetry.space_group_name_H_M'
_definition.update                      2000-11-03
_alias.definition_id                    '_symmetry.space_group_name_H-M'
_description.text
;
     Hermann-Mauguin space-group symbol. Note that the H-M symbol does
     not necessarily contain complete information about the symmetry
     and the space-group origin. If used always supply the FULL symbol
     from International Tables for Crystallography, Vol. A (1987) and
     indicate the origin and the setting if it is not implicit. If
     there is any doubt that the equivalent positions can be uniquely
     deduced from this symbol specify the _symmetry_equiv.pos_as_xyz
     or *_Hall data items as well. Leave spaces between symbols
     referring to different axes.
;
_description.compact                    SpaceGroupSymbolH-M
_name.category_id                       symmetry
_name.attribute_id                      space_group_name_H_M
_type.container                         Single
_type.value                             Uchar
loop_
_description_example.case
'P 1 21/m 1'
'P 2/n 2/n 2/n (origin at -1)'
'R -3 2/m'
save_

#=============================================================================

save_SYMMETRY_EQUIV
_definition.id                          symmetry_equiv
_definition.scope                       Category
_definition.class                       Datum
_definition.update                      2002-02-02
_description.text
;
     The CATEGORY of data items used to describe symmetry equivalent sites
     in the crystal unit cell.
;
_category.parent_id                     symmetry
_category_key.item_id                   '_symmetry_equiv.pos_site_id'
save_


save_symmetry_equiv.pos_as_xyz
_definition.id                          '_symmetry_equiv.pos_as_xyz'
_definition.update                      2000-11-03
_description.text
;
     Symmetry equivalent position in the 'xyz' representation. Except
     for the space group P1, this data will be repeated in a loop.
     The format of the data item is as per International Tables for
     Crystallography, Vol. A. (1987). All equivalent positions should
     be entered, including those for lattice centring and a centre of
     symmetry, if present.
;
_description.compact                    SymmetryEquivPosXyz
_name.category_id                       symmetry_equiv
_name.attribute_id                      pos_as_xyz
_type.container                         Single
_type.value                             Uchar
_description_example.case               -y+x,-y,1/3+z
save_


save_symmetry_equiv.pos_site_id
_definition.id                          '_symmetry_equiv.pos_site_id'
_definition.update                      2000-11-03
_description.text
;
     A code identifying each entry in the _symmetry_equiv.pos_as_xyz
     list. It is normally the sequence number of the entry in that
     list, and should be identified with the code 'n' in the geometry
     symmetry codes of the form 'n_klm'.
;
_description.compact                    SymmetryEquivPosNumber
_name.category_id                       symmetry_equiv
_name.attribute_id                      pos_site_id
_type.container                         Single
_type.value                             Integer
_type.purpose                           Index
save_


save_symmetry_equiv.R
_definition.id                          '_symmetry_equiv.R'
_definition.update                      2000-11-03
_description.text
;
     A matrix containing the symmetry rotation operations of a space group
 
                    |  r11  r12  r13  |
              R  =  |  r21  r22  r23  |
                    |  r31  r32  r33  |
;
_description.compact                    SymmetryRotMatrix
_name.category_id                       symmetry_equiv
_name.attribute_id                      R
_type.container                         Matrix
_type.value                             Real
_type_array.dimension                   [3,3]
_method.expression
;
                       sm <- _symmetry_equiv.Seitz_matrix
 
        _symmetry_equiv.R <- Matrix([[sm[0,0],sm[0,1],sm[0,2]],
                                     [sm[1,0],sm[1,1],sm[1,2]],
                                     [sm[2,0],sm[2,1],sm[2,2]]])
;
save_


save_symmetry_equiv.RT
_definition.id                          '_symmetry_equiv.RT'
_definition.update                      2000-11-03
_description.text
;
     The TRANSFORM of the symmetry rotation matrix representing the point
     group opertions of the space group
 
                     |  r11  r21  r31  |
              RT  =  |  r12  r22  r32  |
                     |  r13  r23  r33  |
;
_description.compact                    SymmetryRotMatrix
_name.category_id                       symmetry_equiv
_name.attribute_id                      RT
_type.container                         Matrix
_type.value                             Real
_type_array.dimension                   [3,3]
_method.expression
;
        _symmetry_equiv.RT <- Transpose (_symmetry_equiv.R)
;
save_


save_symmetry_equiv.Seitz_matrix
_definition.id                          '_symmetry_equiv.Seitz_matrix'
_definition.update                      2000-11-03
_description.text
;
     A matrix containing the symmetry operations of a space group
     in 4x4 Seitz format.
 
                    |  r11  r12  r13  t1  |
       | R  T |     |  r21  r22  r23  t2  |
       | 0  1 |     |  r31  r32  r33  t3  |
                    |   0    0    0    1  |
;
_description.compact                    SymmetrySeitzMatrix
_name.category_id                       symmetry_equiv
_name.attribute_id                      Seitz_matrix
_type.container                         Matrix
_type.value                             Real
_type_array.dimension                   [4,4]
_type_array.order                       Row_Major
_method.expression
;
   _symmetry_equiv.Seitz_matrix <- SeitzFromJones (_symmetry_equiv.pos_as_xyz)
;
save_


save_symmetry_equiv.T
_definition.id                          '_symmetry_equiv.T'
_definition.update                      2000-11-03
_description.text
;
     A vector containing the symmetry translation operations of a space group.
;
_description.compact                    SymmetryTranslVector
_name.category_id                       symmetry_equiv
_name.attribute_id                      T
_type.container                         Vector
_type.value                             Real
_type_array.dimension                   [3]
_method.expression
;
                       sm <- _symmetry_equiv.Seitz_matrix
 
        _symmetry_equiv.T <- Vector( [sm[0,3],sm[1,3],sm[2,3]] )
;
save_

#============================================================================
#
#  This section of the dictionary contains NO data definitions.
#
#  It contains the definitions which are either imported by defined
#  data items via the attribute _definition.import_id, or are used
#  in method expressions as Functions calls.
#
#============================================================================

save_TRANSIENT_CORE
_definition.id                          transient_core
_definition.scope                       Category
_definition.class                       Transient
_definition.update                      2001-01-18
_description.text
;
     Generic definitions of data items that are defined multiply
     in a dictionary. The attributes of these definitions are
     inherited by item definitions using "_definition.import_id".
;
_category.parent_id                     core
save_

#-----------------------------------------------------------------------------

save_GENERIC
_definition.id                          generic
_definition.scope                       Category
_definition.class                       Generic
_definition.update                      2001-01-18
_description.text
;
     Generic definitions of data items that are defined multiply
     in a dictionary. The attributes of these definitions are
     inherited by item definitions using "_definition.import_id".
;
_category.parent_id                     transient_core
save_


save_generic.atom_site_label
_definition.id                          '_generic.atom_site_label'
_definition.update                      2000-11-03
_description.text
;
     This label is a unique identifier for a particular site in the
     asymmetric unit of the crystal unit cell. It is made up of
     components, _atom_site.label_component_0 to *_6, which may be
     specified as separate data items. Component 0 usually matches one
     of the specified _atom_type.symbol codes. This is not mandatory
     if an _atom_site.type_symbol item is included in the atom site
     list. The _atom_site.type_symbol always takes precedence over
     an _atom_site.label in the identification of the atom type. The
     label components 1 to 6 are optional, and normally only
     components 0 and 1 are used. Note that components 0 and 1 are
     concatenated, while all other components, if specified, are
     separated by an underline character. Underline separators are
     only used if higher-order components exist. If an intermediate
     component is not used it may be omitted provided the underline
     separators are inserted. For example the label 'C233__ggg' is
     acceptable and represents the components C, 233, '', and ggg.
     Each label may have a different number of components.
;
_description.compact                    AtomSiteLabel
_name.category_id                       generic
_name.attribute_id                      atom_site_label
_name.linked_item_id                    '_atom_site.label'
_type.container                         Single
_type.value                             Uchar
_type.purpose                           Label
loop_
_description_example.case
C12
Ca3g28
Fe3+17
H*251
C_a_phe_83_a_0
Zn_Zn_301_A_0
save_


save_generic.site_symmetry
_definition.id                          '_generic.site_symmetry'
_definition.update                      2000-11-03
_description.text
;
     The set of data items which specify the symmetry operation codes
     which must be applied to the atom sites involved in the geometry angle.
 
     The symmetry code of each atom site as the symmetry-equivalent position
     number 'n' and the cell translation number 'klm'. These numbers are
     combined to form the code 'n klm' or n_klm.
 
     The character string n_klm is composed as follows:
 
         n refers to the symmetry operation that is applied to the
         coordinates stored in _atom_site.fract_xyz. It must match a
         number given in _symmetry_equiv.pos_site_id.
 
         k, l and m refer to the translations that are subsequently
         applied to the symmetry transformed coordinates to generate
         the atom used in calculating the angle. These translations
         (x,y,z) are related to (k,l,m) by the relations
              k = 5 + x
              l = 5 + y
              m = 5 + z
;
_name.category_id                       generic
_name.attribute_id                      site_symmetry
_type.container                         Single
_type.value                             Uchar
loop_
_description_example.case
_description_example.detail
4 '4th symmetry operation applied'
7_645 '7th symm. posn.; +a on x; -b on y'
_enumeration.default                    1_555
save_


save_generic.Cartn_coord
_definition.id                          '_generic.Cartn_coord'
_definition.update                      2000-11-03
_description.text
;
     The atom site coordinates in angstroms specified according to a
     set of orthogonal Cartesian axes related to the cell axes as
     specified by the _atom_sites_Cartn_transform.axes description.
;
_name.category_id                       generic
_name.attribute_id                      Cartn_coord
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             angstroms
save_


save_generic.fract_coord
_definition.id                          '_generic.fract_coord'
_definition.update                      2000-11-03
_description.text
;
     Atom site coordinates as fractions of the cell length values.
;
_name.category_id                       generic
_name.attribute_id                      fract_coord
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
save_


save_generic.label_component
_definition.id                          '_generic.label_component'
_definition.update                      2000-11-03
_description.text
;
     Component_0 is normally a code which matches identically with
     one of the _atom_type.symbol codes. If this is the case then the
     rules governing the _atom_type.symbol code apply. If, however,
     the data item _atom_site.type_symbol is also specified in the
     atom site list, component 0 need not match this symbol or adhere
     to any of the _atom_type.symbol rules.
     Component_1 is referred to as the "atom number". When component 0
     is the atom type code, it is used to number the sites with the
     same atom type. This component code must start with at least one
     digit which is not followed by a + or - sign (to distinguish it
     from the component 0 rules).
     Components_2 to 6 contain the identifier, residue, sequence,
     asymmetry identifier and alternate codes, respectively. These
     codes may be composed of any characters except an underline.
;
_name.category_id                       generic
_name.attribute_id                      label_component
_type.container                         Single
_type.value                             Uchar
_type.purpose                           IdName
save_


save_generic.aniso_BIJ_element
_definition.id                          '_generic.aniso_BIJ_element'
_definition.update                      2000-11-03
_description.text
;
     These are the standard anisotropic atomic displacement components
     in angstroms squared which appear in the structure factor term:
 
         T = exp{-1/4 sum~i~ [ sum~j~ (B^ij^ h~i~ h~j~ a*~i~ a*~j~) ] }
 
     h = the Miller indices
     a* = the reciprocal-space cell lengths
     The unique elements of the real symmetric matrix are entered by row.
 
     The IUCr Commission on Nomenclature recommends against the use
     of B for reporting atomic displacement parameters. U, being
     directly proportional to B, is preferred.
;
_name.category_id                       generic
_name.attribute_id                      aniso_BIJ_element
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             angstroms_squared
save_


save_generic.aniso_UIJ_element
_definition.id                          '_generic.aniso_UIJ_element'
_definition.update                      2000-11-03
_description.text
;
     These are the standard anisotropic atomic displacement
     components in angstroms squared which appear in the
     structure factor term:
 
        T = exp{-2pi^2^ sum~i~ [sum~j~ (U^ij^ h~i~ h~j~ a*~i~ a*~j~) ] }
 
     h = the Miller indices
     a* = the reciprocal-space cell lengths
 
     The unique elements of the real symmetric matrix are entered by row.
;
_name.category_id                       generic
_name.attribute_id                      aniso_UIJ_element
_type.container                         Single
_type.value                             Real
_type.purpose                           Measurement
_units.code                             angstroms_squared
save_


save_generic.Cromer_Mann_coeff
_definition.id                          '_generic.Cromer_Mann_coeff'
_definition.update                      2000-11-03
_description.text
;
     The set of data items used to define Cromer-Mann coefficients
     for generation of X-ray scattering factors.
 
        Ref: International Tables for X-ray Crystallography, Vol. IV
             (1974) Table 2.2B
        or   International Tables for Crystallography, Vol. C
             (1991) Tables 6.1.1.4 and 6.1.1.5
;
_name.category_id                       generic
_name.attribute_id                      Cromer_Mann_coeff
_type.container                         Single
_type.value                             Real
save_


save_generic.hi_ang_Fox_coeffs
_definition.id                          '_generic.hi_ang_Fox_coeffs'
_definition.update                      2000-11-03
_description.text
;
    The set of data items used to define Fox et al.  coefficients
     for generation of high angle (s >2.0) X-ray scattering factors.
 
        Ref: International Tables for Crystallography, Vol. C
             (1991) Table 6.1.1.5
;
_name.category_id                       generic
_name.attribute_id                      hi_ang_Fox_coeffs
_type.container                         Single
_type.value                             Real
save_


save_generic.Miller_index
_definition.id                          '_generic.Miller_index'
_definition.update                      2000-11-03
_description.text
;
     The index of a reciprocal space vector.
;
_name.category_id                       generic
_name.attribute_id                      Miller_index
_type.container                         Single
_type.value                             Integer
save_


save_generic.orient_matrix_element
_definition.id                          '_generic.orient_matrix_element'
_definition.update                      2000-11-03
_description.text
;
     The set of data items which specify the elements of the matrix of
     the orientation of the crystal axes to the diffractometer goniometer.
;
_name.category_id                       generic
_name.attribute_id                      orient_matrix_element
_type.container                         Single
_type.value                             Real
save_


save_generic.transf_matrix_element
_definition.id                          '_generic.transf_matrix_element'
_definition.update                      2000-11-03
_description.text
;
     The set of data items which specify the elements of the matrix
     used to transform the reflection indices _diffrn_refln.hkl
     into _refln.hkl.
;
_name.category_id                       generic
_name.attribute_id                      transf_matrix_element
_type.container                         Single
_type.value                             Real
save_


save_generic.diffractometer_angle
_definition.id                          '_generic.diffractometer_angle'
_definition.update                      2000-11-03
_description.text
;
     A diffractometer angle value.
;
_name.category_id                       generic
_name.attribute_id                      diffractometer_angle
_type.container                         Single
_type.value                             Real
_units.code                             degrees
_enumeration.range                      -180.:180. 
save_


save_generic.diffractometer_counts
_definition.id                          '_generic.diffractometer_counts'
_definition.update                      2000-11-03
_description.text
;
     The set of data items which specify the diffractometer counts.
     Background counts before the peak, background after the peak,
     net counts after background removed, counts for peak scan or position,
     and the total counts (background plus peak).
;
_name.category_id                       generic
_name.attribute_id                      diffractometer_counts
_type.container                         Single
_type.value                             Real
_enumeration.range                      0.:0. 
save_


save_generic.display_colour_intensity
_definition.id                          '_generic.display_colour_intensity'
_definition.update                      2000-11-03
_description.text
;
     The set of data items which specify the intensity values
     of red, green and blue for display colour codes.
;
_name.category_id                       generic
_name.attribute_id                      display_colour_intensity
_type.container                         Single
_type.value                             Integer
_enumeration.range                      0:255 
save_

#============================================================================
#
#  This section contains discipline-dependent FUNCTIONS written in dREL.
#
#============================================================================

save_FUNCTION
_definition.id                          function
_definition.scope                       Category
_definition.class                       Function
_definition.update                      2001-01-18
_description.text
;
     The group of items that define FUNCTIONS, which do not appear
     in a data file but are used in the methods for evaluating data.
;
_category.parent_id                     transient_core
save_


save_function.AtomType
_definition.id                          '_function.AtomType'
_definition.update                      2000-11-03
_description.text
;
     The function
                   r  <-  AtomType( s )
 
     returns an atom type symbol (element name) from the atom site label.
;
_name.category_id                       function
_name.attribute_id                      AtomType
_type.container                         Single
_type.value                             Uchar
_method.expression
;
     Function AtomType( s :[Single, Uchar, Label])  {  # atom type label
 
        m <- Len(s)
        n <- 1
        If (m > 1 and s[1] not in '0123456789') n <- 2
        If (m > 2 and s[2]     in '+-'        ) n <- 3
        If (m > 3 and s[3]     in '+-'        ) n <- 4
 
                 AtomType <-  s[0:n]
     }
;
save_


save_function.Closest
_definition.id                          '_function.Closest'
_definition.update                      2000-11-03
_description.text
;
     The function
                   u, d  <-  Closest( v, u )
 
     returns the real coordinate vector U which is the closest cell-
     translated occurence of the vector V to the vector W.  D is the
     cell translation vector required to move V to U.
;
_name.category_id                       function
_name.attribute_id                      Closest
_type.container                         Tuple[Vector]
_type.value                             Real
_type_array.dimension                   [2[3]]
_method.expression
;
     Function Closest( v :[Vector, Real],   # coord vector to be cell translated
                       w :[Vector, Real]) { # target vector
 
            d  <-  v - w
            t  <-  Int( Mod( 99.5 + d, 1.0 ) - d )
 
            Closest <- Tuple ([ v+t, t ])
     }
;
save_


save_function.SeitzFromJones
_definition.id                          '_function.SeitzFromJones'
_definition.update                      2000-11-03
_description.text
;
     The function
                   s  <-  SeitzFromJones( j )
 
     returns a 4x4 Seitz matrix from the Jones faithful representation of
     the equivalent position which is a character string e.g. 1/2+x,-x,z.
;
_name.category_id                       function
_name.attribute_id                      SeitzFromJones
_type.container                         Matrix
_type.value                             Real
_type_array.dimension                   [4,4]
_type_array.order                       Row_Major
_method.expression
;
     Function SeitzFromJones( j :[Single, Uchar])  {  # Jones symmetry notation
 
      joneschrs <- "123456xyz/,+- "
      s         <- Matrix([[0,0,0,0],[0,0,0,0],[0,0,0,0],[0,0,0,1]])
      axis      <- 0
      sign      <- 1
      inum      <- 0
 
      do i=0,Len(j)-1    {
          c <- j[i]
          If (c not in joneschrs) print 'illegal char in symmetry xyz'
 
          If      (c == ' ') Next
          If      (c == ',') {
                             axis     +<- 1
                             inum      <- 0
                             sign      <- 1
          }
          Else If (c == '+') sign      <- +1
          Else If (c == '-') sign      <- -1
          Else If (c == 'x') s[axis,0] <- sign
          Else If (c == 'y') s[axis,1] <- sign
          Else If (c == 'z') s[axis,2] <- sign
          Else   {
               If (inum == 0)   m  <- AtoI(c)
               If (inum == 1 and c != '/') print 'illegal num in symmetry xyz'
               If (inum == 2)   {
                                n  <- AtoI(c)
                     If(n == 5) print 'illegal translation in symmetry xyz'
                     s[axis,3] <- Mod(10.+ Float(sign*m)/Float(n), 1.)
                     sign      <- 1
               }
               inum +<- 1
       }  }
                          SeitzFromJones <- s
    }
;
save_


save_function.SymEquiv
_definition.id                          '_function.SymEquiv'
_definition.update                      2000-11-03
_description.text
;
     The function
                     xyz' <-  SymEquiv( symop, symlist, xyz )
 
     returns a fractional coordinate vector xyz' which is input vector
     xyz transformed by the input symop 'n_pqr' applied to the symmetry
     equivalent position list symlist.
;
_name.category_id                       function
_name.attribute_id                      SymEquiv
_type.container                         Single
_type.value                             Integer
_type.purpose                           Index
_method.expression
;
     Function SymEquiv( c :[Single, Uchar, Symop],        # symop string
                        l                        ,        # symmetry_equiv list
                        x :[Vector, Real, Measurement]) { # fract coordinates
 
             s = l[ SymKey( c ) ]
 
             SymEquiv <- s.R * x + s.T + SymLat( c )
     }
;
save_


save_function.SymKey
_definition.id                          '_function.SymKey'
_definition.update                      2000-11-03
_description.text
;
     The function
                   m  <-  SymKey( s )
 
     returns an integer index to the Seitz matrices from the character
     string of the form 'n_pqr' EXCEPT that m is n-1.
;
_name.category_id                       function
_name.attribute_id                      SymKey
_type.container                         Single
_type.value                             Integer
_type.purpose                           Index
_method.expression
;
     Function SymKey( s :[Single, Uchar])  {  # symop string
 
            If (s == '.')   n <- 1
            Else            n <- AtoI(s[0])
 
                 SymKey <-  n - 1
     }
;
save_


save_function.SymLat
_definition.id                          '_function.SymLat'
_definition.update                      2000-11-03
_description.text
;
     The function
                   v  <-  SymLat( s )
 
     returns a vector of the cell translations applied to the coordinates
     from the character string of the form 'n_pqr'. i.e. p-5, q-5, r-5.
;
_name.category_id                       function
_name.attribute_id                      SymLat
_type.container                         Vector
_type.value                             Integer
_type_array.dimension                   [3]
_method.expression
;
     Function SymLat( s :[Single, Uchar])  {  # symop string
 
            If (s[1] == ' ')  v <- Vector([5, 5, 5])
            Else              v <- Vector([AtoI(s[2]), AtoI(s[3]), AtoI(s[4])])
 
                  SymLat  <-  v - 5
     }
;
save_


save_function.Symop
_definition.id                          '_function.Symop'
_definition.update                      2000-11-03
_description.text
;
     The function
                   s  <-  Symop( n, t )
 
     returns a character string of the form 'n_pqr' where n is the
     symmetry equivalent site number and [p,q,r] is the cell translation
     vector PLUS [5,5,5].
;
_name.category_id                       function
_name.attribute_id                      Symop
_type.container                         Single
_type.value                             Uchar
_method.expression
;
     Function Symop( n  :[Single, Integer],   # symmetry equivalent site number
                     t  :[Vector, Integer]) { # cell translation vector
 
            d  <-  t + 5
         Symop <-  `n` + '_' + `d[0]` + `d[1]` + `d[2]`
     }
;
save_

#=============================================================================
#
#  This section contains the history of the dictionary's creation.
#
#============================================================================

save_AUDIT_CORE
_definition.id                          audit_core
_definition.scope                       Category
_definition.class                       Registration
_definition.update                      2000-11-03
_description.text
;
     Enumeration list which is linked to dictionary_audit data items.
;
_category.parent_id                     core
loop_
_dictionary_audit.version
_dictionary_audit.date
_dictionary_audit.revision
3.0.0 1999-05-20
;
   Conversion of CORE dictionary version 2.1 using "newdic.f" and the
   conversion mapping table "convert_all".
;
3.0.1 1999-05-21
;
   Atom site definitions added and hierarchies set.
;
3.0.2 1999-05-22
;
   Reflection definitions added and hierarchies set.
;
3.0.3 1999-05-24
;
   Symmetry definitions added and hierarchies set.
;
3.0.4 1999-05-27
;
   Syntax corrections from agate and cyclops2 scans sent by BM
;
3.0.5 1999-05-28
;
   Change the DATA_ITEM values in _dictionary.class to ITEMS.
;
3.0.6 1999-06-10
;
   Start adding definitions for the methods calculation of _refln.F_complex
;
3.0.7 1999-06-11
;
   Add CELL definitions.
;
3.0.8 1999-06-14
;
   Add ATOM_TYPE definitions.
;
3.0.9 1999-06-22
;
   Add the RECIPROCAL_CELL_LENGTH definitions.
   Add the DISPLAY_COLOUR definitions.
;
3.0.10 1999-06-28
;
   Correct spelling of _refln.sin_theta_over_lambda.
;
3.0.11 1999-06-30
;
   Impose the changes to the DDL3 TYPE attributes and codes.
;
3.0.12 1999-07-09
;
   Impose the changes to the DDL3 TYPE attributes and codes.
;
3.0.13 1999-07-22
;
   Modify the F_complex method.
;
3.0.14 1999-11-15
;
   Added ATOM_SITES definitions.
;
3.0.15 1999-11-16
;
   Added DIFFRN definitions.
;
3.0.16 1999-11-17
;
   Added EXPTL and REFINE definitions.
;
3.0.17 1999-11-18
;
   Added REFLNS definitions.
;
3.0.18 1999-11-19
;
   Adjust some of the hierarchies.
;
3.0.19 1999-11-25
;
   Introduction of cell vectors and the resulting definition changes.
;
3.0.20 1999-11-26
;
   Add the geom_bond and geom_angle evaluation expressions.
   Add the _definition.update attribute.
;
3.0.21 1999-12-02
;
   Add method to _exptl_crystal.density_diffrn.
;
3.0.22 1999-12-07
;
   Change the nature of the category keys in the GEOM categories.
   Add the _cell.atomic_mass definition.
;
3.0.23 1999-12-07
;
   Introduce Tuples for "id" in GEOM definitions.
   Change SYMMETRY_EQUIV parent hierarchy to "symmetry" not "head"
;
3.0.24 1999-12-08
;
   Impose latest Vector and Matrix notation on the methods. i.e.
   the [...] were replaced by Vector(...) and the (-(....)-) were
   replaced by [-(...)-].
;
3.0.25 1999-12-17
;
   Changes to statements implied by If and ElseIf conditions.
   Revamping of GEOM_ANGLE methods expression.
;
3.0.26 1999-12-20
;
   Revamping of other GEOM methods expressions.
;
3.0.27 2000-01-26
;
   Change sin theta on lambda definition.
   Add the real and reciprocal space metric tensor definitions.
   Correct definitions using id.
;
3.0.28 2000-01-27
;
   Numerous changes imposed by Ian's latest dREL parser requirements.
;
3.0.29 2000-02-11
;
   Changes to the cell and reciprocal cell extensions for vectors.
   Changes to the definition of the atom_sites_Cartn_transform.matrix.
;
3.1.01 2000-04-17
;
   Changes to match new dREL parser requirements.
   Addition of discipline dependent functions.
;
3.1.02 2000-04-18
;
   Addition of MODEL_SITE and changed GEOM_BOND method.
   Addition of GEOM_ANGLE method.
;
3.1.03 2000-04-20
;
   Change geom_bond.distance method.
;
3.1.04 2000-05-18
;
   Align the definitions with the latest dREL syntax requirements.
   Add some more description.compact names
;
3.1.05 2000-05-19
;
   Add FUNCTION category in TRANSIENT definition class
   Remove all of the lower bounds from dimension statements
   Insert Tuple/Vector/Matrix for all methods
   Add some more description.compact names
;
3.1.06 2000-05-22
;
   Add some more description.compact names
;
3.1.07 2000-05-24
;
   Add some more description.compact names
;
3.1.08 2000-05-25
;
   Change the model_site.bond_radius to .radius_bond
;
3.1.09 2000-05-26
;
   Change the geom_angle method.
;
3.1.10 2000-05-31
;
   Introduce the for/loop :index into geom_angle/bond and model_site
;
3.1.11 2000-06-05
;
   Added new geom_angle, geom_contact, geom_torsion and model_site defs
;
3.2.00 2000-06-07
;
   Major reorganisational changes to many definition with the introduction
   of definition.scope COSET.
;
3.2.01 2000-06-09
;
   Several small corrections detected by the parser.
   Movement of the ITEM_ENUMERATION definitions to the back.
   Introduce the major categories CRYSTAL, DIFFRACTION, STRUCTURE,
   MODEL and PUBLICATION.
;
3.2.02 2000-06-10
;
   Used Indic2 to correct various problems
   Changed a number of definition.class ITEM_ENUMERATION to ITEM
;
3.2.03 2000-06-12
;
   Corrected name.coset_id for EXPTL_CRYSTAL_FACE_INDEX and DISPLAY_COLOUR
   Changed the type_array.dimension to [3[2]] instead of [[3][2]]
   Corrected spelling of atom_sites_Cartn_transform
;
3.2.04 2000-06-16
;
   Corrected the form_factor method for Cromer_Mann and hi_ang_Fox values
;
3.3.00 2000-06-28
;
   MAJOR changes to many attributes as per DDL proto decisions.
;
3.3.01 2000-06-29
;
   Place the METHOD attributes in loops when UNITS and EVALUATION used.
;
3.3.02 2000-07-03
;
   Corrections resulting from the dREL 1.0.3 run.
;
3.3.03 2000-07-06
;
   Move the functions from coreglobals.py to EVALUATION_FUNCTION category.
;
3.3.04 2000-07-10
;
   Add some methods for atom_site.number_in_cell and multiplicity.
;
3.3.05 2000-07-11
;
   Add enumeration.dot to several definitions.
;
3.3.06 2000-07-12
;
   Add the model_site.adp_matrix_U and .adp_eigen_values_U.
;
3.3.07 2000-07-18
;
   Add category.join_set_id to ATOM_SITE_ANISO category.
   Convert all [-[...]-] notation to Matrix([....]).
   Introduce symmetry_equiv.R .RT and .T
;
3.3.08 2000-07-19
;
   Used cyclops, quasar and indic to correct small organisation problems.
   Add the SymEquiv() function and remove the Seitz_matrix from methods.
;
3.3.09 2000-07-28
;
   Remove the Eigen function from the FUNCTION category.
;
3.3.10 2000-09-13
;
   Remove enumeration.dot from the definitions. Henceforth if a '.'
   is encountered in a cif it implies the default value for that
   item, OR the item is inapplicable/meaningless.
;
3.4.00 2000-11-03
;
   MAJOR revision to match changes to DDL 3.2.00
;
3.4.01 2000-11-06
;
   Several minor changes to definitions.
;
3.4.02 2000-11-13
;
   Change definition.inheritance to definition.import_id.
;
3.4.03 2000-11-24
;
   Change _method.class "UNITS" to "DEFINITION".
;
3.4.04 2000-11-28
;
   Remove all of the SUPERCEDED definitions and place into _alias.definition_id
;
3.4.05 2000-11-29
;
   Corrected _name.category_id in _reflns_shell.d_res_low.
;
3.4.06 2001-01-18
;
   Changed IMPORT_CORE category to TRANSIENT_CORE.
   Changed definition.class of GENERIC to "Generic"
   Changed definition.class of FUNCTION to "Function"
;
3.4.07 2001-02-15
;
   Made _exptl_crystal.density_diffrn a "Measurement" value
;
3.4.08 2001-05-11
;
   Correct category REFINE_DIFF.
;
3.4.09 2001-08-30
;
   Change "category.parent_id" to "category.family_id".
;
3.4.10 2001-09-26
;
   Reverse the last change!
;
3.4.11 2001-10-02
;
   Change "diffrn_detector.class" to "diffrn_detector.description"
;
3.4.12 2001-11-27
;
   Correct category in reflns.d_resolution_low and high.
;
3.4.13 2002-02-02
;
   Define "pos_site_id" as category key for SYMMETRY_EQUIV
;
3.4.14 2002-02-11
;
   Remove the DATA section defining the display colours
;
save_

#------------------------------------------------------------------------------
